@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2017 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -19,25 +19,20 @@
 
 package com.google.checkstyle.test.chapter3filestructure.rule331nowildcard;
 
-import java.io.File;
-import java.io.IOException;
-
 import org.junit.Test;
 
-import com.google.checkstyle.test.base.BaseCheckTestSupport;
+import com.google.checkstyle.test.base.AbstractModuleTestSupport;
 import com.puppycrawl.tools.checkstyle.api.Configuration;
 
-public class AvoidStarImportTest extends BaseCheckTestSupport {
+public class AvoidStarImportTest extends AbstractModuleTestSupport {
 
     @Override
-    protected String getPath(String fileName) throws IOException {
-        return super.getPath("chapter3filestructure" + File.separator + "rule331nowildcard"
-                + File.separator + fileName);
+    protected String getPackageLocation() {
+        return "com/google/checkstyle/test/chapter3filestructure/rule331nowildcard";
     }
 
     @Test
-    public void starImportTest() throws Exception {
-
+    public void testStarImport() throws Exception {
         final String[] expected = {
             "3: Using the '.*' form of import should be avoided - java.io.*.",
             "4: Using the '.*' form of import should be avoided - java.lang.*.",
@@ -45,10 +40,11 @@ public class AvoidStarImportTest extends BaseCheckTestSupport {
             "19: Using the '.*' form of import should be avoided - javax.swing.WindowConstants.*.",
         };
 
-        final Configuration checkConfig = getCheckConfig("AvoidStarImport");
+        final Configuration checkConfig = getModuleConfig("AvoidStarImport");
         final String filePath = getPath("InputAvoidStarImport.java");
 
         final Integer[] warnList = getLinesWithWarn(filePath);
         verify(checkConfig, filePath, expected, warnList);
     }
+
 }
