@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2017 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -19,17 +19,14 @@
 
 package com.google.checkstyle.test.chapter3filestructure.rule333orderingandspacing;
 
-import java.io.File;
-import java.io.IOException;
-
 import org.junit.Test;
 
-import com.google.checkstyle.test.base.BaseCheckTestSupport;
+import com.google.checkstyle.test.base.AbstractModuleTestSupport;
 import com.puppycrawl.tools.checkstyle.api.Configuration;
 import com.puppycrawl.tools.checkstyle.checks.imports.CustomImportOrderCheck;
 import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
 
-public class CustomImportOrderTest extends BaseCheckTestSupport {
+public class CustomImportOrderTest extends AbstractModuleTestSupport {
 
     /** Shortcuts to make code more compact. */
     private static final String MSG_LINE_SEPARATOR = CustomImportOrderCheck.MSG_LINE_SEPARATOR;
@@ -42,14 +39,12 @@ public class CustomImportOrderTest extends BaseCheckTestSupport {
     private final Class<CustomImportOrderCheck> clazz = CustomImportOrderCheck.class;
 
     @Override
-    protected String getPath(String fileName) throws IOException {
-        return super.getPath("chapter3filestructure" + File.separator + "rule333orderingandspacing"
-                + File.separator + fileName);
+    protected String getPackageLocation() {
+        return "com/google/checkstyle/test/chapter3filestructure/rule333orderingandspacing";
     }
 
     @Test
-    public void customImportTest1() throws Exception {
-
+    public void testCustomImport1() throws Exception {
         final String[] expected = {
             "4: " + getCheckMessage(clazz, MSG_LEX, "java.awt.Button.ABORT",
                 "java.io.File.createTempFile"),
@@ -63,7 +58,7 @@ public class CustomImportOrderTest extends BaseCheckTestSupport {
                 "javax.swing.JTable"),
         };
 
-        final Configuration checkConfig = getCheckConfig("CustomImportOrder");
+        final Configuration checkConfig = getModuleConfig("CustomImportOrder");
         final String filePath = getPath("InputCustomImportOrder1.java");
 
         final Integer[] warnList = getLinesWithWarn(filePath);
@@ -71,8 +66,7 @@ public class CustomImportOrderTest extends BaseCheckTestSupport {
     }
 
     @Test
-    public void customImportTest2() throws Exception {
-
+    public void testCustomImport2() throws Exception {
         final String[] expected = {
             "4: " + getCheckMessage(clazz, MSG_LEX, "java.awt.Button.ABORT",
                 "java.io.File.createTempFile"),
@@ -88,7 +82,7 @@ public class CustomImportOrderTest extends BaseCheckTestSupport {
                 "java.util.concurrent.AbstractExecutorService"),
         };
 
-        final Configuration checkConfig = getCheckConfig("CustomImportOrder");
+        final Configuration checkConfig = getModuleConfig("CustomImportOrder");
         final String filePath = getPath("InputCustomImportOrder2.java");
 
         final Integer[] warnList = getLinesWithWarn(filePath);
@@ -96,8 +90,7 @@ public class CustomImportOrderTest extends BaseCheckTestSupport {
     }
 
     @Test
-    public void customImportTest3() throws Exception {
-
+    public void testCustomImport3() throws Exception {
         final String[] expected = {
             "4: " + getCheckMessage(clazz, MSG_LINE_SEPARATOR, "java.awt.Dialog"),
             "5: " + getCheckMessage(clazz, MSG_NONGROUP_EXPECTED, STATIC,
@@ -115,7 +108,7 @@ public class CustomImportOrderTest extends BaseCheckTestSupport {
                 "java.util.concurrent.AbstractExecutorService"),
         };
 
-        final Configuration checkConfig = getCheckConfig("CustomImportOrder");
+        final Configuration checkConfig = getModuleConfig("CustomImportOrder");
         final String filePath = getPath("InputCustomImportOrder3.java");
 
         final Integer[] warnList = getLinesWithWarn(filePath);
@@ -123,11 +116,10 @@ public class CustomImportOrderTest extends BaseCheckTestSupport {
     }
 
     @Test
-    public void validTest() throws Exception {
-
+    public void testValid() throws Exception {
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
 
-        final Configuration checkConfig = getCheckConfig("CustomImportOrder");
+        final Configuration checkConfig = getModuleConfig("CustomImportOrder");
         final String filePath = getPath("InputCustomImportOrderValid.java");
 
         final Integer[] warnList = getLinesWithWarn(filePath);
@@ -135,13 +127,14 @@ public class CustomImportOrderTest extends BaseCheckTestSupport {
     }
 
     @Test
-    public void validGoogleStyleOrderOfImportsTest() throws Exception {
+    public void testValidGoogleStyleOrderOfImports() throws Exception {
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
 
-        final Configuration checkConfig = getCheckConfig("CustomImportOrder");
+        final Configuration checkConfig = getModuleConfig("CustomImportOrder");
         final String filePath = getPath("InputCustomImportOrderNoImports.java");
 
         final Integer[] warnList = getLinesWithWarn(filePath);
         verify(checkConfig, filePath, expected, warnList);
     }
+
 }
