@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2017 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -19,26 +19,21 @@
 
 package com.google.checkstyle.test.chapter4formatting.rule4821onevariableperline;
 
-import java.io.File;
-import java.io.IOException;
-
 import org.junit.Test;
 
-import com.google.checkstyle.test.base.BaseCheckTestSupport;
+import com.google.checkstyle.test.base.AbstractModuleTestSupport;
 import com.puppycrawl.tools.checkstyle.api.Configuration;
 import com.puppycrawl.tools.checkstyle.checks.coding.MultipleVariableDeclarationsCheck;
 
-public class MultipleVariableDeclarationsTest extends BaseCheckTestSupport {
+public class MultipleVariableDeclarationsTest extends AbstractModuleTestSupport {
 
     @Override
-    protected String getPath(String fileName) throws IOException {
-        return super.getPath("chapter4formatting" + File.separator + "rule4821onevariableperline"
-                + File.separator + fileName);
+    protected String getPackageLocation() {
+        return "com/google/checkstyle/test/chapter4formatting/rule4821onevariableperline";
     }
 
     @Test
-    public void multipleVariableDeclarationsTest() throws Exception {
-
+    public void testMultipleVariableDeclarations() throws Exception {
         final String msgComma = getCheckMessage(MultipleVariableDeclarationsCheck.class,
             "multiple.variable.declarations.comma");
         final String msg = getCheckMessage(MultipleVariableDeclarationsCheck.class,
@@ -67,10 +62,11 @@ public class MultipleVariableDeclarationsTest extends BaseCheckTestSupport {
             "89:5: " + msgComma,
         };
 
-        final Configuration checkConfig = getCheckConfig("MultipleVariableDeclarations");
+        final Configuration checkConfig = getModuleConfig("MultipleVariableDeclarations");
         final String filePath = getPath("InputMultipleVariableDeclarations.java");
 
         final Integer[] warnList = getLinesWithWarn(filePath);
         verify(checkConfig, filePath, expected, warnList);
     }
+
 }
