@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2017 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -19,21 +19,17 @@
 
 package com.google.checkstyle.test.chapter4formatting.rule4861blockcommentstyle;
 
-import java.io.File;
-import java.io.IOException;
-
 import org.junit.Test;
 
-import com.google.checkstyle.test.base.BaseCheckTestSupport;
+import com.google.checkstyle.test.base.AbstractModuleTestSupport;
 import com.puppycrawl.tools.checkstyle.api.Configuration;
 import com.puppycrawl.tools.checkstyle.checks.indentation.CommentsIndentationCheck;
 
-public class CommentsIndentationTest extends BaseCheckTestSupport {
+public class CommentsIndentationTest extends AbstractModuleTestSupport {
 
     @Override
-    protected String getPath(String fileName) throws IOException {
-        return super.getPath("chapter4formatting" + File.separator + "rule4861blockcommentstyle"
-                + File.separator + fileName);
+    protected String getPackageLocation() {
+        return "com/google/checkstyle/test/chapter4formatting/rule4861blockcommentstyle";
     }
 
     @Test
@@ -95,7 +91,7 @@ public class CommentsIndentationTest extends BaseCheckTestSupport {
                 352, 9, 8),
             };
 
-        final Configuration checkConfig = getCheckConfig("CommentsIndentation");
+        final Configuration checkConfig = getModuleConfig("CommentsIndentation");
         final String filePath =
             getPath("InputCommentsIndentationCommentIsAtTheEndOfBlock.java");
 
@@ -142,7 +138,7 @@ public class CommentsIndentationTest extends BaseCheckTestSupport {
                 "228, 230", 6, "12, 12"),
             };
 
-        final Configuration checkConfig = getCheckConfig("CommentsIndentation");
+        final Configuration checkConfig = getModuleConfig("CommentsIndentation");
         final String filePath =
             getPath("InputCommentsIndentationInSwitchBlock.java");
 
@@ -165,7 +161,7 @@ public class CommentsIndentationTest extends BaseCheckTestSupport {
                 72, 0, 8),
             };
 
-        final Configuration checkConfig = getCheckConfig("CommentsIndentation");
+        final Configuration checkConfig = getModuleConfig("CommentsIndentation");
         final String filePath =
             getPath("InputCommentsIndentationInEmptyBlock.java");
 
@@ -196,11 +192,12 @@ public class CommentsIndentationTest extends BaseCheckTestSupport {
                 109, 33, 8),
             };
 
-        final Configuration checkConfig = getCheckConfig("CommentsIndentation");
+        final Configuration checkConfig = getModuleConfig("CommentsIndentation");
         final String filePath =
             getPath("InputCommentsIndentationSurroundingCode.java");
 
         final Integer[] warnList = getLinesWithWarn(filePath);
         verify(checkConfig, filePath, expected, warnList);
     }
+
 }
