@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2017 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -19,27 +19,23 @@
 
 package com.google.checkstyle.test.chapter5naming.rule528typevariablenames;
 
-import java.io.File;
-import java.io.IOException;
-
 import org.junit.Test;
 
-import com.google.checkstyle.test.base.BaseCheckTestSupport;
+import com.google.checkstyle.test.base.AbstractModuleTestSupport;
 import com.puppycrawl.tools.checkstyle.api.Configuration;
 
-public class InterfaceTypeParameterNameTest extends BaseCheckTestSupport {
+public class InterfaceTypeParameterNameTest extends AbstractModuleTestSupport {
 
     private static final String MSG_KEY = "name.invalidPattern";
 
     @Override
-    protected String getPath(String fileName) throws IOException {
-        return super.getPath("chapter5naming" + File.separator + "rule528typevariablenames"
-            + File.separator + fileName);
+    protected String getPackageLocation() {
+        return "com/google/checkstyle/test/chapter5naming/rule528typevariablenames";
     }
 
     @Test
     public void testInterfaceDefault() throws Exception {
-        final Configuration configuration = getCheckConfig("InterfaceTypeParameterName");
+        final Configuration configuration = getModuleConfig("InterfaceTypeParameterName");
         final String format = configuration.getAttribute("format");
 
         final String[] expected = {
