@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2017 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -19,21 +19,17 @@
 
 package com.google.checkstyle.test.chapter7javadoc.rule713atclauses;
 
-import java.io.File;
-import java.io.IOException;
-
 import org.junit.Test;
 
-import com.google.checkstyle.test.base.BaseCheckTestSupport;
+import com.google.checkstyle.test.base.AbstractModuleTestSupport;
 import com.puppycrawl.tools.checkstyle.api.Configuration;
 import com.puppycrawl.tools.checkstyle.checks.javadoc.JavadocTagContinuationIndentationCheck;
 
-public class JavadocTagContinuationIndentationTest extends BaseCheckTestSupport {
+public class JavadocTagContinuationIndentationTest extends AbstractModuleTestSupport {
 
     @Override
-    protected String getPath(String fileName) throws IOException {
-        return super.getPath("chapter7javadoc" + File.separator + "rule713atclauses"
-                + File.separator + fileName);
+    protected String getPackageLocation() {
+        return "com/google/checkstyle/test/chapter7javadoc/rule713atclauses";
     }
 
     @Test
@@ -56,10 +52,11 @@ public class JavadocTagContinuationIndentationTest extends BaseCheckTestSupport
             "322: " + msg,
         };
 
-        final Configuration checkConfig = getCheckConfig("JavadocTagContinuationIndentation");
+        final Configuration checkConfig = getModuleConfig("JavadocTagContinuationIndentation");
         final String filePath = getPath("InputJavaDocTagContinuationIndentation.java");
 
         final Integer[] warnList = getLinesWithWarn(filePath);
         verify(checkConfig, filePath, expected, warnList);
     }
+
 }
