@@ -3,20 +3,17 @@ package com.google.checkstyle.test.chapter3filestructure.rule333orderingandspaci
 import static java.io.File.createTempFile;
 import static java.awt.Button.ABORT; //warn
 import static javax.swing.WindowConstants.*;
-
 import java.awt.Button; //warn
-import java.awt.Frame; //warn
+import java.awt.Frame;
 import java.awt.Dialog; //warn
-import java.awt.event.ActionEvent; //warn
-import javax.swing.JComponent; //warn
-import javax.swing.JTable; //warn
+import java.awt.event.ActionEvent;
+import javax.swing.JComponent;
+import javax.swing.JTable;
 import java.io.File; //warn
 import java.io.IOException; //warn
 import java.io.InputStream; //warn
 import java.io.Reader; //warn
 
-
-
-import com.google.common.base.Ascii;
+import com.google.common.base.Ascii; //warn
 
 public class InputCustomImportOrder1 {}
