@@ -1,21 +1,19 @@
 package com.google.checkstyle.test.chapter3filestructure.rule333orderingandspacing;
 
-import static com.google.common.base.Preconditions.checkArgument;
-import static com.google.common.base.Preconditions.checkNotNull;
-
-import com.google.common.annotations.Beta;
-import com.google.common.annotations.GwtCompatible;
-import com.google.common.annotations.GwtIncompatible;
+import static com.puppycrawl.tools.checkstyle.utils.AnnotationUtility.containsAnnotation;
+import static com.puppycrawl.tools.checkstyle.utils.AnnotationUtility.getAnnotation;
 
+import com.puppycrawl.tools.checkstyle.checks.design.FinalClassCheck;
+import com.puppycrawl.tools.checkstyle.checks.design.ThrowsCountCheck;
+import com.puppycrawl.tools.checkstyle.checks.design.VisibilityModifierCheck;
 import com.sun.accessibility.internal.resources.*;
-import org.apache.commons.beanutils.converters.ArrayConverter;
-
 import java.util.Arrays;
 import java.util.BitSet;
 import java.util.Map;
 import java.util.Map.Entry;
 import java.util.NoSuchElementException;
 import javax.accessibility.Accessible;
+import org.apache.commons.beanutils.converters.ArrayConverter;
 
 public class InputCustomImportOrderValid {
 }
