@@ -1,14 +1,14 @@
 package com.google.checkstyle.test.chapter4formatting.rule462horizontalwhitespace;
 
-import com.google.common.base.Function;
-import com.google.common.base.Supplier;
+import java.util.function.Function;
+import java.util.function.Supplier;
 
 class myFoo
 {
     private void foo()
     {
         int i = 0;
-        String[][] x = {{"foo"}};
+        String[][] x = { {"foo"} };
         for (int first = 0; first < 5; first++) {} //ok
         int j = 0;
         while (j == 1) {} //ok
