@@ -23,7 +23,7 @@ final class InputSimple
     private void localVariables()
     {
         //bad examples
-        int a; //warn
+        int a;
         int aA; //warn
         int a1_a; //warn
         int A_A; //warn
