@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2017 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -19,10 +19,10 @@
 
 package com.puppycrawl.tools.checkstyle;
 
+import java.io.IOException;
 import java.lang.reflect.Constructor;
+import java.util.Collections;
 import java.util.HashMap;
-import java.util.HashSet;
-import java.util.Iterator;
 import java.util.LinkedHashSet;
 import java.util.Map;
 import java.util.Set;
@@ -30,10 +30,11 @@ import java.util.stream.Collectors;
 
 import com.puppycrawl.tools.checkstyle.api.CheckstyleException;
 import com.puppycrawl.tools.checkstyle.api.LocalizedMessage;
+import com.puppycrawl.tools.checkstyle.utils.ModuleReflectionUtils;
 
 /**
- * A factory for creating objects from package names and names,
- * considering:
+ * A factory for creating objects from package names and names.
+ * Consider the below example for better understanding.
  * <ul>
  *     <li>module name - name of java class that represents module;</li>
  *     <li>module full name - fully qualifies name of java class that represents module;</li>
@@ -48,24 +49,53 @@ import com.puppycrawl.tools.checkstyle.api.LocalizedMessage;
  * @author lkuehne
  */
 public class PackageObjectFactory implements ModuleFactory {
-    /** Map of Checkstyle module names to their fully qualified names. */
-    private static final Map<String, String> NAME_TO_FULL_MODULE_NAME = new HashMap<>();
 
-    /** Exception message when null class loader is given. */
-    private static final String NULL_LOADER_MESSAGE = "moduleClassLoader must not be null";
+    /**
+     * Enum class to define loading options.
+     */
+    public enum ModuleLoadOption {
 
-    /** Exception message when it is unable to create a class instance. */
-    private static final String UNABLE_TO_INSTANTIATE_EXCEPTION_MESSAGE =
-        "PackageObjectFactory.unableToInstantiateExceptionMessage";
+        /**
+         * Searching from registered checkstyle modules and from packages given in constructor.
+         **/
+        SEARCH_REGISTERED_PACKAGES,
+        /**
+         * As SEARCH_REGISTERED_PACKAGES and also try to load class from all of packages given in
+         * constructor.
+         * Required for eclipse-cs plugin.
+         **/
+        TRY_IN_ALL_REGISTERED_PACKAGES,
 
-    /** Separator to use in strings. */
-    private static final String STRING_SEPARATOR = ", ";
-
-    /** Suffix of checks. */
-    private static final String CHECK_SUFFIX = "Check";
+    }
 
     /** Base package of checkstyle modules checks. */
-    private static final String BASE_PACKAGE = "com.puppycrawl.tools.checkstyle";
+    public static final String BASE_PACKAGE = "com.puppycrawl.tools.checkstyle";
+
+    /** Exception message when it is unable to create a class instance. */
+    public static final String UNABLE_TO_INSTANTIATE_EXCEPTION_MESSAGE =
+            "PackageObjectFactory.unableToInstantiateExceptionMessage";
+
+    /** Exception message when there is ambiguous module name in config file. */
+    public static final String AMBIGUOUS_MODULE_NAME_EXCEPTION_MESSAGE =
+            "PackageObjectFactory.ambiguousModuleNameExceptionMessage";
+
+    /** Suffix of checks. */
+    public static final String CHECK_SUFFIX = "Check";
+
+    /** Character separate package names in qualified name of java class. */
+    public static final String PACKAGE_SEPARATOR = ".";
+
+    /** Exception message when null class loader is given. */
+    public static final String NULL_LOADER_MESSAGE = "moduleClassLoader must not be null";
+
+    /** Exception message when null package name is given. */
+    public static final String NULL_PACKAGE_MESSAGE = "package name must not be null";
+
+    /** Separator to use in strings. */
+    public static final String STRING_SEPARATOR = ", ";
+
+    /** Map of Checkstyle module names to their fully qualified names. */
+    private static final Map<String, String> NAME_TO_FULL_MODULE_NAME = new HashMap<>();
 
     /** A list of package names to prepend to class names. */
     private final Set<String> packages;
@@ -73,6 +103,12 @@ public class PackageObjectFactory implements ModuleFactory {
     /** The class loader used to load Checkstyle core and custom modules. */
     private final ClassLoader moduleClassLoader;
 
+    /** Map of third party Checkstyle module names to the set of their fully qualified names. */
+    private Map<String, Set<String>> thirdPartyNameToFullModuleNames;
+
+    /** Module load option which defines class search type. */
+    private ModuleLoadOption moduleLoadOption;
+
     static {
         fillShortToFullModuleNamesMap();
     }
@@ -84,13 +120,29 @@ public class PackageObjectFactory implements ModuleFactory {
      *          core and custom modules
      */
     public PackageObjectFactory(Set<String> packageNames, ClassLoader moduleClassLoader) {
+        this(packageNames, moduleClassLoader, ModuleLoadOption.SEARCH_REGISTERED_PACKAGES);
+    }
+
+    /**
+     * Creates a new {@code PackageObjectFactory} instance.
+     * @param packageNames the list of package names to use
+     * @param moduleClassLoader class loader used to load Checkstyle
+     *          core and custom modules
+     * @param moduleLoadOption loading option
+     */
+    public PackageObjectFactory(Set<String> packageNames, ClassLoader moduleClassLoader,
+            ModuleLoadOption moduleLoadOption) {
         if (moduleClassLoader == null) {
             throw new IllegalArgumentException(NULL_LOADER_MESSAGE);
         }
+        if (packageNames.contains(null)) {
+            throw new IllegalArgumentException(NULL_PACKAGE_MESSAGE);
+        }
 
         //create a copy of the given set, but retain ordering
         packages = new LinkedHashSet<>(packageNames);
         this.moduleClassLoader = moduleClassLoader;
+        this.moduleLoadOption = moduleLoadOption;
     }
 
     /**
@@ -103,6 +155,9 @@ public class PackageObjectFactory implements ModuleFactory {
         if (moduleClassLoader == null) {
             throw new IllegalArgumentException(NULL_LOADER_MESSAGE);
         }
+        if (packageName == null) {
+            throw new IllegalArgumentException(NULL_PACKAGE_MESSAGE);
+        }
 
         packages = new LinkedHashSet<>(1);
         packages.add(packageName);
@@ -121,38 +176,54 @@ public class PackageObjectFactory implements ModuleFactory {
      */
     @Override
     public Object createModule(String name) throws CheckstyleException {
-        Object instance = createObjectFromMap(name);
-        if (instance == null) {
-            instance = createObjectWithIgnoringProblems(name, getAllPossibleNames(name));
+        Object instance = null;
+        // if the name is a simple class name, try to find it in maps at first
+        if (!name.contains(PACKAGE_SEPARATOR)) {
+            instance = createFromStandardCheckSet(name);
+            // find the name in third party map
+            if (instance == null) {
+                if (thirdPartyNameToFullModuleNames == null) {
+                    thirdPartyNameToFullModuleNames =
+                            generateThirdPartyNameToFullModuleName(moduleClassLoader);
+                }
+                instance = createObjectFromMap(name, thirdPartyNameToFullModuleNames);
+            }
         }
         if (instance == null) {
-            final String nameCheck = name + CHECK_SUFFIX;
-            instance = createObjectWithIgnoringProblems(nameCheck, getAllPossibleNames(nameCheck));
-            if (instance == null) {
-
-                final String attemptedNames = joinPackageNamesWithClassName(name, packages)
+            instance = createObject(name);
+        }
+        if (instance == null
+                && moduleLoadOption == ModuleLoadOption.TRY_IN_ALL_REGISTERED_PACKAGES) {
+            instance = createModuleByTryInEachPackage(name);
+        }
+        if (instance == null) {
+            String attemptedNames = null;
+            if (!name.contains(PACKAGE_SEPARATOR)) {
+                final String nameCheck = name + CHECK_SUFFIX;
+                attemptedNames = joinPackageNamesWithClassName(name, packages)
                         + STRING_SEPARATOR + nameCheck + STRING_SEPARATOR
                         + joinPackageNamesWithClassName(nameCheck, packages);
-                final LocalizedMessage exceptionMessage = new LocalizedMessage(0,
-                    Definitions.CHECKSTYLE_BUNDLE, UNABLE_TO_INSTANTIATE_EXCEPTION_MESSAGE,
-                    new String[] {name, attemptedNames}, null, getClass(), null);
-                throw new CheckstyleException(exceptionMessage.getMessage());
             }
+            final LocalizedMessage exceptionMessage = new LocalizedMessage(0,
+                Definitions.CHECKSTYLE_BUNDLE, UNABLE_TO_INSTANTIATE_EXCEPTION_MESSAGE,
+                new String[] {name, attemptedNames}, null, getClass(), null);
+            throw new CheckstyleException(exceptionMessage.getMessage());
         }
         return instance;
     }
 
     /**
-     * Create object with the help of Checkstyle NAME_TO_FULL_MODULE_NAME map.
+     * Create object from one of Checkstyle module names.
      * @param name name of module.
-     * @return instance of module if it is found in modules map.
-     * @throws CheckstyleException if the class fails to instantiate.
+     * @return instance of module.
+     * @throws CheckstyleException if the class fails to instantiate or there are ambiguous classes.
      */
-    private Object createObjectFromMap(String name) throws CheckstyleException {
+    private Object createFromStandardCheckSet(String name) throws CheckstyleException {
         final String fullModuleName = NAME_TO_FULL_MODULE_NAME.get(name);
         Object instance = null;
         if (fullModuleName == null) {
-            final String fullCheckModuleName = NAME_TO_FULL_MODULE_NAME.get(name + CHECK_SUFFIX);
+            final String fullCheckModuleName =
+                    NAME_TO_FULL_MODULE_NAME.get(name + CHECK_SUFFIX);
             if (fullCheckModuleName != null) {
                 instance = createObject(fullCheckModuleName);
             }
@@ -164,35 +235,80 @@ public class PackageObjectFactory implements ModuleFactory {
     }
 
     /**
-     * Create a new instance of a named class.
-     * @param className the name of the class to instantiate.
-     * @param secondAttempt the set of names to attempt instantiation
-     *                      if usage of the className was not successful.
-     * @return the {@code Object} created by loader or null.
-     * @throws CheckstyleException if the class fails to instantiate.
+     * Create object with the help of the supplied map.
+     * @param name name of module.
+     * @param map the supplied map.
+     * @return instance of module if it is found in modules map and no ambiguous classes exist.
+     * @throws CheckstyleException if the class fails to instantiate or there are ambiguous classes.
      */
-    private Object createObjectWithIgnoringProblems(String className, Set<String> secondAttempt)
+    private Object createObjectFromMap(String name, Map<String, Set<String>> map)
             throws CheckstyleException {
-        Object instance = createObject(className);
-        if (instance == null) {
-            final Iterator<String> ite = secondAttempt.iterator();
-            while (instance == null && ite.hasNext()) {
-                instance = createObject(ite.next());
+        final Set<String> fullModuleNames = map.get(name);
+        Object instance = null;
+        if (fullModuleNames == null) {
+            final Set<String> fullCheckModuleNames = map.get(name + CHECK_SUFFIX);
+            if (fullCheckModuleNames != null) {
+                instance = createObjectFromFullModuleNames(name, fullCheckModuleNames);
             }
         }
+        else {
+            instance = createObjectFromFullModuleNames(name, fullModuleNames);
+        }
         return instance;
     }
 
     /**
-     * Generate the set of all possible names for a class name.
-     * @param name the name of the class get possible names for.
-     * @return all possible name for a class.
+     * Create Object from optional full module names.
+     * In most case, there should be only one element in {@code fullModuleName}, otherwise
+     * an exception would be thrown.
+     * @param name name of module
+     * @param fullModuleNames the supplied full module names set
+     * @return instance of module if there is only one element in {@code fullModuleName}
+     * @throws CheckstyleException if the class fails to instantiate or there are more than one
+     *      element in {@code fullModuleName}
      */
-    private Set<String> getAllPossibleNames(String name) {
-        final Set<String> names = new HashSet<>();
-        names.addAll(packages.stream().map(packageName -> packageName + name)
-            .collect(Collectors.toList()));
-        return names;
+    private Object createObjectFromFullModuleNames(String name, Set<String> fullModuleNames)
+            throws CheckstyleException {
+        final Object returnValue;
+        if (fullModuleNames.size() == 1) {
+            returnValue = createObject(fullModuleNames.iterator().next());
+        }
+        else {
+            final String optionalNames = fullModuleNames.stream()
+                    .sorted()
+                    .collect(Collectors.joining(STRING_SEPARATOR));
+            final LocalizedMessage exceptionMessage = new LocalizedMessage(0,
+                    Definitions.CHECKSTYLE_BUNDLE, AMBIGUOUS_MODULE_NAME_EXCEPTION_MESSAGE,
+                    new String[] {name, optionalNames}, null, getClass(), null);
+            throw new CheckstyleException(exceptionMessage.getMessage());
+        }
+        return returnValue;
+    }
+
+    /**
+     * Generate the map of third party Checkstyle module names to the set of their fully qualified
+     * names.
+     * @param loader the class loader used to load Checkstyle package names
+     * @return the map of third party Checkstyle module names to the set of their fully qualified
+     *      names
+     */
+    private Map<String, Set<String>> generateThirdPartyNameToFullModuleName(ClassLoader loader) {
+        Map<String, Set<String>> returnValue;
+        try {
+            returnValue = ModuleReflectionUtils.getCheckstyleModules(packages, loader).stream()
+                    .collect(Collectors.toMap(
+                        Class::getSimpleName,
+                        cls -> Collections.singleton(cls.getCanonicalName()),
+                        (fullNames1, fullNames2) -> {
+                            final Set<String> mergedNames = new LinkedHashSet<>(fullNames1);
+                            mergedNames.addAll(fullNames2);
+                            return mergedNames;
+                        }));
+        }
+        catch (IOException ignore) {
+            returnValue = new HashMap<>();
+        }
+        return returnValue;
     }
 
     /**
@@ -202,8 +318,9 @@ public class PackageObjectFactory implements ModuleFactory {
      * @return a string which is obtained by joining package names with a class name.
      */
     private static String joinPackageNamesWithClassName(String className, Set<String> packages) {
-        return packages.stream().filter(name -> name != null)
-            .collect(Collectors.joining(className + STRING_SEPARATOR, "", className));
+        return packages.stream().collect(
+            Collectors.joining(PACKAGE_SEPARATOR + className + STRING_SEPARATOR, "",
+                    PACKAGE_SEPARATOR + className));
     }
 
     /**
@@ -219,7 +336,7 @@ public class PackageObjectFactory implements ModuleFactory {
             clazz = Class.forName(className, true, moduleClassLoader);
         }
         catch (final ReflectiveOperationException | NoClassDefFoundError ignored) {
-            // keep looking, ignoring exception
+            // ignore the exception
         }
 
         Object instance = null;
@@ -231,13 +348,37 @@ public class PackageObjectFactory implements ModuleFactory {
                 instance = declaredConstructor.newInstance();
             }
             catch (final ReflectiveOperationException ex) {
-                throw new CheckstyleException("Unable to instatiate " + className, ex);
+                throw new CheckstyleException("Unable to instantiate " + className, ex);
             }
         }
 
         return instance;
     }
 
+    /**
+     * Searching to class with given name (or name concatenated with &quot;Check&quot;) in existing
+     * packages. Returns instance if class found or, otherwise, null.
+     * @param name the name of a class.
+     * @return the {@code Object} created by loader.
+     * @throws CheckstyleException if an error occurs.
+     */
+    private Object createModuleByTryInEachPackage(String name) throws CheckstyleException {
+        final Set<String> possibleNames = packages.stream()
+                .map(packageName -> packageName + PACKAGE_SEPARATOR + name)
+                .collect(Collectors.toSet());
+        possibleNames.addAll(possibleNames.stream()
+                .map(possibleName -> possibleName + CHECK_SUFFIX)
+                .collect(Collectors.toSet()));
+        Object instance = null;
+        for (String possibleName : possibleNames) {
+            instance = createObject(possibleName);
+            if (instance != null) {
+                break;
+            }
+        }
+        return instance;
+    }
+
     /**
      * Fill short-to-full module names map.
      */
@@ -245,7 +386,7 @@ public class PackageObjectFactory implements ModuleFactory {
         fillChecksFromAnnotationPackage();
         fillChecksFromBlocksPackage();
         fillChecksFromCodingPackage();
-        fillChecksFromDesingPackage();
+        fillChecksFromDesignPackage();
         fillChecksFromHeaderPackage();
         fillChecksFromImportsPackage();
         fillChecksFromIndentationPackage();
@@ -268,6 +409,8 @@ public class PackageObjectFactory implements ModuleFactory {
     private static void fillChecksFromAnnotationPackage() {
         NAME_TO_FULL_MODULE_NAME.put("AnnotationLocationCheck",
                 BASE_PACKAGE + ".checks.annotation.AnnotationLocationCheck");
+        NAME_TO_FULL_MODULE_NAME.put("AnnotationOnSameLineCheck",
+                BASE_PACKAGE + ".checks.annotation.AnnotationOnSameLineCheck");
         NAME_TO_FULL_MODULE_NAME.put("AnnotationUseStyleCheck",
                 BASE_PACKAGE + ".checks.annotation.AnnotationUseStyleCheck");
         NAME_TO_FULL_MODULE_NAME.put("MissingDeprecatedCheck",
@@ -394,7 +537,7 @@ public class PackageObjectFactory implements ModuleFactory {
     /**
      * Fill short-to-full module names map with Checks from design package.
      */
-    private static void fillChecksFromDesingPackage() {
+    private static void fillChecksFromDesignPackage() {
         NAME_TO_FULL_MODULE_NAME.put("DesignForExtensionCheck",
                 BASE_PACKAGE + ".checks.design.DesignForExtensionCheck");
         NAME_TO_FULL_MODULE_NAME.put("FinalClassCheck",
@@ -637,8 +780,6 @@ public class PackageObjectFactory implements ModuleFactory {
                 BASE_PACKAGE + ".checks.AvoidEscapedUnicodeCharactersCheck");
         NAME_TO_FULL_MODULE_NAME.put("DescendantTokenCheck",
                 BASE_PACKAGE + ".checks.DescendantTokenCheck");
-        NAME_TO_FULL_MODULE_NAME.put("FileContentsHolder",
-                BASE_PACKAGE + ".checks.FileContentsHolder");
         NAME_TO_FULL_MODULE_NAME.put("FinalParametersCheck",
                 BASE_PACKAGE + ".checks.FinalParametersCheck");
         NAME_TO_FULL_MODULE_NAME.put("NewlineAtEndOfFileCheck",
@@ -681,10 +822,14 @@ public class PackageObjectFactory implements ModuleFactory {
                 BASE_PACKAGE + ".filters.IntRangeFilter");
         NAME_TO_FULL_MODULE_NAME.put("SeverityMatchFilter",
                 BASE_PACKAGE + ".filters.SeverityMatchFilter");
+        NAME_TO_FULL_MODULE_NAME.put("SuppressWithPlainTextCommentFilter",
+            BASE_PACKAGE + ".filters.SuppressWithPlainTextCommentFilter");
         NAME_TO_FULL_MODULE_NAME.put("SuppressionCommentFilter",
                 BASE_PACKAGE + ".filters.SuppressionCommentFilter");
         NAME_TO_FULL_MODULE_NAME.put("SuppressionFilter",
                 BASE_PACKAGE + ".filters.SuppressionFilter");
+        NAME_TO_FULL_MODULE_NAME.put("SuppressionXpathFilter",
+                BASE_PACKAGE + ".filters.SuppressionXpathFilter");
         NAME_TO_FULL_MODULE_NAME.put("SuppressWarningsFilter",
                 BASE_PACKAGE + ".filters.SuppressWarningsFilter");
         NAME_TO_FULL_MODULE_NAME.put("SuppressWithNearbyCommentFilter",
@@ -698,4 +843,5 @@ public class PackageObjectFactory implements ModuleFactory {
         NAME_TO_FULL_MODULE_NAME.put("Checker", BASE_PACKAGE + ".Checker");
         NAME_TO_FULL_MODULE_NAME.put("TreeWalker", BASE_PACKAGE + ".TreeWalker");
     }
+
 }
