@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2017 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -20,27 +20,19 @@
 package com.puppycrawl.tools.checkstyle;
 
 import java.io.File;
-import java.io.Reader;
-import java.io.StringReader;
-import java.util.AbstractMap.SimpleEntry;
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.HashSet;
-import java.util.List;
 import java.util.Locale;
-import java.util.Map.Entry;
 import java.util.Set;
+import java.util.SortedSet;
+import java.util.TreeSet;
 
-import antlr.CommonHiddenStreamToken;
-import antlr.RecognitionException;
-import antlr.Token;
-import antlr.TokenStreamException;
-import antlr.TokenStreamHiddenTokenFilter;
-import antlr.TokenStreamRecognitionException;
 import com.google.common.collect.HashMultimap;
 import com.google.common.collect.Multimap;
 import com.puppycrawl.tools.checkstyle.api.AbstractCheck;
 import com.puppycrawl.tools.checkstyle.api.AbstractFileSetCheck;
+import com.puppycrawl.tools.checkstyle.api.AutomaticBean;
 import com.puppycrawl.tools.checkstyle.api.CheckstyleException;
 import com.puppycrawl.tools.checkstyle.api.Configuration;
 import com.puppycrawl.tools.checkstyle.api.Context;
@@ -48,9 +40,7 @@ import com.puppycrawl.tools.checkstyle.api.DetailAST;
 import com.puppycrawl.tools.checkstyle.api.ExternalResourceHolder;
 import com.puppycrawl.tools.checkstyle.api.FileContents;
 import com.puppycrawl.tools.checkstyle.api.FileText;
-import com.puppycrawl.tools.checkstyle.api.TokenTypes;
-import com.puppycrawl.tools.checkstyle.grammars.GeneratedJavaLexer;
-import com.puppycrawl.tools.checkstyle.grammars.GeneratedJavaRecognizer;
+import com.puppycrawl.tools.checkstyle.api.LocalizedMessage;
 import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
 import com.puppycrawl.tools.checkstyle.utils.TokenUtils;
 
@@ -79,6 +69,12 @@ public final class TreeWalker extends AbstractFileSetCheck implements ExternalRe
     /** Registered comment checks. */
     private final Set<AbstractCheck> commentChecks = new HashSet<>();
 
+    /** The ast filters. */
+    private final Set<TreeWalkerFilter> filters = new HashSet<>();
+
+    /** The sorted set of messages. */
+    private final SortedSet<LocalizedMessage> messages = new TreeSet<>();
+
     /** The distance between tab stops. */
     private int tabWidth = DEFAULT_TAB_WIDTH;
 
@@ -120,6 +116,7 @@ public final class TreeWalker extends AbstractFileSetCheck implements ExternalRe
     }
 
     /**
+     * Sets classLoader to load class.
      * @param classLoader class loader to resolve classes with.
      */
     public void setClassLoader(ClassLoader classLoader) {
@@ -138,60 +135,90 @@ public final class TreeWalker extends AbstractFileSetCheck implements ExternalRe
     public void finishLocalSetup() {
         final DefaultContext checkContext = new DefaultContext();
         checkContext.add("classLoader", classLoader);
-        checkContext.add("messages", getMessageCollector());
         checkContext.add("severity", getSeverity());
         checkContext.add("tabWidth", String.valueOf(tabWidth));
 
         childContext = checkContext;
     }
 
+    /**
+     * {@inheritDoc} Creates child module.
+     * @noinspection ChainOfInstanceofChecks
+     */
     @Override
     public void setupChild(Configuration childConf)
             throws CheckstyleException {
         final String name = childConf.getName();
         final Object module = moduleFactory.createModule(name);
-        if (!(module instanceof AbstractCheck)) {
+        if (module instanceof AutomaticBean) {
+            final AutomaticBean bean = (AutomaticBean) module;
+            bean.contextualize(childContext);
+            bean.configure(childConf);
+        }
+        if (module instanceof AbstractCheck) {
+            final AbstractCheck check = (AbstractCheck) module;
+            check.init();
+            registerCheck(check);
+        }
+        else if (module instanceof TreeWalkerFilter) {
+            final TreeWalkerFilter filter = (TreeWalkerFilter) module;
+            filters.add(filter);
+        }
+        else {
             throw new CheckstyleException(
-                "TreeWalker is not allowed as a parent of " + name);
+                "TreeWalker is not allowed as a parent of " + name
+                        + " Please review 'Parent Module' section for this Check in web"
+                        + " documentation if Check is standard.");
         }
-        final AbstractCheck check = (AbstractCheck) module;
-        check.contextualize(childContext);
-        check.configure(childConf);
-        check.init();
-
-        registerCheck(check);
     }
 
     @Override
-    protected void processFiltered(File file, List<String> lines) throws CheckstyleException {
+    protected void processFiltered(File file, FileText fileText) throws CheckstyleException {
         // check if already checked and passed the file
-        if (CommonUtils.matchesFileExtension(file, getFileExtensions())) {
-            final String msg = "%s occurred during the analysis of file %s.";
-            final String fileName = file.getPath();
-            try {
-                final FileText text = FileText.fromLines(file, lines);
-                final FileContents contents = new FileContents(text);
-                final DetailAST rootAST = parse(contents);
-
-                getMessageCollector().reset();
-
+        if (CommonUtils.matchesFileExtension(file, getFileExtensions())
+                && (!ordinaryChecks.isEmpty() || !commentChecks.isEmpty())) {
+            final FileContents contents = new FileContents(fileText);
+            final DetailAST rootAST = JavaParser.parse(contents);
+            if (!ordinaryChecks.isEmpty()) {
                 walk(rootAST, contents, AstState.ORDINARY);
-
-                final DetailAST astWithComments = appendHiddenCommentNodes(rootAST);
-
+            }
+            if (!commentChecks.isEmpty()) {
+                final DetailAST astWithComments = JavaParser.appendHiddenCommentNodes(rootAST);
                 walk(astWithComments, contents, AstState.WITH_COMMENTS);
             }
-            catch (final TokenStreamRecognitionException tre) {
-                final String exceptionMsg = String.format(Locale.ROOT, msg,
-                        "TokenStreamRecognitionException", fileName);
-                throw new CheckstyleException(exceptionMsg, tre);
+            if (filters.isEmpty()) {
+                addMessages(messages);
             }
-            catch (RecognitionException | TokenStreamException ex) {
-                final String exceptionMsg = String.format(Locale.ROOT, msg,
-                        ex.getClass().getSimpleName(), fileName);
-                throw new CheckstyleException(exceptionMsg, ex);
+            else {
+                final SortedSet<LocalizedMessage> filteredMessages =
+                    getFilteredMessages(file.getPath(), contents, rootAST);
+                addMessages(filteredMessages);
+            }
+            messages.clear();
+        }
+    }
+
+    /**
+     * Returns filtered set of {@link LocalizedMessage}.
+     * @param fileName path to the file
+     * @param fileContents the contents of the file
+     * @param rootAST root AST element {@link DetailAST} of the file
+     * @return filtered set of messages
+     */
+    private SortedSet<LocalizedMessage> getFilteredMessages(
+            String fileName, FileContents fileContents, DetailAST rootAST) {
+        final SortedSet<LocalizedMessage> result = new TreeSet<>(messages);
+        for (LocalizedMessage element : messages) {
+            final TreeWalkerAuditEvent event =
+                    new TreeWalkerAuditEvent(fileContents, fileName, element, rootAST);
+            for (TreeWalkerFilter filter : filters) {
+                if (!filter.accept(event)) {
+                    result.remove(element);
+                    break;
+                }
             }
         }
+        return result;
     }
 
     /**
@@ -324,6 +351,7 @@ public final class TreeWalker extends AbstractFileSetCheck implements ExternalRe
 
         for (AbstractCheck check : checks) {
             check.setFileContents(contents);
+            check.clearMessages();
             check.beginTree(rootAST);
         }
     }
@@ -345,6 +373,7 @@ public final class TreeWalker extends AbstractFileSetCheck implements ExternalRe
 
         for (AbstractCheck check : checks) {
             check.finishTree(rootAST);
+            messages.addAll(check.getMessages());
         }
     }
 
@@ -380,7 +409,7 @@ public final class TreeWalker extends AbstractFileSetCheck implements ExternalRe
     }
 
     /**
-     * Method returns list of checks
+     * Method returns list of checks.
      *
      * @param ast
      *            the node to notify for
@@ -405,54 +434,6 @@ public final class TreeWalker extends AbstractFileSetCheck implements ExternalRe
         return visitors;
     }
 
-    /**
-     * Static helper method to parses a Java source file.
-     *
-     * @param contents
-     *                contains the contents of the file
-     * @return the root of the AST
-     * @throws TokenStreamException
-     *                 if lexing failed
-     * @throws RecognitionException
-     *                 if parsing failed
-     */
-    public static DetailAST parse(FileContents contents)
-            throws RecognitionException, TokenStreamException {
-        final String fullText = contents.getText().getFullText().toString();
-        final Reader reader = new StringReader(fullText);
-        final GeneratedJavaLexer lexer = new GeneratedJavaLexer(reader);
-        lexer.setFilename(contents.getFileName());
-        lexer.setCommentListener(contents);
-        lexer.setTreatAssertAsKeyword(true);
-        lexer.setTreatEnumAsKeyword(true);
-        lexer.setTokenObjectClass("antlr.CommonHiddenStreamToken");
-
-        final TokenStreamHiddenTokenFilter filter =
-                new TokenStreamHiddenTokenFilter(lexer);
-        filter.hide(TokenTypes.SINGLE_LINE_COMMENT);
-        filter.hide(TokenTypes.BLOCK_COMMENT_BEGIN);
-
-        final GeneratedJavaRecognizer parser =
-            new GeneratedJavaRecognizer(filter);
-        parser.setFilename(contents.getFileName());
-        parser.setASTNodeClass(DetailAST.class.getName());
-        parser.compilationUnit();
-
-        return (DetailAST) parser.getAST();
-    }
-
-    /**
-     * Parses Java source file. Result AST contains comment nodes.
-     * @param contents source file content
-     * @return DetailAST tree
-     * @throws RecognitionException if parser failed
-     * @throws TokenStreamException if lexer failed
-     */
-    public static DetailAST parseWithComments(FileContents contents)
-            throws RecognitionException, TokenStreamException {
-        return appendHiddenCommentNodes(parse(contents));
-    }
-
     @Override
     public void destroy() {
         ordinaryChecks.forEach(AbstractCheck::destroy);
@@ -462,21 +443,43 @@ public final class TreeWalker extends AbstractFileSetCheck implements ExternalRe
 
     @Override
     public Set<String> getExternalResourceLocations() {
-        final Set<String> orinaryChecksResources = getExternalResourceLocations(ordinaryChecks);
-        final Set<String> commentChecksResources = getExternalResourceLocations(commentChecks);
-        final int resultListSize = orinaryChecksResources.size() + commentChecksResources.size();
+        final Set<String> ordinaryChecksResources =
+                getExternalResourceLocationsOfChecks(ordinaryChecks);
+        final Set<String> commentChecksResources =
+                getExternalResourceLocationsOfChecks(commentChecks);
+        final Set<String> filtersResources =
+                getExternalResourceLocationsOfFilters();
+        final int resultListSize = commentChecksResources.size()
+                + ordinaryChecksResources.size()
+                + filtersResources.size();
         final Set<String> resourceLocations = new HashSet<>(resultListSize);
-        resourceLocations.addAll(orinaryChecksResources);
+        resourceLocations.addAll(ordinaryChecksResources);
         resourceLocations.addAll(commentChecksResources);
+        resourceLocations.addAll(filtersResources);
         return resourceLocations;
     }
 
+    /**
+     * Returns a set of external configuration resource locations which are used by the filters set.
+     * @return a set of external configuration resource locations which are used by the filters set.
+     */
+    private Set<String> getExternalResourceLocationsOfFilters() {
+        final Set<String> externalConfigurationResources = new HashSet<>();
+        filters.stream().filter(filter -> filter instanceof ExternalResourceHolder)
+                .forEach(filter -> {
+                    final Set<String> checkExternalResources =
+                        ((ExternalResourceHolder) filter).getExternalResourceLocations();
+                    externalConfigurationResources.addAll(checkExternalResources);
+                });
+        return externalConfigurationResources;
+    }
+
     /**
      * Returns a set of external configuration resource locations which are used by the checks set.
      * @param checks a set of checks.
      * @return a set of external configuration resource locations which are used by the checks set.
      */
-    private static Set<String> getExternalResourceLocations(Set<AbstractCheck> checks) {
+    private static Set<String> getExternalResourceLocationsOfChecks(Set<AbstractCheck> checks) {
         final Set<String> externalConfigurationResources = new HashSet<>();
         checks.stream().filter(check -> check instanceof ExternalResourceHolder).forEach(check -> {
             final Set<String> checkExternalResources =
@@ -508,212 +511,12 @@ public final class TreeWalker extends AbstractFileSetCheck implements ExternalRe
         }
     }
 
-    /**
-     * Appends comment nodes to existing AST.
-     * It traverses each node in AST, looks for hidden comment tokens
-     * and appends found comment tokens as nodes in AST.
-     * @param root
-     *        root of AST.
-     * @return root of AST with comment nodes.
-     */
-    private static DetailAST appendHiddenCommentNodes(DetailAST root) {
-        DetailAST result = root;
-        DetailAST curNode = root;
-        DetailAST lastNode = root;
-
-        while (curNode != null) {
-            if (isPositionGreater(curNode, lastNode)) {
-                lastNode = curNode;
-            }
-
-            CommonHiddenStreamToken tokenBefore = curNode.getHiddenBefore();
-            DetailAST currentSibling = curNode;
-            while (tokenBefore != null) {
-                final DetailAST newCommentNode =
-                         createCommentAstFromToken(tokenBefore);
-
-                currentSibling.addPreviousSibling(newCommentNode);
-
-                if (currentSibling == result) {
-                    result = newCommentNode;
-                }
-
-                currentSibling = newCommentNode;
-                tokenBefore = tokenBefore.getHiddenBefore();
-            }
-
-            DetailAST toVisit = curNode.getFirstChild();
-            while (curNode != null && toVisit == null) {
-                toVisit = curNode.getNextSibling();
-                if (toVisit == null) {
-                    curNode = curNode.getParent();
-                }
-            }
-            curNode = toVisit;
-        }
-        if (lastNode != null) {
-            CommonHiddenStreamToken tokenAfter = lastNode.getHiddenAfter();
-            DetailAST currentSibling = lastNode;
-            while (tokenAfter != null) {
-                final DetailAST newCommentNode =
-                        createCommentAstFromToken(tokenAfter);
-
-                currentSibling.addNextSibling(newCommentNode);
-
-                currentSibling = newCommentNode;
-                tokenAfter = tokenAfter.getHiddenAfter();
-            }
-        }
-        return result;
-    }
-
-    /**
-     * Checks if position of first DetailAST is greater than position of
-     * second DetailAST. Position is line number and column number in source
-     * file.
-     * @param ast1
-     *        first DetailAST node.
-     * @param ast2
-     *        second DetailAST node.
-     * @return true if position of ast1 is greater than position of ast2.
-     */
-    private static boolean isPositionGreater(DetailAST ast1, DetailAST ast2) {
-        if (ast1.getLineNo() == ast2.getLineNo()) {
-            return ast1.getColumnNo() > ast2.getColumnNo();
-        }
-        else {
-            return ast1.getLineNo() > ast2.getLineNo();
-        }
-    }
-
-    /**
-     * Create comment AST from token. Depending on token type
-     * SINGLE_LINE_COMMENT or BLOCK_COMMENT_BEGIN is created.
-     * @param token
-     *        Token object.
-     * @return DetailAST of comment node.
-     */
-    private static DetailAST createCommentAstFromToken(Token token) {
-        if (token.getType() == TokenTypes.SINGLE_LINE_COMMENT) {
-            return createSlCommentNode(token);
-        }
-        else {
-            return createBlockCommentNode(token);
-        }
-    }
-
-    /**
-     * Create single-line comment from token.
-     * @param token
-     *        Token object.
-     * @return DetailAST with SINGLE_LINE_COMMENT type.
-     */
-    private static DetailAST createSlCommentNode(Token token) {
-        final DetailAST slComment = new DetailAST();
-        slComment.setType(TokenTypes.SINGLE_LINE_COMMENT);
-        slComment.setText("//");
-
-        // column counting begins from 0
-        slComment.setColumnNo(token.getColumn() - 1);
-        slComment.setLineNo(token.getLine());
-
-        final DetailAST slCommentContent = new DetailAST();
-        slCommentContent.initialize(token);
-        slCommentContent.setType(TokenTypes.COMMENT_CONTENT);
-
-        // column counting begins from 0
-        // plus length of '//'
-        slCommentContent.setColumnNo(token.getColumn() - 1 + 2);
-        slCommentContent.setLineNo(token.getLine());
-        slCommentContent.setText(token.getText());
-
-        slComment.addChild(slCommentContent);
-        return slComment;
-    }
-
-    /**
-     * Create block comment from token.
-     * @param token
-     *        Token object.
-     * @return DetailAST with BLOCK_COMMENT type.
-     */
-    private static DetailAST createBlockCommentNode(Token token) {
-        final DetailAST blockComment = new DetailAST();
-        blockComment.initialize(TokenTypes.BLOCK_COMMENT_BEGIN, "/*");
-
-        // column counting begins from 0
-        blockComment.setColumnNo(token.getColumn() - 1);
-        blockComment.setLineNo(token.getLine());
-
-        final DetailAST blockCommentContent = new DetailAST();
-        blockCommentContent.initialize(token);
-        blockCommentContent.setType(TokenTypes.COMMENT_CONTENT);
-
-        // column counting begins from 0
-        // plus length of '/*'
-        blockCommentContent.setColumnNo(token.getColumn() - 1 + 2);
-        blockCommentContent.setLineNo(token.getLine());
-        blockCommentContent.setText(token.getText());
-
-        final DetailAST blockCommentClose = new DetailAST();
-        blockCommentClose.initialize(TokenTypes.BLOCK_COMMENT_END, "*/");
-
-        final Entry<Integer, Integer> linesColumns = countLinesColumns(
-                token.getText(), token.getLine(), token.getColumn());
-        blockCommentClose.setLineNo(linesColumns.getKey());
-        blockCommentClose.setColumnNo(linesColumns.getValue());
-
-        blockComment.addChild(blockCommentContent);
-        blockComment.addChild(blockCommentClose);
-        return blockComment;
-    }
-
-    /**
-     * Count lines and columns (in last line) in text.
-     * @param text
-     *        String.
-     * @param initialLinesCnt
-     *        initial value of lines counter.
-     * @param initialColumnsCnt
-     *        initial value of columns counter.
-     * @return entry(pair), first element is lines counter, second - columns
-     *         counter.
-     */
-    private static Entry<Integer, Integer> countLinesColumns(
-            String text, int initialLinesCnt, int initialColumnsCnt) {
-        int lines = initialLinesCnt;
-        int columns = initialColumnsCnt;
-        boolean foundCr = false;
-        for (char c : text.toCharArray()) {
-            if (c == '\n') {
-                foundCr = false;
-                lines++;
-                columns = 0;
-            }
-            else {
-                if (foundCr) {
-                    foundCr = false;
-                    lines++;
-                    columns = 0;
-                }
-                if (c == '\r') {
-                    foundCr = true;
-                }
-                columns++;
-            }
-        }
-        if (foundCr) {
-            lines++;
-            columns = 0;
-        }
-        return new SimpleEntry<>(lines, columns);
-    }
-
     /**
      * State of AST.
      * Indicates whether tree contains certain nodes.
      */
     private enum AstState {
+
         /**
          * Ordinary tree.
          */
@@ -723,5 +526,7 @@ public final class TreeWalker extends AbstractFileSetCheck implements ExternalRe
          * AST contains comment nodes.
          */
         WITH_COMMENTS
+
     }
+
 }
