@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2017 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -25,6 +25,7 @@ import java.util.Map;
 import java.util.Set;
 import java.util.regex.Pattern;
 
+import com.puppycrawl.tools.checkstyle.StatelessCheck;
 import com.puppycrawl.tools.checkstyle.api.AbstractCheck;
 import com.puppycrawl.tools.checkstyle.api.DetailAST;
 import com.puppycrawl.tools.checkstyle.api.TextBlock;
@@ -33,15 +34,16 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
 /**
  * <p>
  * The check to ensure that comments are the only thing on a line.
- * For the case of // comments that means that the only thing that should
+ * For the case of {@code //} comments that means that the only thing that should
  * precede it is whitespace.
  * It doesn't check comments if they do not end line, i.e. it accept
  * the following:
- * {@code Thread.sleep( 10 &lt;some comment here&gt; );}
- * Format property is intended to deal with the "} // while" example.
+ * </p>
+ * <pre><code>Thread.sleep( 10 /*some comment here&#42;/ );</code></pre>
+ * <p>Format property is intended to deal with the <code>} // while</code> example.
  * </p>
  *
- * <p>Rationale: Steve McConnel in &quot;Code Complete&quot; suggests that endline
+ * <p>Rationale: Steve McConnell in &quot;Code Complete&quot; suggests that endline
  * comments are a bad practice. An end line comment would
  * be one that is on the same line as actual code. For example:
  * <pre>
@@ -96,7 +98,9 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
  * </pre>
  *
  * @author o_sukhodolsky
+ * @noinspection HtmlTagCanBeJavadocTag
  */
+@StatelessCheck
 public class TrailingCommentCheck extends AbstractCheck {
 
     /**
@@ -109,7 +113,7 @@ public class TrailingCommentCheck extends AbstractCheck {
     private Pattern legalComment;
 
     /** The regexp to match against. */
-    private Pattern format = Pattern.compile("^[\\s\\});]*$");
+    private Pattern format = Pattern.compile("^[\\s});]*$");
 
     /**
      * Sets patter for legal trailing comments.
@@ -129,12 +133,12 @@ public class TrailingCommentCheck extends AbstractCheck {
 
     @Override
     public int[] getDefaultTokens() {
-        return CommonUtils.EMPTY_INT_ARRAY;
+        return getRequiredTokens();
     }
 
     @Override
     public int[] getAcceptableTokens() {
-        return CommonUtils.EMPTY_INT_ARRAY;
+        return getRequiredTokens();
     }
 
     @Override
@@ -150,9 +154,9 @@ public class TrailingCommentCheck extends AbstractCheck {
     @Override
     public void beginTree(DetailAST rootAST) {
         final Map<Integer, TextBlock> cppComments = getFileContents()
-                .getCppComments();
+                .getSingleLineComments();
         final Map<Integer, List<TextBlock>> cComments = getFileContents()
-                .getCComments();
+                .getBlockComments();
         final Set<Integer> lines = new HashSet<>();
         lines.addAll(cppComments.keySet());
         lines.addAll(cComments.keySet());
@@ -172,7 +176,8 @@ public class TrailingCommentCheck extends AbstractCheck {
 
                 // do not check comment which doesn't end line
                 if (comment.getText().length == 1
-                        && !line.substring(comment.getEndColNo() + 1).trim().isEmpty()) {
+                        && !CommonUtils.isBlank(line
+                            .substring(comment.getEndColNo() + 1))) {
                     continue;
                 }
             }
@@ -209,4 +214,5 @@ public class TrailingCommentCheck extends AbstractCheck {
         }
         return legal;
     }
+
 }
