@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -22,7 +22,6 @@ package com.puppycrawl.tools.checkstyle.checks;
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.IOException;
-import java.util.List;
 import java.util.Properties;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
@@ -31,7 +30,10 @@ import com.google.common.collect.HashMultiset;
 import com.google.common.collect.ImmutableMultiset;
 import com.google.common.collect.Multiset;
 import com.google.common.collect.Multiset.Entry;
+import com.google.common.io.Closeables;
+import com.puppycrawl.tools.checkstyle.StatelessCheck;
 import com.puppycrawl.tools.checkstyle.api.AbstractFileSetCheck;
+import com.puppycrawl.tools.checkstyle.api.FileText;
 
 /**
  * Checks the uniqueness of property keys (left from equal sign) in the
@@ -39,6 +41,7 @@ import com.puppycrawl.tools.checkstyle.api.AbstractFileSetCheck;
  *
  * @author Pavel Baranchikov
  */
+@StatelessCheck
 public class UniquePropertiesCheck extends AbstractFileSetCheck {
 
     /**
@@ -63,28 +66,25 @@ public class UniquePropertiesCheck extends AbstractFileSetCheck {
     }
 
     @Override
-    protected void processFiltered(File file, List<String> lines) {
+    protected void processFiltered(File file, FileText fileText) {
         final UniqueProperties properties = new UniqueProperties();
-
+        FileInputStream fileInputStream = null;
         try {
-            final FileInputStream fileInputStream = new FileInputStream(file);
-            try {
-                // As file is already read, there should not be any exceptions.
-                properties.load(fileInputStream);
-            }
-            finally {
-                fileInputStream.close();
-            }
+            fileInputStream = new FileInputStream(file);
+            properties.load(fileInputStream);
         }
         catch (IOException ex) {
             log(0, MSG_IO_EXCEPTION_KEY, file.getPath(),
                     ex.getLocalizedMessage());
         }
+        finally {
+            Closeables.closeQuietly(fileInputStream);
+        }
 
         for (Entry<String> duplication : properties
                 .getDuplicatedKeys().entrySet()) {
             final String keyName = duplication.getElement();
-            final int lineNumber = getLineNumber(lines, keyName);
+            final int lineNumber = getLineNumber(fileText, keyName);
             // Number of occurrences is number of duplications + 1
             log(lineNumber, MSG_KEY, keyName, duplication.getCount() + 1);
         }
@@ -94,38 +94,54 @@ public class UniquePropertiesCheck extends AbstractFileSetCheck {
      * Method returns line number the key is detected in the checked properties
      * files first.
      *
-     * @param lines
-     *            properties file lines list
+     * @param fileText
+     *            {@link FileText} object contains the lines to process
      * @param keyName
      *            key name to look for
      * @return line number of first occurrence. If no key found in properties
      *         file, 0 is returned
      */
-    protected static int getLineNumber(List<String> lines, String keyName) {
-        final String keyPatternString = "^" + SPACE_PATTERN.matcher(keyName)
-                        .replaceAll(Matcher.quoteReplacement("\\\\ ")) + "[\\s:=].*$";
-        final Pattern keyPattern = Pattern.compile(keyPatternString);
+    private static int getLineNumber(FileText fileText, String keyName) {
+        final Pattern keyPattern = getKeyPattern(keyName);
         int lineNumber = 1;
         final Matcher matcher = keyPattern.matcher("");
-        for (String line : lines) {
+        for (int index = 0; index < fileText.size(); index++) {
+            final String line = fileText.get(index);
             matcher.reset(line);
             if (matcher.matches()) {
                 break;
             }
             ++lineNumber;
         }
-        if (lineNumber > lines.size()) {
+        // -1 as check seeks for the first duplicate occurrence in file,
+        // so it cannot be the last line.
+        if (lineNumber > fileText.size() - 1) {
             lineNumber = 0;
         }
         return lineNumber;
     }
 
+    /**
+     * Method returns regular expression pattern given key name.
+     *
+     * @param keyName
+     *            key name to look for
+     * @return regular expression pattern given key name
+     */
+    private static Pattern getKeyPattern(String keyName) {
+        final String keyPatternString = "^" + SPACE_PATTERN.matcher(keyName)
+                .replaceAll(Matcher.quoteReplacement("\\\\ ")) + "[\\s:=].*$";
+        return Pattern.compile(keyPatternString);
+    }
+
     /**
      * Properties subclass to store duplicated property keys in a separate map.
      *
      * @author Pavel Baranchikov
+     * @noinspection ClassExtendsConcreteCollection, SerializableHasSerializationMethods
      */
     private static class UniqueProperties extends Properties {
+
         private static final long serialVersionUID = 1L;
         /**
          * Multiset, holding duplicated keys. Keys are added here only if they
@@ -134,8 +150,12 @@ public class UniquePropertiesCheck extends AbstractFileSetCheck {
         private final Multiset<String> duplicatedKeys = HashMultiset
                 .create();
 
+        /**
+         * Puts the value into properties by the key specified.
+         * @noinspection UseOfPropertiesAsHashtable
+         */
         @Override
-        public Object put(Object key, Object value) {
+        public synchronized Object put(Object key, Object value) {
             final Object oldValue = super.put(key, value);
             if (oldValue != null && key instanceof String) {
                 final String keyString = (String) key;
@@ -152,5 +172,7 @@ public class UniquePropertiesCheck extends AbstractFileSetCheck {
         public Multiset<String> getDuplicatedKeys() {
             return ImmutableMultiset.copyOf(duplicatedKeys);
         }
+
     }
+
 }
