@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2017 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -25,6 +25,7 @@ package com.puppycrawl.tools.checkstyle.checks.blocks;
  * @see EmptyBlockCheck
  */
 public enum BlockOption {
+
     /**
      * Represents the policy that there is some text in the block. For example:
      *
@@ -46,5 +47,6 @@ public enum BlockOption {
      * }
      * </pre>
      */
-    STMT
+    STATEMENT
+
 }
