@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -20,11 +20,11 @@
 package com.puppycrawl.tools.checkstyle.checks.coding;
 
 import java.util.Deque;
+import java.util.LinkedList;
 
 import antlr.collections.AST;
-
-import com.google.common.collect.Lists;
-import com.puppycrawl.tools.checkstyle.api.Check;
+import com.puppycrawl.tools.checkstyle.FileStatefulCheck;
+import com.puppycrawl.tools.checkstyle.api.AbstractCheck;
 import com.puppycrawl.tools.checkstyle.api.DetailAST;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
 import com.puppycrawl.tools.checkstyle.utils.ScopeUtils;
@@ -36,8 +36,9 @@ import com.puppycrawl.tools.checkstyle.utils.ScopeUtils;
  * </p>
  * @author Rick Giles
  */
+@FileStatefulCheck
 public abstract class AbstractSuperCheck
-        extends Check {
+        extends AbstractCheck {
 
     /**
      * A key is pointing to the warning message text in "messages.properties"
@@ -46,7 +47,7 @@ public abstract class AbstractSuperCheck
     public static final String MSG_KEY = "missing.super.call";
 
     /** Stack of methods. */
-    private final Deque<MethodNode> methodStack = Lists.newLinkedList();
+    private final Deque<MethodNode> methodStack = new LinkedList<>();
 
     /**
      * Returns the name of the overriding method.
@@ -56,20 +57,20 @@ public abstract class AbstractSuperCheck
 
     @Override
     public int[] getAcceptableTokens() {
-        return new int[] {
-            TokenTypes.METHOD_DEF,
-            TokenTypes.LITERAL_SUPER,
-        };
+        return getRequiredTokens();
     }
 
     @Override
     public int[] getDefaultTokens() {
-        return getAcceptableTokens();
+        return getRequiredTokens();
     }
 
     @Override
     public int[] getRequiredTokens() {
-        return getDefaultTokens();
+        return new int[] {
+            TokenTypes.METHOD_DEF,
+            TokenTypes.LITERAL_SUPER,
+        };
     }
 
     @Override
@@ -101,8 +102,7 @@ public abstract class AbstractSuperCheck
             // dot operator?
             final DetailAST dotAst = literalSuperAst.getParent();
 
-            if (dotAst.getType() == TokenTypes.DOT
-                && !isSameNameMethod(literalSuperAst)
+            if (!isSameNameMethod(literalSuperAst)
                 && !hasArguments(dotAst)) {
                 superCall = isSuperCallInOverridingMethod(dotAst);
             }
@@ -120,16 +120,13 @@ public abstract class AbstractSuperCheck
         boolean inOverridingMethod = false;
         DetailAST dotAst = ast;
 
-        while (dotAst != null
-                && dotAst.getType() != TokenTypes.CTOR_DEF
+        while (dotAst.getType() != TokenTypes.CTOR_DEF
                 && dotAst.getType() != TokenTypes.INSTANCE_INIT) {
-
             if (dotAst.getType() == TokenTypes.METHOD_DEF) {
                 inOverridingMethod = isOverridingMethod(dotAst);
                 break;
             }
             dotAst = dotAst.getParent();
-
         }
         return inOverridingMethod;
     }
@@ -150,18 +147,13 @@ public abstract class AbstractSuperCheck
      * @return true if method name is the same
      */
     private boolean isSameNameMethod(DetailAST ast) {
-
         AST sibling = ast.getNextSibling();
         // ignore type parameters
         if (sibling != null
             && sibling.getType() == TokenTypes.TYPE_ARGUMENTS) {
             sibling = sibling.getNextSibling();
         }
-        if (sibling == null || sibling.getType() != TokenTypes.IDENT) {
-            return true;
-        }
-        final String name = sibling.getText();
-        return !getMethodName().equals(name);
+        return sibling == null || !getMethodName().equals(sibling.getText());
     }
 
     @Override
@@ -195,7 +187,7 @@ public abstract class AbstractSuperCheck
             final DetailAST modifiersAST = ast.findFirstToken(TokenTypes.MODIFIERS);
 
             if (getMethodName().equals(name)
-                    && !modifiersAST.branchContains(TokenTypes.LITERAL_NATIVE)) {
+                    && modifiersAST.findFirstToken(TokenTypes.LITERAL_NATIVE) == null) {
                 final DetailAST params = ast.findFirstToken(TokenTypes.PARAMETERS);
                 overridingMethod = params.getChildCount() == 0;
             }
@@ -209,6 +201,7 @@ public abstract class AbstractSuperCheck
      * @author Rick Giles
      */
     private static class MethodNode {
+
         /** Method definition. */
         private final DetailAST method;
 
@@ -247,5 +240,7 @@ public abstract class AbstractSuperCheck
         public DetailAST getMethod() {
             return method;
         }
+
     }
+
 }
