@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2017 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -23,6 +23,7 @@ import java.util.HashMap;
 import java.util.Map;
 
 import antlr.collections.AST;
+import com.puppycrawl.tools.checkstyle.FileStatefulCheck;
 import com.puppycrawl.tools.checkstyle.api.AbstractCheck;
 import com.puppycrawl.tools.checkstyle.api.DetailAST;
 import com.puppycrawl.tools.checkstyle.api.FullIdent;
@@ -51,8 +52,10 @@ import com.puppycrawl.tools.checkstyle.utils.CheckUtils;
  * </pre>
  * @author lkuehne
  */
+@FileStatefulCheck
 public class EqualsHashCodeCheck
         extends AbstractCheck {
+
     // implementation note: we have to use the following members to
     // keep track of definitions in different inner classes
 
@@ -76,17 +79,17 @@ public class EqualsHashCodeCheck
 
     @Override
     public int[] getDefaultTokens() {
-        return getAcceptableTokens();
+        return getRequiredTokens();
     }
 
     @Override
     public int[] getAcceptableTokens() {
-        return new int[] {TokenTypes.METHOD_DEF};
+        return getRequiredTokens();
     }
 
     @Override
     public int[] getRequiredTokens() {
-        return getAcceptableTokens();
+        return new int[] {TokenTypes.METHOD_DEF};
     }
 
     @Override
@@ -116,10 +119,10 @@ public class EqualsHashCodeCheck
         final DetailAST parameters = ast.findFirstToken(TokenTypes.PARAMETERS);
 
         return CheckUtils.isEqualsMethod(ast)
-                && modifiers.branchContains(TokenTypes.LITERAL_PUBLIC)
+                && modifiers.findFirstToken(TokenTypes.LITERAL_PUBLIC) != null
                 && isObjectParam(parameters.getFirstChild())
-                && (ast.branchContains(TokenTypes.SLIST)
-                        || modifiers.branchContains(TokenTypes.LITERAL_NATIVE));
+                && (ast.findFirstToken(TokenTypes.SLIST) != null
+                        || modifiers.findFirstToken(TokenTypes.LITERAL_NATIVE) != null);
     }
 
     /**
@@ -136,11 +139,11 @@ public class EqualsHashCodeCheck
 
         return type.getFirstChild().getType() == TokenTypes.LITERAL_INT
                 && "hashCode".equals(methodName.getText())
-                && modifiers.branchContains(TokenTypes.LITERAL_PUBLIC)
-                && !modifiers.branchContains(TokenTypes.LITERAL_STATIC)
+                && modifiers.findFirstToken(TokenTypes.LITERAL_PUBLIC) != null
+                && modifiers.findFirstToken(TokenTypes.LITERAL_STATIC) == null
                 && parameters.getFirstChild() == null
-                && (ast.branchContains(TokenTypes.SLIST)
-                        || modifiers.branchContains(TokenTypes.LITERAL_NATIVE));
+                && (ast.findFirstToken(TokenTypes.SLIST) != null
+                        || modifiers.findFirstToken(TokenTypes.LITERAL_NATIVE) != null);
     }
 
     /**
@@ -158,18 +161,15 @@ public class EqualsHashCodeCheck
     @Override
     public void finishTree(DetailAST rootAST) {
         objBlockWithEquals
-            .entrySet().stream().filter(detailASTDetailASTEntry ->
-                objBlockWithHashCode.remove(detailASTDetailASTEntry.getKey()) == null)
-            .forEach(detailASTDetailASTEntry -> {
+            .entrySet().stream().filter(detailASTDetailASTEntry -> {
+                return objBlockWithHashCode.remove(detailASTDetailASTEntry.getKey()) == null;
+            }).forEach(detailASTDetailASTEntry -> {
                 final DetailAST equalsAST = detailASTDetailASTEntry.getValue();
                 log(equalsAST.getLineNo(), equalsAST.getColumnNo(), MSG_KEY_HASHCODE);
             });
-        objBlockWithHashCode.entrySet().forEach(detailASTDetailASTEntry -> {
-            final DetailAST equalsAST = detailASTDetailASTEntry.getValue();
+        objBlockWithHashCode.forEach((key, equalsAST) -> {
             log(equalsAST.getLineNo(), equalsAST.getColumnNo(), MSG_KEY_EQUALS);
         });
-
-        objBlockWithEquals.clear();
-        objBlockWithHashCode.clear();
     }
+
 }
