@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2017 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -19,6 +19,7 @@
 
 package com.puppycrawl.tools.checkstyle.checks.coding;
 
+import com.puppycrawl.tools.checkstyle.StatelessCheck;
 import com.puppycrawl.tools.checkstyle.api.AbstractCheck;
 import com.puppycrawl.tools.checkstyle.api.DetailAST;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
@@ -53,6 +54,7 @@ import com.puppycrawl.tools.checkstyle.utils.TokenUtils;
  * @author <a href="mailto:simon@redhillconsulting.com.au">Simon Harris</a>
  * @author Rick Giles
  */
+@StatelessCheck
 public class IllegalTokenCheck
     extends AbstractCheck {
 
@@ -105,9 +107,9 @@ public class IllegalTokenCheck
             case TokenTypes.LABELED_STAT:
                 tokenText = ast.getFirstChild().getText() + ast.getText();
                 break;
-            // multyline tokens need to become singlelined
+            // multiline tokens need to become singlelined
             case TokenTypes.COMMENT_CONTENT:
-                tokenText = JavadocUtils.excapeAllControlChars(ast.getText());
+                tokenText = JavadocUtils.escapeAllControlChars(ast.getText());
                 break;
             default:
                 tokenText = ast.getText();
