@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -27,12 +27,11 @@ import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
 import antlr.collections.ASTEnumeration;
-
-import com.puppycrawl.tools.checkstyle.api.Check;
+import com.puppycrawl.tools.checkstyle.StatelessCheck;
+import com.puppycrawl.tools.checkstyle.api.AbstractCheck;
 import com.puppycrawl.tools.checkstyle.api.DetailAST;
 import com.puppycrawl.tools.checkstyle.api.FullIdent;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
-import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
 
 /**
  * <p>
@@ -165,7 +164,9 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
  * @author <a href="mailto:rd.ryly@gmail.com">Ruslan Diachenko</a>
  * @author <a href="mailto:barataliba@gmail.com">Baratali Izmailov</a>
  */
-public class VariableDeclarationUsageDistanceCheck extends Check {
+@StatelessCheck
+public class VariableDeclarationUsageDistanceCheck extends AbstractCheck {
+
     /**
      * Warning message key.
      */
@@ -213,13 +214,10 @@ public class VariableDeclarationUsageDistanceCheck extends Check {
 
     /**
      * Sets RegExp pattern to ignore distance calculation for variables listed in this pattern.
-     * @param ignorePattern
-     *        Pattern contains ignored variables.
-     * @throws org.apache.commons.beanutils.ConversionException
-     *         if unable to create Pattern object.
+     * @param pattern a pattern.
      */
-    public void setIgnoreVariablePattern(String ignorePattern) {
-        ignoreVariablePattern = CommonUtils.createPattern(ignorePattern);
+    public void setIgnoreVariablePattern(Pattern pattern) {
+        ignoreVariablePattern = pattern;
     }
 
     /**
@@ -244,17 +242,17 @@ public class VariableDeclarationUsageDistanceCheck extends Check {
 
     @Override
     public int[] getDefaultTokens() {
-        return getAcceptableTokens();
+        return getRequiredTokens();
     }
 
     @Override
     public int[] getAcceptableTokens() {
-        return new int[] {TokenTypes.VARIABLE_DEF};
+        return getRequiredTokens();
     }
 
     @Override
     public int[] getRequiredTokens() {
-        return getAcceptableTokens();
+        return new int[] {TokenTypes.VARIABLE_DEF};
     }
 
     @Override
@@ -263,7 +261,7 @@ public class VariableDeclarationUsageDistanceCheck extends Check {
         final DetailAST modifiers = ast.getFirstChild();
 
         if (parentType != TokenTypes.OBJBLOCK
-                && (!ignoreFinal || !modifiers.branchContains(TokenTypes.FINAL))) {
+                && (!ignoreFinal || modifiers.findFirstToken(TokenTypes.FINAL) == null)) {
             final DetailAST variable = ast.findFirstToken(TokenTypes.IDENT);
 
             if (!isVariableMatchesIgnorePattern(variable.getText())) {
@@ -329,9 +327,7 @@ public class VariableDeclarationUsageDistanceCheck extends Check {
         while (result
                 && !isUsedVariableDeclarationFound
                 && currentSiblingAst != null) {
-
             switch (currentSiblingAst.getType()) {
-
                 case TokenTypes.EXPR:
                     final DetailAST methodCallAst = currentSiblingAst.getFirstChild();
 
@@ -397,38 +393,8 @@ public class VariableDeclarationUsageDistanceCheck extends Check {
         while (!firstUsageFound && currentAst != null
                 && currentAst.getType() != TokenTypes.RCURLY) {
             if (currentAst.getFirstChild() != null) {
-
                 if (isChild(currentAst, variableIdentAst)) {
-
-                    switch (currentAst.getType()) {
-                        case TokenTypes.VARIABLE_DEF:
-                            dist++;
-                            break;
-                        case TokenTypes.SLIST:
-                            dist = 0;
-                            break;
-                        case TokenTypes.LITERAL_FOR:
-                        case TokenTypes.LITERAL_WHILE:
-                        case TokenTypes.LITERAL_DO:
-                        case TokenTypes.LITERAL_IF:
-                        case TokenTypes.LITERAL_SWITCH:
-                            if (isVariableInOperatorExpr(currentAst, variableIdentAst)) {
-                                dist++;
-                            }
-                            else {
-                                // variable usage is in inner scope
-                                // reset counters, because we can't determine distance
-                                dist = 0;
-                            }
-                            break;
-                        default:
-                            if (currentAst.branchContains(TokenTypes.SLIST)) {
-                                dist = 0;
-                            }
-                            else {
-                                dist++;
-                            }
-                    }
+                    dist = getDistToVariableUsageInChildNode(currentAst, variableIdentAst, dist);
                     variableUsageAst = currentAst;
                     firstUsageFound = true;
                 }
@@ -447,6 +413,53 @@ public class VariableDeclarationUsageDistanceCheck extends Check {
         return new SimpleEntry<>(variableUsageAst, dist);
     }
 
+    /**
+     * Returns the distance to variable usage for in the child node.
+     * @param childNode child node.
+     * @param varIdent variable variable identifier.
+     * @param currentDistToVarUsage current distance to the variable usage.
+     * @return the distance to variable usage for in the child node.
+     */
+    private static int getDistToVariableUsageInChildNode(DetailAST childNode, DetailAST varIdent,
+                                                         int currentDistToVarUsage) {
+        DetailAST examineNode = childNode;
+        if (examineNode.getType() == TokenTypes.LABELED_STAT) {
+            examineNode = examineNode.getFirstChild().getNextSibling();
+        }
+
+        int resultDist = currentDistToVarUsage;
+        switch (examineNode.getType()) {
+            case TokenTypes.VARIABLE_DEF:
+                resultDist++;
+                break;
+            case TokenTypes.SLIST:
+                resultDist = 0;
+                break;
+            case TokenTypes.LITERAL_FOR:
+            case TokenTypes.LITERAL_WHILE:
+            case TokenTypes.LITERAL_DO:
+            case TokenTypes.LITERAL_IF:
+            case TokenTypes.LITERAL_SWITCH:
+                if (isVariableInOperatorExpr(examineNode, varIdent)) {
+                    resultDist++;
+                }
+                else {
+                    // variable usage is in inner scope
+                    // reset counters, because we can't determine distance
+                    resultDist = 0;
+                }
+                break;
+            default:
+                if (examineNode.findFirstToken(TokenTypes.SLIST) == null) {
+                    resultDist++;
+                }
+                else {
+                    resultDist = 0;
+                }
+        }
+        return resultDist;
+    }
+
     /**
      * Calculates distance between declaration of variable and its first usage
      * in multiple scopes.
@@ -512,16 +525,17 @@ public class VariableDeclarationUsageDistanceCheck extends Check {
                     variableUsageAst = exprWithVariableUsage;
                 }
             }
+
+            // If there's no any variable usage, then distance = 0.
+            else if (variableUsageExpressions.isEmpty()) {
+                variableUsageAst = null;
+            }
             // If variable usage exists in different scopes, then distance =
             // distance until variable first usage.
-            else if (variableUsageExpressions.size() > 1) {
+            else {
                 dist++;
                 variableUsageAst = variableUsageExpressions.get(0);
             }
-            // If there's no any variable usage, then distance = 0.
-            else {
-                variableUsageAst = null;
-            }
         }
         return new SimpleEntry<>(variableUsageAst, dist);
     }
@@ -672,7 +686,6 @@ public class VariableDeclarationUsageDistanceCheck extends Check {
      */
     private static DetailAST getFirstNodeInsideSwitchBlock(
             DetailAST block, DetailAST variable) {
-
         DetailAST currentNode = block
                 .findFirstToken(TokenTypes.CASE_GROUP);
         final List<DetailAST> variableUsageExpressions =
@@ -784,7 +797,6 @@ public class VariableDeclarationUsageDistanceCheck extends Check {
 
         // Look if variable is in operator expression
         while (exprBetweenBrackets.getType() != TokenTypes.RPAREN) {
-
             if (isChild(exprBetweenBrackets, variable)) {
                 isVarInOperatorDeclaration = true;
                 break;
@@ -828,7 +840,6 @@ public class VariableDeclarationUsageDistanceCheck extends Check {
             DetailAST astParent = astNode.getParent();
 
             while (astParent != null) {
-
                 if (astParent.equals(parent)
                         && astParent.getLineNo() == parent.getLineNo()) {
                     isChild = true;
@@ -851,4 +862,5 @@ public class VariableDeclarationUsageDistanceCheck extends Check {
         final Matcher matcher = ignoreVariablePattern.matcher(variable);
         return matcher.matches();
     }
+
 }
