@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2017 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -24,8 +24,7 @@ import java.util.Collections;
 import java.util.Set;
 import java.util.regex.Pattern;
 
-import org.apache.commons.beanutils.ConversionException;
-
+import com.puppycrawl.tools.checkstyle.FileStatefulCheck;
 import com.puppycrawl.tools.checkstyle.api.AbstractCheck;
 import com.puppycrawl.tools.checkstyle.api.CheckstyleException;
 import com.puppycrawl.tools.checkstyle.api.DetailAST;
@@ -46,6 +45,7 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
  *
  * @author Oliver Burn
  */
+@FileStatefulCheck
 public class ImportControlCheck extends AbstractCheck implements ExternalResourceHolder {
 
     /**
@@ -72,7 +72,7 @@ public class ImportControlCheck extends AbstractCheck implements ExternalResourc
     private static final String UNABLE_TO_LOAD = "Unable to load ";
 
     /** Location of import control file. */
-    private String fileLocation;
+    private URI file;
 
     /** The filepath pattern this check applies to. */
     private Pattern path = Pattern.compile(".*");
@@ -92,28 +92,27 @@ public class ImportControlCheck extends AbstractCheck implements ExternalResourc
 
     @Override
     public int[] getDefaultTokens() {
-        return getAcceptableTokens();
+        return getRequiredTokens();
     }
 
     @Override
     public int[] getAcceptableTokens() {
-        return new int[] {TokenTypes.PACKAGE_DEF, TokenTypes.IMPORT,
-                          TokenTypes.STATIC_IMPORT, };
+        return getRequiredTokens();
     }
 
     @Override
     public int[] getRequiredTokens() {
-        return getAcceptableTokens();
+        return new int[] {TokenTypes.PACKAGE_DEF, TokenTypes.IMPORT, TokenTypes.STATIC_IMPORT, };
     }
 
     @Override
-    public void beginTree(final DetailAST rootAST) {
+    public void beginTree(DetailAST rootAST) {
         currentImportControl = null;
         processCurrentFile = path.matcher(getFileContents().getFileName()).find();
     }
 
     @Override
-    public void visitToken(final DetailAST ast) {
+    public void visitToken(DetailAST ast) {
         if (processCurrentFile) {
             if (ast.getType() == TokenTypes.PACKAGE_DEF) {
                 if (root == null) {
@@ -140,7 +139,7 @@ public class ImportControlCheck extends AbstractCheck implements ExternalResourc
 
     @Override
     public Set<String> getExternalResourceLocations() {
-        return Collections.singleton(fileLocation);
+        return Collections.singleton(file.toString());
     }
 
     /**
@@ -176,17 +175,17 @@ public class ImportControlCheck extends AbstractCheck implements ExternalResourc
      * configuration. It can also be a URL or resource in the classpath.
      * It will cause the file to be loaded.
      * @param uri the uri of the file to load.
-     * @throws ConversionException on error loading the file.
+     * @throws IllegalArgumentException on error loading the file.
      */
     public void setFile(URI uri) {
         // Handle empty param
         if (uri != null) {
             try {
                 root = ImportControlLoader.load(uri);
-                fileLocation = uri.toString();
+                file = uri;
             }
-            catch (final CheckstyleException ex) {
-                throw new ConversionException(UNABLE_TO_LOAD + uri, ex);
+            catch (CheckstyleException ex) {
+                throw new IllegalArgumentException(UNABLE_TO_LOAD + uri, ex);
             }
         }
     }
@@ -199,15 +198,4 @@ public class ImportControlCheck extends AbstractCheck implements ExternalResourc
         path = pattern;
     }
 
-    /**
-     * Set the parameter for the url containing the import control
-     * configuration. It will cause the url to be loaded.
-     * @param uri the uri of the file to load.
-     * @throws ConversionException on error loading the file.
-     * @deprecated use {@link #setFile(URI uri)} to load URLs instead
-     */
-    @Deprecated
-    public void setUrl(URI uri) {
-        setFile(uri);
-    }
 }
