@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -28,6 +28,7 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
  * @author jrichard
  */
 public class DoWhileHandler extends BlockParentHandler {
+
     /**
      * Construct an instance of this handler with the given indentation check,
      * abstract syntax tree, and parent handler.
@@ -42,17 +43,29 @@ public class DoWhileHandler extends BlockParentHandler {
     }
 
     /**
-     * Check the indentation level of the conditional expression.
+     * Check the indentation level of the while and conditional expression.
      */
-    private void checkCondExpr() {
-        final DetailAST condAst = getMainAst()
-            .findFirstToken(TokenTypes.LPAREN).getNextSibling();
+    private void checkWhileExpr() {
+        // check while statement alone
+
+        final DetailAST whileAst = getMainAst().findFirstToken(TokenTypes.DO_WHILE);
+
+        if (isOnStartOfLine(whileAst)
+                && !getIndent().isAcceptable(expandedTabsColumnNo(whileAst))) {
+            logError(whileAst, "while", expandedTabsColumnNo(whileAst));
+        }
+
+        // check condition alone
+
+        final DetailAST condAst = getMainAst().findFirstToken(TokenTypes.LPAREN).getNextSibling();
+
         checkExpressionSubtree(condAst, getIndent(), false, false);
     }
 
     @Override
     public void checkIndentation() {
         super.checkIndentation();
-        checkCondExpr();
+        checkWhileExpr();
     }
+
 }
