@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -28,6 +28,7 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
  * @author jrichard
  */
 public class ImportHandler extends AbstractExpressionHandler {
+
     /**
      * Construct an instance of this handler with the given indentation check,
      * abstract syntax tree, and parent handler.
@@ -43,12 +44,15 @@ public class ImportHandler extends AbstractExpressionHandler {
 
     @Override
     public void checkIndentation() {
-        final int lineStart = getMainAst().getLineNo();
-        final DetailAST semi = getMainAst().findFirstToken(TokenTypes.SEMI);
-        final int lineEnd = semi.getLineNo();
+        final int columnNo = expandedTabsColumnNo(getMainAst());
 
-        if (getMainAst().getLineNo() != lineEnd) {
-            checkLinesIndent(lineStart, lineEnd, getIndent());
+        if (!getIndent().isAcceptable(columnNo) && isOnStartOfLine(getMainAst())) {
+            logError(getMainAst(), "", columnNo);
         }
+
+        final DetailAST semi = getMainAst().findFirstToken(TokenTypes.SEMI);
+
+        checkWrappingIndentation(getMainAst(), semi);
     }
+
 }
