@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -28,6 +28,7 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
  * @author o_sukhodolsky
  */
 public class MemberDefHandler extends AbstractExpressionHandler {
+
     /**
      * Construct an instance of this handler with the given indentation check,
      * abstract syntax tree, and parent handler.
@@ -50,11 +51,11 @@ public class MemberDefHandler extends AbstractExpressionHandler {
         else {
             checkModifiers();
         }
-        final LineWrappingHandler lineWrap =
-            new LineWrappingHandler(getIndentCheck(), getMainAst(),
-                getVarDefStatementSemicolon(getMainAst()));
-        if (lineWrap.getLastNode() != null && !isArrayDeclaration(getMainAst())) {
-            lineWrap.checkIndentation();
+        final DetailAST firstNode = getMainAst();
+        final DetailAST lastNode = getVarDefStatementSemicolon(firstNode);
+
+        if (lastNode != null && !isArrayDeclaration(firstNode)) {
+            checkWrappingIndentation(firstNode, lastNode);
         }
     }
 
@@ -107,4 +108,5 @@ public class MemberDefHandler extends AbstractExpressionHandler {
         }
         return lastNode;
     }
+
 }
