@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -21,7 +21,8 @@ package com.puppycrawl.tools.checkstyle.checks.naming;
 
 import java.util.regex.Pattern;
 
-import com.puppycrawl.tools.checkstyle.api.Check;
+import com.puppycrawl.tools.checkstyle.StatelessCheck;
+import com.puppycrawl.tools.checkstyle.api.AbstractCheck;
 import com.puppycrawl.tools.checkstyle.api.DetailAST;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
 import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
@@ -31,25 +32,24 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
  *
  * @author Rick Giles
  */
+@StatelessCheck
 public abstract class AbstractNameCheck
-    extends Check {
+    extends AbstractCheck {
+
     /**
      * Message key for invalid pattern error.
      */
     public static final String MSG_INVALID_PATTERN = "name.invalidPattern";
 
-    /** The format string of the regexp. */
-    private String format;
-
     /** The regexp to match against. */
-    private Pattern regexp;
+    private Pattern format;
 
     /**
      * Creates a new {@code AbstractNameCheck} instance.
      * @param format format to check with
      */
     protected AbstractNameCheck(String format) {
-        setFormat(format);
+        this.format = CommonUtils.createPattern(format);
     }
 
     /**
@@ -62,26 +62,25 @@ public abstract class AbstractNameCheck
     protected abstract boolean mustCheckName(DetailAST ast);
 
     /**
-     * Set the format to the specified regular expression.
-     * @param format a {@code String} value
-     * @throws org.apache.commons.beanutils.ConversionException unable to parse format
+     * Set the format for the specified regular expression.
+     * @param pattern the new pattern
      */
-    public final void setFormat(String format) {
-        this.format = format;
-        regexp = CommonUtils.createPattern(format);
+    public final void setFormat(Pattern pattern) {
+        format = pattern;
     }
 
     @Override
     public void visitToken(DetailAST ast) {
         if (mustCheckName(ast)) {
             final DetailAST nameAST = ast.findFirstToken(TokenTypes.IDENT);
-            if (!regexp.matcher(nameAST.getText()).find()) {
+            if (!format.matcher(nameAST.getText()).find()) {
                 log(nameAST.getLineNo(),
                     nameAST.getColumnNo(),
                     MSG_INVALID_PATTERN,
                     nameAST.getText(),
-                    format);
+                    format.pattern());
             }
         }
     }
+
 }
