@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2017 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -19,14 +19,16 @@
 
 package com.puppycrawl.tools.checkstyle.checks.regexp;
 
-import java.util.List;
 import java.util.regex.Matcher;
 
+import com.puppycrawl.tools.checkstyle.api.FileText;
+
 /**
  * A detector that matches individual lines.
  * @author oliver
  */
 class SinglelineDetector {
+
     /**
      * A key is pointing to the warning message text in "messages.properties"
      * file.
@@ -54,12 +56,13 @@ class SinglelineDetector {
 
     /**
      * Processes a set of lines looking for matches.
-     * @param lines the lines to process.
+     * @param fileText {@link FileText} object contains the lines to process.
      */
-    public void processLines(List<String> lines) {
+    public void processLines(FileText fileText) {
         resetState();
         int lineNo = 0;
-        for (String line : lines) {
+        for (int index = 0; index < fileText.size(); index++) {
+            final String line = fileText.get(index);
             lineNo++;
             checkLine(lineNo, line, options.getPattern().matcher(line), 0);
         }
@@ -106,10 +109,7 @@ class SinglelineDetector {
             // So we need to use (endCol - 1) here.
             if (options.getSuppressor()
                     .shouldSuppress(lineNo, startCol, lineNo, endCol - 1)) {
-                if (endCol < line.length()) {
-                    // check if the expression is on the rest of the line
-                    checkLine(lineNo, line, matcher, endCol);
-                }
+                checkLine(lineNo, line, matcher, endCol);
             }
             else {
                 currentMatches++;
@@ -125,4 +125,5 @@ class SinglelineDetector {
             }
         }
     }
+
 }
