@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2017 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -19,6 +19,7 @@
 
 package com.puppycrawl.tools.checkstyle.checks.sizes;
 
+import com.puppycrawl.tools.checkstyle.StatelessCheck;
 import com.puppycrawl.tools.checkstyle.api.AbstractCheck;
 import com.puppycrawl.tools.checkstyle.api.DetailAST;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
@@ -56,6 +57,7 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
  *
  * @author Rob Worth
  */
+@StatelessCheck
 public class AnonInnerLengthCheck extends AbstractCheck {
 
     /**
@@ -72,17 +74,17 @@ public class AnonInnerLengthCheck extends AbstractCheck {
 
     @Override
     public int[] getDefaultTokens() {
-        return getAcceptableTokens();
+        return getRequiredTokens();
     }
 
     @Override
     public int[] getAcceptableTokens() {
-        return new int[] {TokenTypes.LITERAL_NEW};
+        return getRequiredTokens();
     }
 
     @Override
     public int[] getRequiredTokens() {
-        return getAcceptableTokens();
+        return new int[] {TokenTypes.LITERAL_NEW};
     }
 
     @Override
@@ -101,9 +103,11 @@ public class AnonInnerLengthCheck extends AbstractCheck {
     }
 
     /**
+     * Sets maximum length of an anonymous inner class.
      * @param length the maximum length of an anonymous inner class.
      */
     public void setMax(int length) {
         max = length;
     }
+
 }
