@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2017 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -19,9 +19,11 @@
 
 package com.puppycrawl.tools.checkstyle.checks.whitespace;
 
+import com.puppycrawl.tools.checkstyle.StatelessCheck;
 import com.puppycrawl.tools.checkstyle.api.AbstractCheck;
 import com.puppycrawl.tools.checkstyle.api.DetailAST;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
+import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
 
 /**
  * <p>
@@ -33,6 +35,7 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
  * </p>
   * <p> By default the check will check the following operators:
  *  {@link TokenTypes#ARRAY_INIT ARRAY_INIT},
+ *  {@link TokenTypes#AT AT},
  *  {@link TokenTypes#BNOT BNOT},
  *  {@link TokenTypes#DEC DEC},
  *  {@link TokenTypes#DOT DOT},
@@ -50,6 +53,9 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
  * {@link TokenTypes#INDEX_OP INDEX_OP}
  * specially from other tokens. Actually it is checked that there is
  * no whitespace before this tokens, not after them.
+ * Spaces after the {@link TokenTypes#ANNOTATIONS ANNOTATIONS}
+ * before {@link TokenTypes#ARRAY_DECLARATOR ARRAY_DECLARATOR}
+ * and {@link TokenTypes#INDEX_OP INDEX_OP} will be ignored.
  * </p>
  * <p>
  * An example of how to configure the check is:
@@ -66,11 +72,18 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
  *     &lt;property name="allowLineBreaks" value="false"/&gt;
  * &lt;/module&gt;
  * </pre>
+ * <p>
+ * If the annotation is between the type and the array, the check will skip validation for spaces:
+ * </p>
+ * <pre>
+ * public void foo(final char @NotNull [] param) {} // No violation
+ * </pre>
  * @author Rick Giles
  * @author lkuehne
  * @author <a href="mailto:nesterenko-aleksey@list.ru">Aleksey Nesterenko</a>
  * @author attatrol
  */
+@StatelessCheck
 public class NoWhitespaceAfterCheck extends AbstractCheck {
 
     /**
@@ -86,6 +99,7 @@ public class NoWhitespaceAfterCheck extends AbstractCheck {
     public int[] getDefaultTokens() {
         return new int[] {
             TokenTypes.ARRAY_INIT,
+            TokenTypes.AT,
             TokenTypes.INC,
             TokenTypes.DEC,
             TokenTypes.UNARY_MINUS,
@@ -102,6 +116,7 @@ public class NoWhitespaceAfterCheck extends AbstractCheck {
     public int[] getAcceptableTokens() {
         return new int[] {
             TokenTypes.ARRAY_INIT,
+            TokenTypes.AT,
             TokenTypes.INC,
             TokenTypes.DEC,
             TokenTypes.UNARY_MINUS,
@@ -113,9 +128,15 @@ public class NoWhitespaceAfterCheck extends AbstractCheck {
             TokenTypes.ARRAY_DECLARATOR,
             TokenTypes.INDEX_OP,
             TokenTypes.LITERAL_SYNCHRONIZED,
+            TokenTypes.METHOD_REF,
         };
     }
 
+    @Override
+    public int[] getRequiredTokens() {
+        return CommonUtils.EMPTY_INT_ARRAY;
+    }
+
     /**
      * Control whether whitespace is flagged at linebreaks.
      * @param allowLineBreaks whether whitespace should be
@@ -129,12 +150,15 @@ public class NoWhitespaceAfterCheck extends AbstractCheck {
     public void visitToken(DetailAST ast) {
         final DetailAST whitespaceFollowedAst = getWhitespaceFollowedNode(ast);
 
-        final int whitespaceColumnNo = getPositionAfter(whitespaceFollowedAst);
-        final int whitespaceLineNo = whitespaceFollowedAst.getLineNo();
+        if (whitespaceFollowedAst.getNextSibling() == null
+                || whitespaceFollowedAst.getNextSibling().getType() != TokenTypes.ANNOTATIONS) {
+            final int whitespaceColumnNo = getPositionAfter(whitespaceFollowedAst);
+            final int whitespaceLineNo = whitespaceFollowedAst.getLineNo();
 
-        if (hasTrailingWhitespace(ast, whitespaceColumnNo, whitespaceLineNo)) {
-            log(whitespaceLineNo, whitespaceColumnNo,
-                MSG_KEY, whitespaceFollowedAst.getText());
+            if (hasTrailingWhitespace(ast, whitespaceColumnNo, whitespaceLineNo)) {
+                log(whitespaceLineNo, whitespaceColumnNo,
+                        MSG_KEY, whitespaceFollowedAst.getText());
+            }
         }
     }
 
@@ -263,7 +287,7 @@ public class NoWhitespaceAfterCheck extends AbstractCheck {
                     }
                     break;
                 default:
-                    throw new IllegalStateException("unexpected ast syntax" + parent);
+                    throw new IllegalStateException("unexpected ast syntax " + parent);
             }
         }
         return previousElement;
@@ -287,8 +311,16 @@ public class NoWhitespaceAfterCheck extends AbstractCheck {
         else {
             final DetailAST ident = getIdentLastToken(ast);
             if (ident == null) {
+                final DetailAST rparen = ast.findFirstToken(TokenTypes.RPAREN);
+                // construction like new int[]{1}[0]
+                if (rparen == null) {
+                    final DetailAST lastChild = firstChild.getLastChild();
+                    result = lastChild.findFirstToken(TokenTypes.RCURLY);
+                }
                 // construction like ((byte[]) pixels)[0]
-                result = ast.findFirstToken(TokenTypes.RPAREN);
+                else {
+                    result = rparen;
+                }
             }
             else {
                 result = ident;
@@ -358,8 +390,12 @@ public class NoWhitespaceAfterCheck extends AbstractCheck {
         }
         //ident and lastTypeNode lay on one line
         else {
-            if (ident.getColumnNo() > ast.getColumnNo()
-                || lastTypeNode.getColumnNo() > ident.getColumnNo()) {
+            final int instanceOfSize = 13;
+            // +2 because ast has `[]` after the ident
+            if (ident.getColumnNo() >= ast.getColumnNo() + 2
+                // +13 because ident (at most 1 character) is followed by
+                // ' instanceof ' (12 characters)
+                || lastTypeNode.getColumnNo() >= ident.getColumnNo() + instanceOfSize) {
                 previousElement = lastTypeNode;
             }
             else {
