@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2017 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -19,6 +19,7 @@
 
 package com.puppycrawl.tools.checkstyle.checks.whitespace;
 
+import com.puppycrawl.tools.checkstyle.StatelessCheck;
 import com.puppycrawl.tools.checkstyle.api.AbstractCheck;
 import com.puppycrawl.tools.checkstyle.api.DetailAST;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
@@ -30,12 +31,15 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
  * More specifically, it checks that it is not preceded with whitespace,
  * or (if line breaks are allowed) all characters on the line before are
  * whitespace. To allow line breaks before a token, set property
- * allowLineBreaks to true.
+ * allowLineBreaks to true. No check occurs before semi-colons in empty
+ * for loop initializers or conditions.
  * </p>
  * <p> By default the check will check the following operators:
+ *  {@link TokenTypes#COMMA COMMA},
  *  {@link TokenTypes#SEMI SEMI},
  *  {@link TokenTypes#POST_DEC POST_DEC},
- *  {@link TokenTypes#POST_INC POST_INC}.
+ *  {@link TokenTypes#POST_INC POST_INC},
+ *  {@link TokenTypes#ELLIPSIS ELLIPSIS}.
  * {@link TokenTypes#DOT DOT} is also an acceptable token in a configuration
  * of this check.
  * </p>
@@ -58,6 +62,7 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
  * @author Rick Giles
  * @author lkuehne
  */
+@StatelessCheck
 public class NoWhitespaceBeforeCheck
     extends AbstractCheck {
 
@@ -77,6 +82,7 @@ public class NoWhitespaceBeforeCheck
             TokenTypes.SEMI,
             TokenTypes.POST_INC,
             TokenTypes.POST_DEC,
+            TokenTypes.ELLIPSIS,
         };
     }
 
@@ -90,6 +96,8 @@ public class NoWhitespaceBeforeCheck
             TokenTypes.DOT,
             TokenTypes.GENERIC_START,
             TokenTypes.GENERIC_END,
+            TokenTypes.ELLIPSIS,
+            TokenTypes.METHOD_REF,
         };
     }
 
@@ -103,14 +111,14 @@ public class NoWhitespaceBeforeCheck
         final String line = getLine(ast.getLineNo() - 1);
         final int before = ast.getColumnNo() - 1;
 
-        if ((before < 0 || Character.isWhitespace(line.charAt(before)))
-                && !isInEmptyForInitializer(ast)) {
-
+        if ((before == -1 || Character.isWhitespace(line.charAt(before)))
+                && !isInEmptyForInitializerOrCondition(ast)) {
             boolean flag = !allowLineBreaks;
             // verify all characters before '.' are whitespace
-            for (int i = 0; !flag && i < before; i++) {
+            for (int i = 0; !flag && i <= before - 1; i++) {
                 if (!Character.isWhitespace(line.charAt(i))) {
                     flag = true;
+                    break;
                 }
             }
             if (flag) {
@@ -120,16 +128,17 @@ public class NoWhitespaceBeforeCheck
     }
 
     /**
-     * Checks that semicolon is in empty for initializer.
+     * Checks that semicolon is in empty for initializer or condition.
      * @param semicolonAst DetailAST of semicolon.
-     * @return true if semicolon is in empty for initializer.
+     * @return true if semicolon is in empty for initializer or condition.
      */
-    private static boolean isInEmptyForInitializer(DetailAST semicolonAst) {
+    private static boolean isInEmptyForInitializerOrCondition(DetailAST semicolonAst) {
         boolean result = false;
         if (semicolonAst.getType() == TokenTypes.SEMI) {
             final DetailAST sibling = semicolonAst.getPreviousSibling();
             if (sibling != null
-                    && sibling.getType() == TokenTypes.FOR_INIT
+                    && (sibling.getType() == TokenTypes.FOR_INIT
+                            || sibling.getType() == TokenTypes.FOR_CONDITION)
                     && sibling.getChildCount() == 0) {
                 result = true;
             }
@@ -145,4 +154,5 @@ public class NoWhitespaceBeforeCheck
     public void setAllowLineBreaks(boolean allowLineBreaks) {
         this.allowLineBreaks = allowLineBreaks;
     }
+
 }
