@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2017 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -24,7 +24,6 @@ import java.util.regex.Pattern;
 
 import com.puppycrawl.tools.checkstyle.api.AuditEvent;
 import com.puppycrawl.tools.checkstyle.api.Filter;
-import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
 
 /**
  * This filter processes {@link AuditEvent}
@@ -41,6 +40,7 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
  */
 public class SuppressElement
     implements Filter {
+
     /** The regexp to match file names against. */
     private final Pattern fileRegexp;
 
@@ -48,60 +48,67 @@ public class SuppressElement
     private final String filePattern;
 
     /** The regexp to match check names against. */
-    private Pattern checkRegexp;
+    private final Pattern checkRegexp;
 
     /** The pattern for check class names. */
-    private String checkPattern;
+    private final String checkPattern;
+
+    /** The regexp to match message names against. */
+    private final Pattern messageRegexp;
+
+    /** The pattern for message names. */
+    private final String messagePattern;
 
     /** Module id filter. */
-    private String moduleId;
+    private final String moduleId;
 
     /** Line number filter. */
-    private CsvFilter lineFilter;
+    private final CsvFilter lineFilter;
 
     /** CSV for line number filter. */
-    private String linesCsv;
+    private final String linesCsv;
 
     /** Column number filter. */
-    private CsvFilter columnFilter;
+    private final CsvFilter columnFilter;
 
     /** CSV for column number filter. */
-    private String columnsCsv;
+    private final String columnsCsv;
 
     /**
      * Constructs a {@code SuppressElement} for a
-     * file name pattern. Must either call {@link #setColumns(String)} or
-     * {@link #setModuleId(String)} before using this object.
-     * @param files regular expression for names of filtered files.
+     * file name pattern.
+     *
+     * @param files   regular expression for names of filtered files.
+     * @param checks  regular expression for filtered check classes.
+     * @param message regular expression for messages.
+     * @param modId   the id
+     * @param lines   lines CSV values and ranges for line number filtering.
+     * @param columns columns CSV values and ranges for column number filtering.
      */
-    public SuppressElement(String files) {
+    public SuppressElement(String files, String checks,
+                           String message, String modId, String lines, String columns) {
         filePattern = files;
-        fileRegexp = Pattern.compile(files);
-    }
-
-    /**
-     * Set the check class pattern.
-     * @param checks regular expression for filtered check classes.
-     */
-    public void setChecks(final String checks) {
+        if (files == null) {
+            fileRegexp = null;
+        }
+        else {
+            fileRegexp = Pattern.compile(files);
+        }
         checkPattern = checks;
-        checkRegexp = CommonUtils.createPattern(checks);
-    }
-
-    /**
-     * Set the module id for filtering. Cannot be null.
-     * @param moduleId the id
-     */
-    public void setModuleId(final String moduleId) {
-        this.moduleId = moduleId;
-    }
-
-    /**
-     * Sets the CSV values and ranges for line number filtering.
-     * E.g. "1,7-15,18".
-     * @param lines CSV values and ranges for line number filtering.
-     */
-    public void setLines(String lines) {
+        if (checks == null) {
+            checkRegexp = null;
+        }
+        else {
+            checkRegexp = Pattern.compile(checks);
+        }
+        messagePattern = message;
+        if (message == null) {
+            messageRegexp = null;
+        }
+        else {
+            messageRegexp = Pattern.compile(message);
+        }
+        moduleId = modId;
         linesCsv = lines;
         if (lines == null) {
             lineFilter = null;
@@ -109,14 +116,6 @@ public class SuppressElement
         else {
             lineFilter = new CsvFilter(lines);
         }
-    }
-
-    /**
-     * Sets the CSV values and ranges for column number filtering.
-     *  E.g. "1,7-15,18".
-     * @param columns CSV values and ranges for column number filtering.
-     */
-    public void setColumns(String columns) {
         columnsCsv = columns;
         if (columns == null) {
             columnFilter = null;
@@ -128,15 +127,9 @@ public class SuppressElement
 
     @Override
     public boolean accept(AuditEvent event) {
-        // reject if file or check module mismatch?
-        if (isFileNameAndModuleNotMatching(event)) {
-            return true;
-        }
-
-        // reject if no line/column matching
-        return (lineFilter != null || columnFilter != null)
-                && (lineFilter == null || !lineFilter.accept(event.getLine()))
-                && (columnFilter == null || !columnFilter.accept(event.getColumn()));
+        return isFileNameAndModuleNotMatching(event)
+                || !isMessageNameMatching(event)
+                || isLineAndColumnMatch(event);
     }
 
     /**
@@ -146,15 +139,36 @@ public class SuppressElement
      */
     private boolean isFileNameAndModuleNotMatching(AuditEvent event) {
         return event.getFileName() == null
-                || !fileRegexp.matcher(event.getFileName()).find()
+                || fileRegexp != null && !fileRegexp.matcher(event.getFileName()).find()
                 || event.getLocalizedMessage() == null
                 || moduleId != null && !moduleId.equals(event.getModuleId())
                 || checkRegexp != null && !checkRegexp.matcher(event.getSourceName()).find();
     }
 
+    /**
+     * Is matching by message.
+     * @param event event
+     * @return true is matching or not set.
+     */
+    private boolean isMessageNameMatching(AuditEvent event) {
+        return messageRegexp == null || messageRegexp.matcher(event.getMessage()).find();
+    }
+
+    /**
+     * Whether line and column match.
+     * @param event event to process.
+     * @return true if line and column match.
+     */
+    private boolean isLineAndColumnMatch(AuditEvent event) {
+        return (lineFilter != null || columnFilter != null)
+                && (lineFilter == null || !lineFilter.accept(event.getLine()))
+                && (columnFilter == null || !columnFilter.accept(event.getColumn()));
+    }
+
     @Override
     public int hashCode() {
-        return Objects.hash(filePattern, checkPattern, moduleId, linesCsv, columnsCsv);
+        return Objects.hash(filePattern, checkPattern, messagePattern, moduleId, linesCsv,
+                columnsCsv);
     }
 
     @Override
@@ -168,8 +182,10 @@ public class SuppressElement
         final SuppressElement suppressElement = (SuppressElement) other;
         return Objects.equals(filePattern, suppressElement.filePattern)
                 && Objects.equals(checkPattern, suppressElement.checkPattern)
+                && Objects.equals(messagePattern, suppressElement.messagePattern)
                 && Objects.equals(moduleId, suppressElement.moduleId)
                 && Objects.equals(linesCsv, suppressElement.linesCsv)
                 && Objects.equals(columnsCsv, suppressElement.columnsCsv);
     }
+
 }
