@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2016 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -41,19 +41,17 @@ public final class Main {
      * @param args the command line arguments.
      */
     public static void main(final String... args) {
-        SwingUtilities.invokeLater(new Runnable() {
-            @Override
-            public void run() {
-                final MainFrame mainFrame = new MainFrame();
+        SwingUtilities.invokeLater(() -> {
+            final MainFrame mainFrame = new MainFrame();
 
-                if (args.length > 0) {
-                    final File sourceFile = new File(args[0]);
-                    mainFrame.openFile(sourceFile);
-                }
-                mainFrame.setTitle("Checkstyle");
-                mainFrame.setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);
-                mainFrame.setVisible(true);
+            if (args.length > 0) {
+                final File sourceFile = new File(args[0]);
+                mainFrame.openFile(sourceFile);
             }
+            mainFrame.setTitle("Checkstyle GUI");
+            mainFrame.setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);
+            mainFrame.setVisible(true);
         });
     }
+
 }
