@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2017 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -21,16 +21,15 @@ package com.puppycrawl.tools.checkstyle.gui;
 
 import java.io.File;
 import java.io.IOException;
+import java.nio.charset.StandardCharsets;
 import java.util.ArrayList;
-import java.util.Collections;
 import java.util.List;
 import java.util.Locale;
 
-import antlr.ANTLRException;
-import com.puppycrawl.tools.checkstyle.TreeWalker;
+import com.google.common.collect.ImmutableList;
+import com.puppycrawl.tools.checkstyle.JavaParser;
 import com.puppycrawl.tools.checkstyle.api.CheckstyleException;
 import com.puppycrawl.tools.checkstyle.api.DetailAST;
-import com.puppycrawl.tools.checkstyle.api.FileContents;
 import com.puppycrawl.tools.checkstyle.api.FileText;
 
 /**
@@ -73,14 +72,15 @@ public class MainFrameModel {
         public String toString() {
             return description;
         }
-    }
 
-    /** Lines to position map. */
-    private final List<Integer> linesToPosition = new ArrayList<>();
+    }
 
     /** Parse tree model. */
     private final ParseTreeTableModel parseTreeTableModel;
 
+    /** Lines to position map. */
+    private ImmutableList<Integer> linesToPosition = ImmutableList.of();
+
     /** Current mode. */
     private ParseMode parseMode = ParseMode.PLAIN_JAVA;
 
@@ -126,6 +126,7 @@ public class MainFrameModel {
     }
 
     /**
+     * Returns title for the main frame.
      * @return title for the main frame.
      */
     public String getTitle() {
@@ -133,6 +134,7 @@ public class MainFrameModel {
     }
 
     /**
+     * Returns true if the reload action is enabled, false otherwise.
      * @return true if the reload action is enabled.
      */
     public boolean isReloadActionEnabled() {
@@ -170,11 +172,14 @@ public class MainFrameModel {
 
     /**
      * Get lines to position map.
+     * It returns unmodifiable collection to
+     * prevent additional overhead of copying
+     * and possible state modifications.
      * @return lines to position map.
+     * @noinspection ReturnOfCollectionOrArrayField
      */
-    public List<Integer> getLinesToPosition() {
-        final List<Integer> copy = new ArrayList<>(linesToPosition);
-        return Collections.unmodifiableList(copy);
+    public ImmutableList<Integer> getLinesToPosition() {
+        return linesToPosition;
     }
 
     /**
@@ -192,11 +197,11 @@ public class MainFrameModel {
 
                 switch (parseMode) {
                     case PLAIN_JAVA:
-                        parseTree = parseFile(file);
+                        parseTree = JavaParser.parseFile(file, JavaParser.Options.WITHOUT_COMMENTS);
                         break;
                     case JAVA_WITH_COMMENTS:
                     case JAVA_WITH_JAVADOC_AND_COMMENTS:
-                        parseTree = parseFileWithComments(file);
+                        parseTree = JavaParser.parseFile(file, JavaParser.Options.WITH_COMMENTS);
                         break;
                     default:
                         throw new IllegalArgumentException("Unknown mode: " + parseMode);
@@ -206,20 +211,20 @@ public class MainFrameModel {
                 parseTreeTableModel.setParseMode(parseMode);
                 final String[] sourceLines = getFileText(file).toLinesArray();
 
-                // clear for each new file
-                linesToPosition.clear();
+                final List<Integer> linesToPositionTemp = new ArrayList<>();
                 // starts line counting at 1
-                linesToPosition.add(0);
+                linesToPositionTemp.add(0);
 
-                final StringBuilder sb = new StringBuilder();
+                final StringBuilder sb = new StringBuilder(1024);
                 // insert the contents of the file to the text area
                 for (final String element : sourceLines) {
-                    linesToPosition.add(sb.length());
+                    linesToPositionTemp.add(sb.length());
                     sb.append(element).append(System.lineSeparator());
                 }
+                linesToPosition = ImmutableList.copyOf(linesToPositionTemp);
                 text = sb.toString();
             }
-            catch (IOException | ANTLRException ex) {
+            catch (IOException ex) {
                 final String exceptionMsg = String.format(Locale.ROOT,
                     "%s occurred while opening file %s.",
                     ex.getClass().getSimpleName(), file.getPath());
@@ -228,40 +233,15 @@ public class MainFrameModel {
         }
     }
 
-    /**
-     * Parse a file and return the parse tree.
-     * @param file the file to parse.
-     * @return the root node of the parse tree.
-     * @throws IOException if the file could not be read.
-     * @throws ANTLRException if the file is not a Java source.
-     */
-    public DetailAST parseFile(File file) throws IOException, ANTLRException {
-        final FileText fileText = getFileText(file);
-        final FileContents contents = new FileContents(fileText);
-        return TreeWalker.parse(contents);
-    }
-
-    /**
-     * Parse a file and return the parse tree with comment nodes.
-     * @param file the file to parse.
-     * @return the root node of the parse tree.
-     * @throws IOException if the file could not be read.
-     * @throws ANTLRException if the file is not a Java source.
-     */
-    public DetailAST parseFileWithComments(File file) throws IOException, ANTLRException {
-        final FileText fileText = getFileText(file);
-        final FileContents contents = new FileContents(fileText);
-        return TreeWalker.parseWithComments(contents);
-    }
-
     /**
      * Get FileText from a file.
      * @param file the file to get the FileText from.
      * @return the FileText.
      * @throws IOException if the file could not be read.
      */
-    public FileText getFileText(File file) throws IOException {
+    private static FileText getFileText(File file) throws IOException {
         return new FileText(file.getAbsoluteFile(),
-                System.getProperty("file.encoding", "UTF-8"));
+                System.getProperty("file.encoding", StandardCharsets.UTF_8.name()));
     }
+
 }
