@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2017 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -21,25 +21,23 @@ package com.puppycrawl.tools.checkstyle.checks;
 
 import static com.puppycrawl.tools.checkstyle.checks.FinalParametersCheck.MSG_KEY;
 
-import java.io.File;
-import java.io.IOException;
-
 import org.junit.Test;
 
-import com.puppycrawl.tools.checkstyle.BaseCheckTestSupport;
+import com.puppycrawl.tools.checkstyle.AbstractModuleTestSupport;
 import com.puppycrawl.tools.checkstyle.DefaultConfiguration;
 import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
 
-public class FinalParametersCheckTest extends BaseCheckTestSupport {
+public class FinalParametersCheckTest extends AbstractModuleTestSupport {
+
     @Override
-    protected String getPath(String filename) throws IOException {
-        return super.getPath("checks" + File.separator + filename);
+    protected String getPackageLocation() {
+        return "com/puppycrawl/tools/checkstyle/checks/finalparameters";
     }
 
     @Test
     public void testDefaultTokens() throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(FinalParametersCheck.class);
+            createModuleConfig(FinalParametersCheck.class);
         final String[] expected = {
             "23:26: " + getCheckMessage(MSG_KEY, "s"),
             "38:26: " + getCheckMessage(MSG_KEY, "i"),
@@ -59,7 +57,7 @@ public class FinalParametersCheckTest extends BaseCheckTestSupport {
     @Test
     public void testCtorToken() throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(FinalParametersCheck.class);
+            createModuleConfig(FinalParametersCheck.class);
         checkConfig.addAttribute("tokens", "CTOR_DEF");
         final String[] expected = {
             "23:26: " + getCheckMessage(MSG_KEY, "s"),
@@ -72,7 +70,7 @@ public class FinalParametersCheckTest extends BaseCheckTestSupport {
     @Test
     public void testMethodToken() throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(FinalParametersCheck.class);
+            createModuleConfig(FinalParametersCheck.class);
         checkConfig.addAttribute("tokens", "METHOD_DEF");
         final String[] expected = {
             "53:17: " + getCheckMessage(MSG_KEY, "s"),
@@ -90,7 +88,7 @@ public class FinalParametersCheckTest extends BaseCheckTestSupport {
     @Test
     public void testCatchToken() throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(FinalParametersCheck.class);
+            createModuleConfig(FinalParametersCheck.class);
         checkConfig.addAttribute("tokens", "LITERAL_CATCH");
         final String[] expected = {
             "125:16: " + getCheckMessage(MSG_KEY, "npe"),
@@ -103,7 +101,7 @@ public class FinalParametersCheckTest extends BaseCheckTestSupport {
     @Test
     public void testForEachClauseToken() throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(FinalParametersCheck.class);
+            createModuleConfig(FinalParametersCheck.class);
         checkConfig.addAttribute("tokens", "FOR_EACH_CLAUSE");
         final String[] expected = {
             "152:13: " + getCheckMessage(MSG_KEY, "s"),
@@ -115,7 +113,7 @@ public class FinalParametersCheckTest extends BaseCheckTestSupport {
     @Test
     public void testIgnorePrimitiveTypesParameters() throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(FinalParametersCheck.class);
+            createModuleConfig(FinalParametersCheck.class);
         checkConfig.addAttribute("ignorePrimitiveTypes", "true");
         final String[] expected = {
             "6:22: " + getCheckMessage(MSG_KEY, "k"),
@@ -130,10 +128,11 @@ public class FinalParametersCheckTest extends BaseCheckTestSupport {
     }
 
     @Test
-    public void testRecieverParameters() throws Exception {
+    public void testReceiverParameters() throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(FinalParametersCheck.class);
+            createModuleConfig(FinalParametersCheck.class);
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
         verify(checkConfig, getPath("InputFinalParametersReceiver.java"), expected);
     }
+
 }
