@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2017 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -20,45 +20,72 @@
 package com.puppycrawl.tools.checkstyle.checks;
 
 import static com.puppycrawl.tools.checkstyle.checks.TranslationCheck.MSG_KEY;
+import static com.puppycrawl.tools.checkstyle.checks.TranslationCheck.MSG_KEY_MISSING_TRANSLATION_FILE;
 import static org.hamcrest.CoreMatchers.containsString;
 import static org.hamcrest.CoreMatchers.endsWith;
+import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertThat;
+import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
+import static org.mockito.Matchers.any;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.times;
+import static org.powermock.api.mockito.PowerMockito.doNothing;
+import static org.powermock.api.mockito.PowerMockito.mockStatic;
+import static org.powermock.api.mockito.PowerMockito.verifyStatic;
 
+import java.io.ByteArrayOutputStream;
 import java.io.File;
+import java.io.FileInputStream;
 import java.io.IOException;
+import java.io.InputStream;
+import java.lang.reflect.Field;
 import java.lang.reflect.Method;
+import java.nio.charset.StandardCharsets;
+import java.util.Collection;
+import java.util.Collections;
+import java.util.Set;
+import java.util.SortedSet;
 
 import org.junit.Test;
+import org.junit.runner.RunWith;
+import org.mockito.ArgumentCaptor;
+import org.mockito.Captor;
+import org.mockito.Mockito;
+import org.powermock.core.classloader.annotations.PrepareForTest;
+import org.powermock.modules.junit4.PowerMockRunner;
 
-import com.puppycrawl.tools.checkstyle.BaseCheckTestSupport;
+import com.google.common.collect.ImmutableMap;
+import com.google.common.io.Closeables;
+import com.puppycrawl.tools.checkstyle.AbstractXmlTestSupport;
 import com.puppycrawl.tools.checkstyle.Checker;
 import com.puppycrawl.tools.checkstyle.DefaultConfiguration;
+import com.puppycrawl.tools.checkstyle.XMLLogger;
+import com.puppycrawl.tools.checkstyle.api.AutomaticBean;
 import com.puppycrawl.tools.checkstyle.api.Configuration;
+import com.puppycrawl.tools.checkstyle.api.FileText;
+import com.puppycrawl.tools.checkstyle.api.LocalizedMessage;
+import com.puppycrawl.tools.checkstyle.api.MessageDispatcher;
+import com.puppycrawl.tools.checkstyle.api.SeverityLevel;
+import com.puppycrawl.tools.checkstyle.api.SeverityLevelCounter;
+import com.puppycrawl.tools.checkstyle.internal.utils.XmlUtil;
 import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
 
-public class TranslationCheckTest extends BaseCheckTestSupport {
-    @Override
-    protected DefaultConfiguration createCheckerConfig(
-        Configuration config) {
-        final DefaultConfiguration dc = new DefaultConfiguration("root");
-        dc.addChild(config);
-        return dc;
-    }
+@RunWith(PowerMockRunner.class)
+@PrepareForTest(Closeables.class)
+public class TranslationCheckTest extends AbstractXmlTestSupport {
+
+    @Captor
+    private ArgumentCaptor<SortedSet<LocalizedMessage>> captor;
 
     @Override
-    protected String getPath(String filename) throws IOException {
-        return super.getPath("checks" + File.separator + filename);
-    }
-
-    @Override
-    protected String getNonCompilablePath(String filename) throws IOException {
-        return super.getNonCompilablePath("checks" + File.separator + filename);
+    protected String getPackageLocation() {
+        return "com/puppycrawl/tools/checkstyle/checks/translation";
     }
 
     @Test
     public void testTranslation() throws Exception {
-        final Configuration checkConfig = createCheckConfig(TranslationCheck.class);
+        final Configuration checkConfig = createModuleConfig(TranslationCheck.class);
         final String[] expected = {
             "0: " + getCheckMessage(MSG_KEY, "only.english"),
         };
@@ -73,9 +100,91 @@ public class TranslationCheckTest extends BaseCheckTestSupport {
             expected);
     }
 
+    /**
+     * Even when we pass several files to AbstractModuleTestSupport#verify,
+     * the check processes it during one run, so we cannot reproduce situation
+     * when TranslationCheck#beginProcessing called several times during single run.
+     * So, we have to use reflection to check this particular case.
+     *
+     * @throws Exception when code tested throws exception
+     */
+    @Test
+    @SuppressWarnings("unchecked")
+    public void testStateIsCleared() throws Exception {
+        final File fileToProcess = new File(
+                getPath("InputTranslationCheckFireErrors_de.properties")
+        );
+        final String charset = StandardCharsets.UTF_8.name();
+        final TranslationCheck check = new TranslationCheck();
+        check.beginProcessing(charset);
+        check.processFiltered(fileToProcess, new FileText(fileToProcess, charset));
+        check.beginProcessing(charset);
+        final Field field = check.getClass().getDeclaredField("filesToProcess");
+        field.setAccessible(true);
+
+        assertTrue("Stateful field is not cleared on beginProcessing",
+            ((Collection<File>) field.get(check)).isEmpty());
+    }
+
+    @Test
+    public void testFileExtension() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(TranslationCheck.class);
+        checkConfig.addAttribute("baseName", "^InputTranslation.*$");
+        final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
+        final File[] propertyFiles = {
+            new File(getPath("InputTranslation_de.txt")),
+        };
+        verify(createChecker(checkConfig),
+            propertyFiles,
+            getPath("InputTranslation_de.txt"),
+            expected);
+    }
+
+    @Test
+    public void testLogOutput() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(TranslationCheck.class);
+        checkConfig.addAttribute("requiredTranslations", "ja,de");
+        checkConfig.addAttribute("baseName", "^InputTranslation.*$");
+        final Checker checker = createChecker(checkConfig);
+        checker.setBasedir(getPath(""));
+        final ByteArrayOutputStream out = new ByteArrayOutputStream();
+        final XMLLogger logger = new XMLLogger(out, AutomaticBean.OutputStreamOptions.NONE);
+        checker.addListener(logger);
+
+        final String defaultProps = getPath("InputTranslationCheckFireErrors.properties");
+        final String translationProps = getPath("InputTranslationCheckFireErrors_de.properties");
+
+        final File[] propertyFiles = {
+            new File(defaultProps),
+            new File(translationProps),
+        };
+
+        final String line = "0: ";
+        final String firstErrorMessage = getCheckMessage(MSG_KEY_MISSING_TRANSLATION_FILE,
+                "InputTranslationCheckFireErrors_ja.properties");
+        final String secondErrorMessage = getCheckMessage(MSG_KEY, "anotherKey");
+
+        verify(checker, propertyFiles, ImmutableMap.of(
+            ":0", Collections.singletonList(" " + firstErrorMessage),
+            "InputTranslationCheckFireErrors_de.properties",
+                Collections.singletonList(line + secondErrorMessage)));
+
+        verifyXml(getPath("ExpectedTranslationLog.xml"), out, (expected, actual) -> {
+            // order is not always maintained here for an unknown reason.
+            // File names can appear in different orders depending on the OS and VM.
+            // This ensures we pick up the correct file based on its name and the
+            // number of children it has.
+            return !"file".equals(expected.getNodeName())
+                    || expected.getAttributes().getNamedItem("name").getNodeValue()
+                            .equals(actual.getAttributes().getNamedItem("name").getNodeValue())
+                    && XmlUtil.getChildrenElements(expected).size() == XmlUtil
+                            .getChildrenElements(actual).size();
+        }, firstErrorMessage, secondErrorMessage);
+    }
+
     @Test
     public void testOnePropertyFileSet() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(TranslationCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(TranslationCheck.class);
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
         final File[] propertyFiles = {
             new File(getPath("app-dev.properties")),
@@ -88,21 +197,25 @@ public class TranslationCheckTest extends BaseCheckTestSupport {
     }
 
     @Test
+    @SuppressWarnings("unchecked")
     public void testLogIoExceptionFileNotFound() throws Exception {
         //I can't put wrong file here. Checkstyle fails before check started.
         //I saw some usage of file or handling of wrong file in Checker, or somewhere
         //in checks running part. So I had to do it with reflection to improve coverage.
         final TranslationCheck check = new TranslationCheck();
-        final DefaultConfiguration checkConfig = createCheckConfig(TranslationCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(TranslationCheck.class);
         check.configure(checkConfig);
         final Checker checker = createChecker(checkConfig);
+        final SeverityLevelCounter counter = new SeverityLevelCounter(SeverityLevel.ERROR);
+        checker.addListener(counter);
         check.setMessageDispatcher(checker);
 
         final Method loadKeys =
             check.getClass().getDeclaredMethod("getTranslationKeys", File.class);
         loadKeys.setAccessible(true);
-        loadKeys.invoke(check, new File(""));
-
+        final Set<String> keys = (Set<String>) loadKeys.invoke(check, new File(""));
+        assertTrue("Translation keys should be empty when File is not found", keys.isEmpty());
+        assertEquals("Invalid error count", 1, counter.getCount());
     }
 
     @Test
@@ -111,20 +224,26 @@ public class TranslationCheckTest extends BaseCheckTestSupport {
         //I saw some usage of file or handling of wrong file in Checker, or somewhere
         //in checks running part. So I had to do it with reflection to improve coverage.
         final TranslationCheck check = new TranslationCheck();
-        final DefaultConfiguration checkConfig = createCheckConfig(TranslationCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(TranslationCheck.class);
+        final MessageDispatcher dispatcher = mock(MessageDispatcher.class);
         check.configure(checkConfig);
-        check.setMessageDispatcher(createChecker(checkConfig));
+        check.setMessageDispatcher(dispatcher);
 
         final Method logIoException = check.getClass().getDeclaredMethod("logIoException",
                 IOException.class,
                 File.class);
         logIoException.setAccessible(true);
-        logIoException.invoke(check, new IOException("test exception"), new File(""));
+        final File file = new File("");
+        logIoException.invoke(check, new IOException("test exception"), file);
+
+        Mockito.verify(dispatcher, times(1)).fireErrors(any(String.class), captor.capture());
+        final String actual = captor.getValue().first().getMessage();
+        assertThat("Invalid message: " + actual, actual, endsWith("test exception"));
     }
 
     @Test
     public void testDefaultTranslationFileIsMissing() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(TranslationCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(TranslationCheck.class);
         checkConfig.addAttribute("requiredTranslations", "ja,,, de, ja");
 
         final File[] propertyFiles = {
@@ -133,7 +252,8 @@ public class TranslationCheckTest extends BaseCheckTestSupport {
         };
 
         final String[] expected = {
-            "0: Properties file 'messages_translation.properties' is missing.",
+            "0: " + getCheckMessage(MSG_KEY_MISSING_TRANSLATION_FILE,
+                    "messages_translation.properties"),
         };
         verify(
             createChecker(checkConfig),
@@ -144,7 +264,7 @@ public class TranslationCheckTest extends BaseCheckTestSupport {
 
     @Test
     public void testTranslationFilesAreMissing() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(TranslationCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(TranslationCheck.class);
         checkConfig.addAttribute("requiredTranslations", "ja, de");
 
         final File[] propertyFiles = {
@@ -153,7 +273,8 @@ public class TranslationCheckTest extends BaseCheckTestSupport {
         };
 
         final String[] expected = {
-            "0: Properties file 'messages_translation_de.properties' is missing.",
+            "0: " + getCheckMessage(MSG_KEY_MISSING_TRANSLATION_FILE,
+                    "messages_translation_de.properties"),
         };
         verify(
             createChecker(checkConfig),
@@ -164,7 +285,7 @@ public class TranslationCheckTest extends BaseCheckTestSupport {
 
     @Test
     public void testBaseNameWithSeparatorDefaultTranslationIsMissing() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(TranslationCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(TranslationCheck.class);
         checkConfig.addAttribute("requiredTranslations", "fr");
 
         final File[] propertyFiles = {
@@ -172,7 +293,8 @@ public class TranslationCheckTest extends BaseCheckTestSupport {
         };
 
         final String[] expected = {
-            "0: Properties file 'messages-translation.properties' is missing.",
+            "0: " + getCheckMessage(MSG_KEY_MISSING_TRANSLATION_FILE,
+                    "messages-translation.properties"),
         };
         verify(
             createChecker(checkConfig),
@@ -183,7 +305,7 @@ public class TranslationCheckTest extends BaseCheckTestSupport {
 
     @Test
     public void testBaseNameWithSeparatorTranslationsAreMissing() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(TranslationCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(TranslationCheck.class);
         checkConfig.addAttribute("requiredTranslations", "fr, tr");
 
         final File[] propertyFiles = {
@@ -192,7 +314,8 @@ public class TranslationCheckTest extends BaseCheckTestSupport {
         };
 
         final String[] expected = {
-            "0: Properties file 'messages-translation_tr.properties' is missing.",
+            "0: " + getCheckMessage(MSG_KEY_MISSING_TRANSLATION_FILE,
+                    "messages-translation_tr.properties"),
         };
         verify(
             createChecker(checkConfig),
@@ -203,7 +326,7 @@ public class TranslationCheckTest extends BaseCheckTestSupport {
 
     @Test
     public void testIsNotMessagesBundle() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(TranslationCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(TranslationCheck.class);
         checkConfig.addAttribute("requiredTranslations", "de");
 
         final File[] propertyFiles = {
@@ -221,7 +344,7 @@ public class TranslationCheckTest extends BaseCheckTestSupport {
 
     @Test
     public void testTranslationFileWithLanguageCountryVariantIsMissing() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(TranslationCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(TranslationCheck.class);
         checkConfig.addAttribute("requiredTranslations", "es, de");
 
         final File[] propertyFiles = {
@@ -231,7 +354,8 @@ public class TranslationCheckTest extends BaseCheckTestSupport {
             };
 
         final String[] expected = {
-            "0: Properties file 'messages_home_de.properties' is missing.",
+            "0: " + getCheckMessage(MSG_KEY_MISSING_TRANSLATION_FILE,
+                    "messages_home_de.properties"),
         };
         verify(
             createChecker(checkConfig),
@@ -242,7 +366,7 @@ public class TranslationCheckTest extends BaseCheckTestSupport {
 
     @Test
     public void testTranslationFileWithLanguageCountryVariantArePresent() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(TranslationCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(TranslationCheck.class);
         checkConfig.addAttribute("requiredTranslations", "es, fr");
 
         final File[] propertyFiles = {
@@ -259,9 +383,39 @@ public class TranslationCheckTest extends BaseCheckTestSupport {
             expected);
     }
 
+    /**
+     * Pitest requires all closes of streams and readers to be verified. Using PowerMock
+     * is almost only possibility to check it without rewriting production code.
+     *
+     * @throws Exception when code tested throws some exception
+     */
+    @Test
+    public void testResourcesAreClosed() throws Exception {
+        mockStatic(Closeables.class);
+        doNothing().when(Closeables.class);
+        Closeables.closeQuietly(any(InputStream.class));
+
+        final DefaultConfiguration checkConfig = createModuleConfig(TranslationCheck.class);
+        checkConfig.addAttribute("requiredTranslations", "es");
+
+        final File[] propertyFiles = {
+            new File(getPath("messages_home.properties")),
+            new File(getPath("messages_home_es_US.properties")),
+            };
+
+        final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
+        verify(
+            createChecker(checkConfig),
+            propertyFiles,
+            getPath(""),
+            expected);
+        verifyStatic(times(2));
+        Closeables.closeQuietly(any(FileInputStream.class));
+    }
+
     @Test
     public void testBaseNameOption() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(TranslationCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(TranslationCheck.class);
         checkConfig.addAttribute("requiredTranslations", "de, es, fr, ja");
         checkConfig.addAttribute("baseName", "^.*Labels$");
 
@@ -276,7 +430,8 @@ public class TranslationCheckTest extends BaseCheckTestSupport {
         };
 
         final String[] expected = {
-            "0: Properties file 'ButtonLabels_ja.properties' is missing.",
+            "0: " + getCheckMessage(MSG_KEY_MISSING_TRANSLATION_FILE,
+                    "ButtonLabels_ja.properties"),
         };
         verify(
             createChecker(checkConfig),
@@ -287,7 +442,7 @@ public class TranslationCheckTest extends BaseCheckTestSupport {
 
     @Test
     public void testFileExtensions() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(TranslationCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(TranslationCheck.class);
         checkConfig.addAttribute("requiredTranslations", "de, es, fr, ja");
         checkConfig.addAttribute("fileExtensions", "properties,translation");
         checkConfig.addAttribute("baseName", "^.*(Titles|Labels)$");
@@ -305,7 +460,8 @@ public class TranslationCheckTest extends BaseCheckTestSupport {
         };
 
         final String[] expected = {
-            "0: Properties file 'ButtonLabels_ja.properties' is missing.",
+            "0: " + getCheckMessage(MSG_KEY_MISSING_TRANSLATION_FILE,
+                    "ButtonLabels_ja.properties"),
         };
 
         verify(
@@ -317,7 +473,7 @@ public class TranslationCheckTest extends BaseCheckTestSupport {
 
     @Test
     public void testEqualBaseNamesButDifferentExtensions() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(TranslationCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(TranslationCheck.class);
         checkConfig.addAttribute("requiredTranslations", "de, es, fr, ja");
         checkConfig.addAttribute("fileExtensions", "properties,translations");
         checkConfig.addAttribute("baseName", "^.*Labels$");
@@ -335,7 +491,8 @@ public class TranslationCheckTest extends BaseCheckTestSupport {
         };
 
         final String[] expected = {
-            "0: Properties file 'ButtonLabels_ja.properties' is missing.",
+            "0: " + getCheckMessage(MSG_KEY_MISSING_TRANSLATION_FILE,
+                    "ButtonLabels_ja.properties"),
         };
 
         verify(
@@ -347,7 +504,7 @@ public class TranslationCheckTest extends BaseCheckTestSupport {
 
     @Test
     public void testRegexpToMatchPartOfBaseName() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(TranslationCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(TranslationCheck.class);
         checkConfig.addAttribute("requiredTranslations", "de, es, fr, ja");
         checkConfig.addAttribute("fileExtensions", "properties,translations");
         checkConfig.addAttribute("baseName", "^.*Labels.*");
@@ -359,9 +516,9 @@ public class TranslationCheckTest extends BaseCheckTestSupport {
         };
 
         final String[] expected = {
-            "0: Properties file 'MyLabelsI18_fr.properties' is missing.",
-            "0: Properties file 'MyLabelsI18_ja.properties' is missing.",
-            };
+            "0: " + getCheckMessage(MSG_KEY_MISSING_TRANSLATION_FILE, "MyLabelsI18_fr.properties"),
+            "0: " + getCheckMessage(MSG_KEY_MISSING_TRANSLATION_FILE, "MyLabelsI18_ja.properties"),
+        };
 
         verify(
             createChecker(checkConfig),
@@ -372,7 +529,7 @@ public class TranslationCheckTest extends BaseCheckTestSupport {
 
     @Test
     public void testBundlesWithSameNameButDifferentPaths() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(TranslationCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(TranslationCheck.class);
         checkConfig.addAttribute("requiredTranslations", "de");
         checkConfig.addAttribute("fileExtensions", "properties");
         checkConfig.addAttribute("baseName", "^.*Labels.*");
@@ -402,8 +559,11 @@ public class TranslationCheckTest extends BaseCheckTestSupport {
         }
         catch (IllegalArgumentException ex) {
             final String exceptionMessage = ex.getMessage();
-            assertThat(exceptionMessage, containsString("11"));
-            assertThat(exceptionMessage, endsWith("[TranslationCheck]"));
+            assertThat("Error message is unexpected",
+                    exceptionMessage, containsString("11"));
+            assertThat("Error message is unexpected",
+                    exceptionMessage, endsWith("[TranslationCheck]"));
         }
     }
+
 }
