@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2017 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -21,26 +21,23 @@ package com.puppycrawl.tools.checkstyle.checks.coding;
 
 import static com.puppycrawl.tools.checkstyle.checks.coding.IllegalThrowsCheck.MSG_KEY;
 
-import java.io.File;
-import java.io.IOException;
-
 import org.junit.Assert;
 import org.junit.Test;
 
-import com.puppycrawl.tools.checkstyle.BaseCheckTestSupport;
+import com.puppycrawl.tools.checkstyle.AbstractModuleTestSupport;
 import com.puppycrawl.tools.checkstyle.DefaultConfiguration;
 import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
 
-public class IllegalThrowsCheckTest extends BaseCheckTestSupport {
+public class IllegalThrowsCheckTest extends AbstractModuleTestSupport {
+
     @Override
-    protected String getPath(String filename) throws IOException {
-        return super.getPath("checks" + File.separator
-                + "coding" + File.separator + filename);
+    protected String getPackageLocation() {
+        return "com/puppycrawl/tools/checkstyle/checks/coding/illegalthrows";
     }
 
     @Test
     public void testDefault() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(IllegalThrowsCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(IllegalThrowsCheck.class);
 
         final String[] expected = {
             "9:51: " + getCheckMessage(MSG_KEY, "RuntimeException"),
@@ -53,7 +50,7 @@ public class IllegalThrowsCheckTest extends BaseCheckTestSupport {
 
     @Test
     public void testIllegalClassNames() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(IllegalThrowsCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(IllegalThrowsCheck.class);
         checkConfig.addAttribute("illegalClassNames",
                                  "java.lang.Error, java.lang.Exception, NullPointerException");
 
@@ -74,7 +71,7 @@ public class IllegalThrowsCheckTest extends BaseCheckTestSupport {
      */
     @Test
     public void testIgnoreMethodNames() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(IllegalThrowsCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(IllegalThrowsCheck.class);
         checkConfig.addAttribute("ignoredMethodNames", "methodTwo");
 
         final String[] expected = {
@@ -90,7 +87,7 @@ public class IllegalThrowsCheckTest extends BaseCheckTestSupport {
      */
     @Test
     public void testIllegalClassNamesWithIgnoreMethodNames() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(IllegalThrowsCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(IllegalThrowsCheck.class);
         checkConfig.addAttribute("illegalClassNames",
             "java.lang.Error, java.lang.Exception, NullPointerException, Throwable");
         checkConfig.addAttribute("ignoredMethodNames", "methodTwo");
@@ -109,7 +106,7 @@ public class IllegalThrowsCheckTest extends BaseCheckTestSupport {
      */
     @Test
     public void testIgnoreOverriddenMethods() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(IllegalThrowsCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(IllegalThrowsCheck.class);
         checkConfig.addAttribute("ignoreOverriddenMethods", "true");
 
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
@@ -123,7 +120,7 @@ public class IllegalThrowsCheckTest extends BaseCheckTestSupport {
      */
     @Test
     public void testNotIgnoreOverriddenMethods() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(IllegalThrowsCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(IllegalThrowsCheck.class);
         checkConfig.addAttribute("ignoreOverriddenMethods", "false");
 
         final String[] expected = {
@@ -137,8 +134,9 @@ public class IllegalThrowsCheckTest extends BaseCheckTestSupport {
     @Test
     public void testTokensNotNull() {
         final IllegalThrowsCheck check = new IllegalThrowsCheck();
-        Assert.assertNotNull(check.getAcceptableTokens());
-        Assert.assertNotNull(check.getDefaultTokens());
-        Assert.assertNotNull(check.getRequiredTokens());
+        Assert.assertNotNull("Acceptable tokens should not be null", check.getAcceptableTokens());
+        Assert.assertNotNull("Default tokens should not be null", check.getDefaultTokens());
+        Assert.assertNotNull("Required tokens should not be null", check.getRequiredTokens());
     }
+
 }
