@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2017 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -21,27 +21,24 @@ package com.puppycrawl.tools.checkstyle.checks.coding;
 
 import static com.puppycrawl.tools.checkstyle.checks.coding.MagicNumberCheck.MSG_KEY;
 
-import java.io.File;
-import java.io.IOException;
-
 import org.junit.Test;
 
-import com.puppycrawl.tools.checkstyle.BaseCheckTestSupport;
+import com.puppycrawl.tools.checkstyle.AbstractModuleTestSupport;
 import com.puppycrawl.tools.checkstyle.DefaultConfiguration;
 
 public class MagicNumberCheckTest
-    extends BaseCheckTestSupport {
+    extends AbstractModuleTestSupport {
+
     @Override
-    protected String getPath(String filename) throws IOException {
-        return super.getPath("checks" + File.separator
-                + "coding" + File.separator + filename);
+    protected String getPackageLocation() {
+        return "com/puppycrawl/tools/checkstyle/checks/coding/magicnumber";
     }
 
     @Test
     public void testDefault()
             throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(MagicNumberCheck.class);
+            createModuleConfig(MagicNumberCheck.class);
         final String[] expected = {
             "41:26: " + getCheckMessage(MSG_KEY, "3_000"),
             "42:32: " + getCheckMessage(MSG_KEY, "1.5_0"),
@@ -80,10 +77,10 @@ public class MagicNumberCheckTest
             "174:15: " + getCheckMessage(MSG_KEY, "21"),
             "178:15: " + getCheckMessage(MSG_KEY, "37"),
             "182:15: " + getCheckMessage(MSG_KEY, "101"),
-            "185:31: " + getCheckMessage(MSG_KEY, "42"),
-            "189:37: " + getCheckMessage(MSG_KEY, "43"),
-            "193:31: " + getCheckMessage(MSG_KEY, "-44"),
-            "197:37: " + getCheckMessage(MSG_KEY, "-45"),
+            "185:42: " + getCheckMessage(MSG_KEY, "42"),
+            "189:48: " + getCheckMessage(MSG_KEY, "43"),
+            "193:42: " + getCheckMessage(MSG_KEY, "-44"),
+            "197:48: " + getCheckMessage(MSG_KEY, "-45"),
         };
         verify(checkConfig, getPath("InputMagicNumber.java"), expected);
     }
@@ -92,7 +89,7 @@ public class MagicNumberCheckTest
     public void testIgnoreSome()
             throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(MagicNumberCheck.class);
+            createModuleConfig(MagicNumberCheck.class);
         checkConfig.addAttribute("ignoreNumbers", "0, 1, 3.0, 8, 16, 3000");
         checkConfig.addAttribute("ignoreAnnotation", "true");
         final String[] expected = {
@@ -138,7 +135,7 @@ public class MagicNumberCheckTest
     public void testIgnoreNone()
             throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(MagicNumberCheck.class);
+            createModuleConfig(MagicNumberCheck.class);
         checkConfig.addAttribute("ignoreNumbers", "");
         checkConfig.addAttribute("ignoreAnnotation", "true");
         final String[] expected = {
@@ -212,7 +209,7 @@ public class MagicNumberCheckTest
     public void testIntegersOnly()
             throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(MagicNumberCheck.class);
+            createModuleConfig(MagicNumberCheck.class);
         checkConfig.addAttribute("tokens", "NUM_INT, NUM_LONG");
         checkConfig.addAttribute("ignoreAnnotation", "true");
         final String[] expected = {
@@ -256,8 +253,9 @@ public class MagicNumberCheckTest
     @Test
     public void testIgnoreNegativeOctalHex() throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(MagicNumberCheck.class);
-        checkConfig.addAttribute("ignoreNumbers", "-9223372036854775808, -2147483648, -1, 0, 1, 2");
+            createModuleConfig(MagicNumberCheck.class);
+        checkConfig.addAttribute("ignoreNumbers",
+            "-9223372036854775808, -2147483648, -1, 0, 1, 2, -2");
         checkConfig.addAttribute("tokens", "NUM_INT, NUM_LONG");
         checkConfig.addAttribute("ignoreAnnotation", "true");
         final String[] expected = {
@@ -282,7 +280,6 @@ public class MagicNumberCheckTest
             "85:28: " + getCheckMessage(MSG_KEY, "3"),
             "92:14: " + getCheckMessage(MSG_KEY, "0xffffffffL"),
             "100:30: " + getCheckMessage(MSG_KEY, "+3"),
-            "101:29: " + getCheckMessage(MSG_KEY, "-2"),
             "131:20: " + getCheckMessage(MSG_KEY, "378"),
             "160:16: " + getCheckMessage(MSG_KEY, "31"),
             "165:16: " + getCheckMessage(MSG_KEY, "42"),
@@ -297,7 +294,7 @@ public class MagicNumberCheckTest
     @Test
     public void testIgnoreHashCodeMethod() throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(MagicNumberCheck.class);
+            createModuleConfig(MagicNumberCheck.class);
         checkConfig.addAttribute("ignoreHashCodeMethod", "true");
         checkConfig.addAttribute("ignoreAnnotation", "true");
         final String[] expected = {
@@ -345,7 +342,7 @@ public class MagicNumberCheckTest
     public void testIgnoreFieldDeclaration()
             throws Exception {
         final DefaultConfiguration checkConfig =
-                createCheckConfig(MagicNumberCheck.class);
+                createModuleConfig(MagicNumberCheck.class);
         checkConfig.addAttribute("ignoreFieldDeclaration", "true");
         final String[] expected = {
             "41:26: " + getCheckMessage(MSG_KEY, "3_000"),
@@ -375,10 +372,10 @@ public class MagicNumberCheckTest
             "174:15: " + getCheckMessage(MSG_KEY, "21"),
             "178:15: " + getCheckMessage(MSG_KEY, "37"),
             "182:15: " + getCheckMessage(MSG_KEY, "101"),
-            "185:31: " + getCheckMessage(MSG_KEY, "42"),
-            "189:37: " + getCheckMessage(MSG_KEY, "43"),
-            "193:31: " + getCheckMessage(MSG_KEY, "-44"),
-            "197:37: " + getCheckMessage(MSG_KEY, "-45"),
+            "185:42: " + getCheckMessage(MSG_KEY, "42"),
+            "189:48: " + getCheckMessage(MSG_KEY, "43"),
+            "193:42: " + getCheckMessage(MSG_KEY, "-44"),
+            "197:48: " + getCheckMessage(MSG_KEY, "-45"),
         };
         verify(checkConfig, getPath("InputMagicNumber.java"), expected);
     }
@@ -387,7 +384,7 @@ public class MagicNumberCheckTest
     public void testWaiverParentToken()
             throws Exception {
         final DefaultConfiguration checkConfig =
-                createCheckConfig(MagicNumberCheck.class);
+                createModuleConfig(MagicNumberCheck.class);
         checkConfig.addAttribute("constantWaiverParentToken", "ASSIGN, ARRAY_INIT,"
                 + " EXPR, UNARY_PLUS, UNARY_MINUS, TYPECAST, ELIST, STAR, DIV, PLUS, MINUS");
         final String[] expected = {
@@ -433,12 +430,13 @@ public class MagicNumberCheckTest
             "174:15: " + getCheckMessage(MSG_KEY, "21"),
             "178:15: " + getCheckMessage(MSG_KEY, "37"),
             "182:15: " + getCheckMessage(MSG_KEY, "101"),
-            "185:31: " + getCheckMessage(MSG_KEY, "42"),
-            "189:37: " + getCheckMessage(MSG_KEY, "43"),
-            "193:31: " + getCheckMessage(MSG_KEY, "-44"),
-            "197:37: " + getCheckMessage(MSG_KEY, "-45"),
+            "185:42: " + getCheckMessage(MSG_KEY, "42"),
+            "189:48: " + getCheckMessage(MSG_KEY, "43"),
+            "193:42: " + getCheckMessage(MSG_KEY, "-44"),
+            "197:48: " + getCheckMessage(MSG_KEY, "-45"),
             "209:63: " + getCheckMessage(MSG_KEY, "62"),
         };
         verify(checkConfig, getPath("InputMagicNumber.java"), expected);
     }
+
 }
