@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2017 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -21,27 +21,24 @@ package com.puppycrawl.tools.checkstyle.checks.coding;
 
 import static com.puppycrawl.tools.checkstyle.checks.coding.NestedIfDepthCheck.MSG_KEY;
 
-import java.io.File;
-import java.io.IOException;
-
 import org.junit.Assert;
 import org.junit.Test;
 
-import com.puppycrawl.tools.checkstyle.BaseCheckTestSupport;
+import com.puppycrawl.tools.checkstyle.AbstractModuleTestSupport;
 import com.puppycrawl.tools.checkstyle.DefaultConfiguration;
 import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
 
-public class NestedIfDepthCheckTest extends BaseCheckTestSupport {
+public class NestedIfDepthCheckTest extends AbstractModuleTestSupport {
+
     @Override
-    protected String getPath(String filename) throws IOException {
-        return super.getPath("checks" + File.separator
-                + "coding" + File.separator + filename);
+    protected String getPackageLocation() {
+        return "com/puppycrawl/tools/checkstyle/checks/coding/nestedifdepth";
     }
 
     @Test
     public void testDefault() throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(NestedIfDepthCheck.class);
+            createModuleConfig(NestedIfDepthCheck.class);
 
         final String[] expected = {
             "18:17: " + getCheckMessage(MSG_KEY, 2, 1),
@@ -55,7 +52,7 @@ public class NestedIfDepthCheckTest extends BaseCheckTestSupport {
     @Test
     public void testCustomizedDepth() throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(NestedIfDepthCheck.class);
+            createModuleConfig(NestedIfDepthCheck.class);
         checkConfig.addAttribute("max", "2");
 
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
@@ -66,8 +63,9 @@ public class NestedIfDepthCheckTest extends BaseCheckTestSupport {
     @Test
     public void testTokensNotNull() {
         final NestedIfDepthCheck check = new NestedIfDepthCheck();
-        Assert.assertNotNull(check.getAcceptableTokens());
-        Assert.assertNotNull(check.getDefaultTokens());
-        Assert.assertNotNull(check.getRequiredTokens());
+        Assert.assertNotNull("Acceptable tokens should not be null", check.getAcceptableTokens());
+        Assert.assertNotNull("Default tokens should not be null", check.getDefaultTokens());
+        Assert.assertNotNull("Required tokens should not be null", check.getRequiredTokens());
     }
+
 }
