@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2017 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -22,22 +22,19 @@ package com.puppycrawl.tools.checkstyle.checks.design;
 import static com.puppycrawl.tools.checkstyle.checks.design.HideUtilityClassConstructorCheck.MSG_KEY;
 import static org.junit.Assert.assertArrayEquals;
 
-import java.io.File;
-import java.io.IOException;
-
 import org.junit.Test;
 
-import com.puppycrawl.tools.checkstyle.BaseCheckTestSupport;
+import com.puppycrawl.tools.checkstyle.AbstractModuleTestSupport;
 import com.puppycrawl.tools.checkstyle.DefaultConfiguration;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
 import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
 
 public class HideUtilityClassConstructorCheckTest
-    extends BaseCheckTestSupport {
+    extends AbstractModuleTestSupport {
+
     @Override
-    protected String getPath(String filename) throws IOException {
-        return super.getPath("checks" + File.separator
-                + "design" + File.separator + filename);
+    protected String getPackageLocation() {
+        return "com/puppycrawl/tools/checkstyle/checks/design/hideutilityclassconstructor";
     }
 
     @Test
@@ -45,90 +42,99 @@ public class HideUtilityClassConstructorCheckTest
         final HideUtilityClassConstructorCheck checkObj =
             new HideUtilityClassConstructorCheck();
         final int[] expected = {TokenTypes.CLASS_DEF};
-        assertArrayEquals(expected, checkObj.getRequiredTokens());
+        assertArrayEquals("Default required tokens are invalid",
+            expected, checkObj.getRequiredTokens());
     }
 
     @Test
     public void testUtilClass() throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(HideUtilityClassConstructorCheck.class);
+            createModuleConfig(HideUtilityClassConstructorCheck.class);
         final String[] expected = {
             "3:1: " + getCheckMessage(MSG_KEY),
         };
-        verify(checkConfig, getPath("InputUtilityClassConstructor.java"), expected);
+        verify(checkConfig, getPath("InputHideUtilityClassConstructorInnerStaticClasses.java"),
+                expected);
     }
 
     @Test
     public void testUtilClassPublicCtor() throws Exception {
         final DefaultConfiguration checkConfig =
-                createCheckConfig(HideUtilityClassConstructorCheck.class);
+                createModuleConfig(HideUtilityClassConstructorCheck.class);
         final String[] expected = {
             "3:1: " + getCheckMessage(MSG_KEY),
         };
-        verify(checkConfig, getPath("InputUtilityClassConstructorPublic.java"), expected);
+        verify(checkConfig, getPath("InputHideUtilityClassConstructorPublic.java"), expected);
     }
 
     @Test
     public void testUtilClassPrivateCtor() throws Exception {
         final DefaultConfiguration checkConfig =
-                createCheckConfig(HideUtilityClassConstructorCheck.class);
+                createModuleConfig(HideUtilityClassConstructorCheck.class);
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
-        verify(checkConfig, getPath("InputUtilityClassConstructorPrivate.java"), expected);
+        verify(checkConfig, getPath("InputHideUtilityClassConstructorPrivate.java"), expected);
     }
 
     /** Non-static methods - always OK. */
     @Test
     public void testNonUtilClass() throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(HideUtilityClassConstructorCheck.class);
+            createModuleConfig(HideUtilityClassConstructorCheck.class);
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
-        verify(checkConfig, getPath("InputDesignForExtension.java"), expected);
+        verify(checkConfig, getPath("InputHideUtilityClassConstructorDesignForExtension.java"),
+                expected);
     }
 
     @Test
     public void testDerivedNonUtilClass() throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(HideUtilityClassConstructorCheck.class);
+            createModuleConfig(HideUtilityClassConstructorCheck.class);
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
-        verify(checkConfig, getPath("InputNonUtilityClass.java"), expected);
+        verify(checkConfig, getPath("InputHideUtilityClassConstructorNonUtilityClass.java"),
+                expected);
     }
 
     @Test
     public void testOnlyNonStaticFieldNonUtilClass() throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(HideUtilityClassConstructorCheck.class);
+            createModuleConfig(HideUtilityClassConstructorCheck.class);
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
-        verify(checkConfig, getPath("InputRegression1762702.java"), expected);
+        verify(checkConfig, getPath("InputHideUtilityClassConstructorRegression.java"),
+                expected);
     }
 
     @Test
     public void testEmptyAbstractClass() throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(HideUtilityClassConstructorCheck.class);
+            createModuleConfig(HideUtilityClassConstructorCheck.class);
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
-        verify(checkConfig, getPath("InputHideUtilityClassConstructor3041574_1.java"), expected);
+        verify(checkConfig, getPath("InputHideUtilityClassConstructorAbstractSerializable.java"),
+                expected);
     }
 
     @Test
     public void testEmptyClassWithOnlyPrivateFields() throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(HideUtilityClassConstructorCheck.class);
+            createModuleConfig(HideUtilityClassConstructorCheck.class);
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
-        verify(checkConfig, getPath("InputHideUtilityClassConstructor3041574_2.java"), expected);
+        verify(checkConfig, getPath("InputHideUtilityClassConstructorSerializable.java"),
+                expected);
     }
 
     @Test
     public void testClassWithStaticInnerClass() throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(HideUtilityClassConstructorCheck.class);
+            createModuleConfig(HideUtilityClassConstructorCheck.class);
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
-        verify(checkConfig, getPath("InputHideUtilityClassConstructor3041574_3.java"), expected);
+        verify(checkConfig, getPath(
+                "InputHideUtilityClassConstructorSerializableInnerStatic.java"),
+                expected);
     }
 
     @Test
     public void testProtectedCtor() throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(HideUtilityClassConstructorCheck.class);
+            createModuleConfig(HideUtilityClassConstructorCheck.class);
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
         verify(checkConfig, getPath("InputHideUtilityClassConstructor.java"), expected);
     }
@@ -137,6 +143,8 @@ public class HideUtilityClassConstructorCheckTest
     public void testGetAcceptableTokens() {
         final HideUtilityClassConstructorCheck obj = new HideUtilityClassConstructorCheck();
         final int[] expected = {TokenTypes.CLASS_DEF};
-        assertArrayEquals(expected, obj.getAcceptableTokens());
+        assertArrayEquals("Default acceptable tokens are invalid",
+            expected, obj.getAcceptableTokens());
     }
+
 }
