@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2017 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -22,34 +22,29 @@ package com.puppycrawl.tools.checkstyle.checks.design;
 import static com.puppycrawl.tools.checkstyle.checks.design.VisibilityModifierCheck.MSG_KEY;
 import static org.junit.Assert.assertArrayEquals;
 import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 
 import java.io.File;
-import java.io.IOException;
+import java.lang.reflect.Method;
 
 import org.junit.Test;
+import org.powermock.reflect.Whitebox;
 
 import antlr.CommonHiddenStreamToken;
-import com.puppycrawl.tools.checkstyle.BaseCheckTestSupport;
-import com.puppycrawl.tools.checkstyle.Checker;
+import com.puppycrawl.tools.checkstyle.AbstractModuleTestSupport;
 import com.puppycrawl.tools.checkstyle.DefaultConfiguration;
+import com.puppycrawl.tools.checkstyle.JavaParser;
 import com.puppycrawl.tools.checkstyle.api.DetailAST;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
 import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
 
 public class VisibilityModifierCheckTest
-    extends BaseCheckTestSupport {
-    private Checker getChecker() throws Exception {
-        final DefaultConfiguration checkConfig =
-            createCheckConfig(VisibilityModifierCheck.class);
-        checkConfig.addAttribute("publicMemberPattern", "^f[A-Z][a-zA-Z0-9]*$");
-        return createChecker(checkConfig);
-    }
+    extends AbstractModuleTestSupport {
 
     @Override
-    protected String getPath(String filename) throws IOException {
-        return super.getPath("checks" + File.separator
-                + "design" + File.separator + filename);
+    protected String getPackageLocation() {
+        return "com/puppycrawl/tools/checkstyle/checks/design/visibilitymodifier";
     }
 
     @Test
@@ -59,12 +54,16 @@ public class VisibilityModifierCheckTest
             TokenTypes.VARIABLE_DEF,
             TokenTypes.IMPORT,
         };
-        assertArrayEquals(expected, checkObj.getRequiredTokens());
+        assertArrayEquals("Default required tokens are invalid",
+            expected, checkObj.getRequiredTokens());
     }
 
     @Test
     public void testInner()
             throws Exception {
+        final DefaultConfiguration checkConfig =
+                createModuleConfig(VisibilityModifierCheck.class);
+        checkConfig.addAttribute("publicMemberPattern", "^f[A-Z][a-zA-Z0-9]*$");
         final String[] expected = {
             "30:24: " + getCheckMessage(MSG_KEY, "rData"),
             "33:27: " + getCheckMessage(MSG_KEY, "protectedVariable"),
@@ -73,14 +72,14 @@ public class VisibilityModifierCheckTest
             "43:19: " + getCheckMessage(MSG_KEY, "sWeird2"),
             "77:20: " + getCheckMessage(MSG_KEY, "someValue"),
         };
-        verify(getChecker(), getPath("InputInner.java"), expected);
+        verify(checkConfig, getPath("InputVisibilityModifierInner.java"), expected);
     }
 
     @Test
     public void testIgnoreAccess()
             throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(VisibilityModifierCheck.class);
+            createModuleConfig(VisibilityModifierCheck.class);
         checkConfig.addAttribute("publicMemberPattern", "^r[A-Z]");
         checkConfig.addAttribute("protectedAllowed", "true");
         checkConfig.addAttribute("packageAllowed", "true");
@@ -88,11 +87,14 @@ public class VisibilityModifierCheckTest
             "17:20: " + getCheckMessage(MSG_KEY, "fData"),
             "77:20: " + getCheckMessage(MSG_KEY, "someValue"),
         };
-        verify(checkConfig, getPath("InputInner.java"), expected);
+        verify(checkConfig, getPath("InputVisibilityModifierInner.java"), expected);
     }
 
     @Test
     public void testSimple() throws Exception {
+        final DefaultConfiguration checkConfig =
+                createModuleConfig(VisibilityModifierCheck.class);
+        checkConfig.addAttribute("publicMemberPattern", "^f[A-Z][a-zA-Z0-9]*$");
         final String[] expected = {
             "33:19: " + getCheckMessage(MSG_KEY, "mNumCreated2"),
             "43:23: " + getCheckMessage(MSG_KEY, "sTest1"),
@@ -101,23 +103,26 @@ public class VisibilityModifierCheckTest
             "50:9: " + getCheckMessage(MSG_KEY, "mTest1"),
             "52:16: " + getCheckMessage(MSG_KEY, "mTest2"),
         };
-        verify(getChecker(), getPath("InputSimple.java"), expected);
+        verify(checkConfig, getPath("InputVisibilityModifierSimple.java"), expected);
     }
 
     @Test
     public void testStrictJavadoc() throws Exception {
+        final DefaultConfiguration checkConfig =
+                createModuleConfig(VisibilityModifierCheck.class);
+        checkConfig.addAttribute("publicMemberPattern", "^f[A-Z][a-zA-Z0-9]*$");
         final String[] expected = {
             "32:9: " + getCheckMessage(MSG_KEY, "mLen"),
             "33:19: " + getCheckMessage(MSG_KEY, "mDeer"),
             "34:16: " + getCheckMessage(MSG_KEY, "aFreddo"),
         };
-        verify(getChecker(), getPath("InputPublicOnly.java"), expected);
+        verify(checkConfig, getPath("InputVisibilityModifierPublicOnly.java"), expected);
     }
 
     @Test
     public void testAllowPublicFinalFieldsInImmutableClass() throws Exception {
         final DefaultConfiguration checkConfig =
-                createCheckConfig(VisibilityModifierCheck.class);
+                createModuleConfig(VisibilityModifierCheck.class);
         checkConfig.addAttribute("allowPublicImmutableFields", "true");
         final String[] expected = {
             "12:39: " + getCheckMessage(MSG_KEY, "includes"),
@@ -127,13 +132,13 @@ public class VisibilityModifierCheckTest
             "36:24: " + getCheckMessage(MSG_KEY, "bValue"),
             "37:31: " + getCheckMessage(MSG_KEY, "longValue"),
         };
-        verify(checkConfig, getPath("InputImmutable.java"), expected);
+        verify(checkConfig, getPath("InputVisibilityModifierImmutable.java"), expected);
     }
 
     @Test
     public void testDisAllowPublicFinalAndImmutableFieldsInImmutableClass() throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(VisibilityModifierCheck.class);
+            createModuleConfig(VisibilityModifierCheck.class);
         final String[] expected = {
             "11:22: " + getCheckMessage(MSG_KEY, "someIntValue"),
             "12:39: " + getCheckMessage(MSG_KEY, "includes"),
@@ -150,26 +155,26 @@ public class VisibilityModifierCheckTest
             "36:24: " + getCheckMessage(MSG_KEY, "bValue"),
             "37:31: " + getCheckMessage(MSG_KEY, "longValue"),
             };
-        verify(checkConfig, getPath("InputImmutable.java"), expected);
+        verify(checkConfig, getPath("InputVisibilityModifierImmutable.java"), expected);
     }
 
     @Test
     public void testAllowPublicFinalFieldsInNonFinalClass() throws Exception {
         final DefaultConfiguration checkConfig =
-                createCheckConfig(VisibilityModifierCheck.class);
+                createModuleConfig(VisibilityModifierCheck.class);
         checkConfig.addAttribute("allowPublicFinalFields", "true");
         final String[] expected = {
             "34:20: " + getCheckMessage(MSG_KEY, "value"),
             "36:24: " + getCheckMessage(MSG_KEY, "bValue"),
             "37:31: " + getCheckMessage(MSG_KEY, "longValue"),
         };
-        verify(checkConfig, getPath("InputImmutable.java"), expected);
+        verify(checkConfig, getPath("InputVisibilityModifierImmutable.java"), expected);
     }
 
     @Test
     public void testUserSpecifiedImmutableClassesList() throws Exception {
         final DefaultConfiguration checkConfig =
-                createCheckConfig(VisibilityModifierCheck.class);
+                createModuleConfig(VisibilityModifierCheck.class);
         checkConfig.addAttribute("allowPublicImmutableFields", "true");
         checkConfig.addAttribute("immutableClassCanonicalNames", "java.util.List,"
                 + "com.google.common.collect.ImmutableSet, java.lang.String");
@@ -182,63 +187,68 @@ public class VisibilityModifierCheckTest
             "36:24: " + getCheckMessage(MSG_KEY, "bValue"),
             "37:31: " + getCheckMessage(MSG_KEY, "longValue"),
         };
-        verify(checkConfig, getPath("InputImmutable.java"), expected);
+        verify(checkConfig, getPath("InputVisibilityModifierImmutable.java"), expected);
     }
 
     @Test
     public void testImmutableSpecifiedSameTypeName() throws Exception {
         final DefaultConfiguration checkConfig =
-                createCheckConfig(VisibilityModifierCheck.class);
+                createModuleConfig(VisibilityModifierCheck.class);
         checkConfig.addAttribute("allowPublicImmutableFields", "true");
         checkConfig.addAttribute("immutableClassCanonicalNames",
-                 "com.puppycrawl.tools.checkstyle.checks.coding.InputGregorianCalendar,"
-                 + "com.puppycrawl.tools.checkstyle.checks.design.InetSocketAddress");
+                 "com.puppycrawl.tools.checkstyle.checks.design."
+                         + "visibilitymodifier.InputVisibilityModifierGregorianCalendar,"
+                 + "com.puppycrawl.tools.checkstyle.checks.design."
+                         + "visibilitymodifier.inputs.InetSocketAddress");
         final String[] expected = {
             "7:46: " + getCheckMessage(MSG_KEY, "calendar"),
-            "11:45: " + getCheckMessage(MSG_KEY, "adr"),
+            "12:45: " + getCheckMessage(MSG_KEY, "adr"),
         };
-        verify(checkConfig, getPath("InputImmutableSameTypeName.java"), expected);
+        verify(checkConfig, getPath("InputVisibilityModifierImmutableSameTypeName.java"),
+                expected);
     }
 
     @Test
     public void testImmutableValueSameTypeName() throws Exception {
         final DefaultConfiguration checkConfig =
-                createCheckConfig(VisibilityModifierCheck.class);
+                createModuleConfig(VisibilityModifierCheck.class);
         checkConfig.addAttribute("allowPublicImmutableFields", "true");
         final String[] expected = {
             "7:46: " + getCheckMessage(MSG_KEY, "calendar"),
-            "8:41: " + getCheckMessage(MSG_KEY, "calendar2"),
-            "9:87: " + getCheckMessage(MSG_KEY, "calendar3"),
-            "10:36: " + getCheckMessage(MSG_KEY, "address"),
+            "8:59: " + getCheckMessage(MSG_KEY, "calendar2"),
+            "10:73: " + getCheckMessage(MSG_KEY, "calendar3"),
+            "11:36: " + getCheckMessage(MSG_KEY, "address"),
         };
-        verify(checkConfig, getPath("InputImmutableSameTypeName.java"), expected);
+        verify(checkConfig, getPath("InputVisibilityModifierImmutableSameTypeName.java"),
+                expected);
     }
 
     @Test
     public void testImmutableStarImportFalseNegative() throws Exception {
         final DefaultConfiguration checkConfig =
-                createCheckConfig(VisibilityModifierCheck.class);
+                createModuleConfig(VisibilityModifierCheck.class);
         checkConfig.addAttribute("allowPublicImmutableFields", "true");
         checkConfig.addAttribute("immutableClassCanonicalNames", "java.util.Arrays");
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
-        verify(checkConfig, getPath("InputImmutableStarImport.java"), expected);
+        verify(checkConfig, getPath("InputVisibilityModifierImmutableStarImport.java"), expected);
     }
 
     @Test
     public void testImmutableStarImportNoWarn() throws Exception {
         final DefaultConfiguration checkConfig =
-                createCheckConfig(VisibilityModifierCheck.class);
+                createModuleConfig(VisibilityModifierCheck.class);
         checkConfig.addAttribute("allowPublicImmutableFields", "true");
         checkConfig.addAttribute("immutableClassCanonicalNames",
             "java.lang.String, com.google.common.collect.ImmutableSet");
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
-        verify(checkConfig, getPath("InputImmutableStarImport2.java"), expected);
+        verify(checkConfig, getPath("InputVisibilityModifierImmutableStarImport2.java"),
+                expected);
     }
 
     @Test
     public void testDefaultAnnotationPatterns() throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(VisibilityModifierCheck.class);
+            createModuleConfig(VisibilityModifierCheck.class);
         final String[] expected = {
             "40:19: " + getCheckMessage(MSG_KEY, "customAnnotatedPublic"),
             "43:12: " + getCheckMessage(MSG_KEY, "customAnnotatedPackage"),
@@ -247,16 +257,16 @@ public class VisibilityModifierCheckTest
             "49:12: " + getCheckMessage(MSG_KEY, "unannotatedPackage"),
             "50:22: " + getCheckMessage(MSG_KEY, "unannotatedProtected"),
         };
-        verify(checkConfig, getPath("InputAnnotatedVisibility.java"), expected);
+        verify(checkConfig, getPath("InputVisibilityModifierAnnotated.java"), expected);
     }
 
     @Test
     public void testCustomAnnotationPatterns() throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(VisibilityModifierCheck.class);
+            createModuleConfig(VisibilityModifierCheck.class);
         checkConfig.addAttribute("ignoreAnnotationCanonicalNames",
                 "com.puppycrawl.tools.checkstyle.checks.design."
-                    + "InputAnnotatedVisibility.CustomAnnotation");
+                    + "InputVisibilityModifierAnnotated.CustomAnnotation");
         final String[] expected = {
             "16:28: " + getCheckMessage(MSG_KEY, "publicJUnitRule"),
             "19:28: " + getCheckMessage(MSG_KEY, "fqPublicJUnitRule"),
@@ -272,13 +282,13 @@ public class VisibilityModifierCheckTest
             "59:35: " + getCheckMessage(MSG_KEY, "publicJUnitClassRule"),
             "62:35: " + getCheckMessage(MSG_KEY, "fqPublicJUnitClassRule"),
         };
-        verify(checkConfig, getPath("InputAnnotatedVisibility.java"), expected);
+        verify(checkConfig, getPath("InputVisibilityModifierAnnotated.java"), expected);
     }
 
     @Test
     public void testIgnoreAnnotationNoPattern() throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(VisibilityModifierCheck.class);
+            createModuleConfig(VisibilityModifierCheck.class);
         checkConfig.addAttribute("ignoreAnnotationCanonicalNames", "");
         final String[] expected = {
             "16:28: " + getCheckMessage(MSG_KEY, "publicJUnitRule"),
@@ -298,18 +308,19 @@ public class VisibilityModifierCheckTest
             "59:35: " + getCheckMessage(MSG_KEY, "publicJUnitClassRule"),
             "62:35: " + getCheckMessage(MSG_KEY, "fqPublicJUnitClassRule"),
         };
-        verify(checkConfig, getPath("InputAnnotatedVisibility.java"), expected);
+        verify(checkConfig, getPath("InputVisibilityModifierAnnotated.java"), expected);
     }
 
     @Test
     public void testIgnoreAnnotationSameName() throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(VisibilityModifierCheck.class);
+            createModuleConfig(VisibilityModifierCheck.class);
         final String[] expected = {
             "11:28: " + getCheckMessage(MSG_KEY, "publicJUnitRule"),
             "14:28: " + getCheckMessage(MSG_KEY, "publicJUnitClassRule"),
         };
-        verify(checkConfig, getPath("InputAnnotatedVisibilitySameTypeName.java"), expected);
+        verify(checkConfig, getPath("InputVisibilityModifierAnnotatedSameTypeName.java"),
+                expected);
     }
 
     @Test
@@ -319,13 +330,14 @@ public class VisibilityModifierCheckTest
             TokenTypes.VARIABLE_DEF,
             TokenTypes.IMPORT,
         };
-        assertArrayEquals(expected, obj.getAcceptableTokens());
+        assertArrayEquals("Default acceptable tokens are invalid",
+            expected, obj.getAcceptableTokens());
     }
 
     @Test
     public void testPublicImmutableFieldsNotAllowed() throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(VisibilityModifierCheck.class);
+            createModuleConfig(VisibilityModifierCheck.class);
         final String[] expected = {
             "10:22: " + getCheckMessage(MSG_KEY, "someIntValue"),
             "11:39: " + getCheckMessage(MSG_KEY, "includes"),
@@ -333,13 +345,13 @@ public class VisibilityModifierCheckTest
             "13:29: " + getCheckMessage(MSG_KEY, "value"),
             "14:23: " + getCheckMessage(MSG_KEY, "list"),
         };
-        verify(checkConfig, getPath("InputPublicImmutable.java"), expected);
+        verify(checkConfig, getPath("InputVisibilityModifiersPublicImmutable.java"), expected);
     }
 
     @Test
     public void testPublicFinalFieldsNotAllowed() throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(VisibilityModifierCheck.class);
+            createModuleConfig(VisibilityModifierCheck.class);
         final String[] expected = {
             "10:22: " + getCheckMessage(MSG_KEY, "someIntValue"),
             "11:39: " + getCheckMessage(MSG_KEY, "includes"),
@@ -347,29 +359,29 @@ public class VisibilityModifierCheckTest
             "13:29: " + getCheckMessage(MSG_KEY, "value"),
             "14:23: " + getCheckMessage(MSG_KEY, "list"),
         };
-        verify(checkConfig, getPath("InputPublicImmutable.java"), expected);
+        verify(checkConfig, getPath("InputVisibilityModifiersPublicImmutable.java"), expected);
     }
 
     @Test
     public void testPublicFinalFieldsAllowed() throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(VisibilityModifierCheck.class);
+            createModuleConfig(VisibilityModifierCheck.class);
         checkConfig.addAttribute("allowPublicFinalFields", "true");
         checkConfig.addAttribute("immutableClassCanonicalNames",
             "com.google.common.collect.ImmutableSet");
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
-        verify(checkConfig, getPath("InputPublicImmutable.java"), expected);
+        verify(checkConfig, getPath("InputVisibilityModifiersPublicImmutable.java"), expected);
     }
 
     @Test
     public void testPublicFinalFieldInEnum() throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(VisibilityModifierCheck.class);
+            createModuleConfig(VisibilityModifierCheck.class);
         checkConfig.addAttribute("allowPublicImmutableFields", "true");
         final String[] expected = {
             "15:23: " + getCheckMessage(MSG_KEY, "hole"),
         };
-        verify(checkConfig, getPath("InputEnumIsSealed.java"), expected);
+        verify(checkConfig, getPath("InputVisibilityModifiersEnumIsSealed.java"), expected);
     }
 
     @Test
@@ -382,25 +394,26 @@ public class VisibilityModifierCheckTest
             fail("exception expected");
         }
         catch (IllegalArgumentException ex) {
-            assertEquals("Unexpected token type: class", ex.getMessage());
+            assertEquals("Invalid exception message",
+                "Unexpected token type: class", ex.getMessage());
         }
     }
 
     @Test
     public void testNullModifiers() throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(VisibilityModifierCheck.class);
+            createModuleConfig(VisibilityModifierCheck.class);
         checkConfig.addAttribute("allowPublicImmutableFields", "true");
         final String[] expected = {
             "11:50: " + getCheckMessage(MSG_KEY, "i"),
         };
-        verify(checkConfig, getPath("InputNullModifiers.java"), expected);
+        verify(checkConfig, getPath("InputVisibilityModifiersNullModifiers.java"), expected);
     }
 
     @Test
     public void testVisibilityModifiersOfGenericFields() throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(VisibilityModifierCheck.class);
+            createModuleConfig(VisibilityModifierCheck.class);
         checkConfig.addAttribute("allowPublicImmutableFields", "true");
         checkConfig.addAttribute("immutableClassCanonicalNames",
             "com.google.common.collect.ImmutableMap,"
@@ -430,4 +443,27 @@ public class VisibilityModifierCheckTest
         };
         verify(checkConfig, getPath("InputVisibilityModifierGenerics.java"), expected);
     }
+
+    /**
+     * We can not cover this mutation because it force all imports to be non static,
+     * but static imports are ignored, so we will not see any affect on validation.
+     * We could remove this method at all, and it will work correctly as we can not use
+     * class with name "", but in this case internal collection will have short names
+     * as "" that will not make problems, but will be weird in debug.
+     *
+     * @throws Exception when exception occurred during execution.
+     */
+    @Test
+    public void testIsStarImportNullAst() throws Exception {
+        final DetailAST importAst = JavaParser.parseFile(
+            new File(getPath("InputVisibilityModifierIsStarImport.java")),
+            JavaParser.Options.WITHOUT_COMMENTS).getNextSibling();
+        final VisibilityModifierCheck check = new VisibilityModifierCheck();
+        final Method isStarImport = Whitebox.getMethod(VisibilityModifierCheck.class,
+            "isStarImport", DetailAST.class);
+
+        assertTrue("Should return true when star import is passed",
+            (boolean) isStarImport.invoke(check, importAst));
+    }
+
 }
