@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2017 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -27,40 +27,28 @@ import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 
 import java.io.File;
-import java.io.IOException;
+import java.nio.charset.StandardCharsets;
+import java.nio.file.Files;
 
 import org.junit.Rule;
 import org.junit.Test;
 import org.junit.rules.TemporaryFolder;
 
-import com.puppycrawl.tools.checkstyle.BaseCheckTestSupport;
-import com.puppycrawl.tools.checkstyle.BriefUtLogger;
-import com.puppycrawl.tools.checkstyle.Checker;
+import com.puppycrawl.tools.checkstyle.AbstractModuleTestSupport;
 import com.puppycrawl.tools.checkstyle.DefaultConfiguration;
 import com.puppycrawl.tools.checkstyle.TreeWalker;
 import com.puppycrawl.tools.checkstyle.api.CheckstyleException;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
 import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
 
-public class ImportControlCheckTest extends BaseCheckTestSupport {
+public class ImportControlCheckTest extends AbstractModuleTestSupport {
 
     @Rule
     public final TemporaryFolder temporaryFolder = new TemporaryFolder();
 
     @Override
-    protected String getPath(String filename) throws IOException {
-        return super.getPath("checks" + File.separator
-                + "imports" + File.separator + filename);
-    }
-
-    @Override
-    protected String getUriString(String filename) {
-        return super.getUriString("checks" + File.separator
-                + "imports" + File.separator + filename);
-    }
-
-    private static String getResourcePath(String filename) {
-        return "/com/puppycrawl/tools/checkstyle/checks/imports/" + filename;
+    protected String getPackageLocation() {
+        return "com/puppycrawl/tools/checkstyle/checks/imports/importcontrol";
     }
 
     @Test
@@ -71,13 +59,14 @@ public class ImportControlCheckTest extends BaseCheckTestSupport {
             TokenTypes.IMPORT,
             TokenTypes.STATIC_IMPORT,
         };
-        assertArrayEquals(expected, checkObj.getRequiredTokens());
+        assertArrayEquals("Default required tokens are invalid",
+            expected, checkObj.getRequiredTokens());
     }
 
     @Test
     public void testOne() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(ImportControlCheck.class);
-        checkConfig.addAttribute("file", getPath("import-control_one.xml"));
+        final DefaultConfiguration checkConfig = createModuleConfig(ImportControlCheck.class);
+        checkConfig.addAttribute("file", getPath("InputImportControlOne.xml"));
         final String[] expected = {"5:1: " + getCheckMessage(MSG_DISALLOWED, "java.io.File")};
 
         verify(checkConfig, getPath("InputImportControl.java"), expected);
@@ -85,8 +74,8 @@ public class ImportControlCheckTest extends BaseCheckTestSupport {
 
     @Test
     public void testTwo() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(ImportControlCheck.class);
-        checkConfig.addAttribute("file", getPath("import-control_two.xml"));
+        final DefaultConfiguration checkConfig = createModuleConfig(ImportControlCheck.class);
+        checkConfig.addAttribute("file", getPath("InputImportControlTwo.xml"));
         final String[] expected = {
             "3:1: " + getCheckMessage(MSG_DISALLOWED, "java.awt.Image"),
             "4:1: " + getCheckMessage(MSG_DISALLOWED, "javax.swing.border.*"),
@@ -98,22 +87,22 @@ public class ImportControlCheckTest extends BaseCheckTestSupport {
 
     @Test
     public void testWrong() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(ImportControlCheck.class);
-        checkConfig.addAttribute("file", getPath("import-control_wrong.xml"));
+        final DefaultConfiguration checkConfig = createModuleConfig(ImportControlCheck.class);
+        checkConfig.addAttribute("file", getPath("InputImportControlWrong.xml"));
         final String[] expected = {"1:1: " + getCheckMessage(MSG_UNKNOWN_PKG)};
         verify(checkConfig, getPath("InputImportControl.java"), expected);
     }
 
     @Test
     public void testMissing() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(ImportControlCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(ImportControlCheck.class);
         final String[] expected = {"1:1: " + getCheckMessage(MSG_MISSING_FILE)};
         verify(checkConfig, getPath("InputImportControl.java"), expected);
     }
 
     @Test
     public void testEmpty() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(ImportControlCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(ImportControlCheck.class);
         checkConfig.addAttribute("file", "   ");
         final String[] expected = {"1:1: " + getCheckMessage(MSG_MISSING_FILE)};
         verify(checkConfig, getPath("InputImportControl.java"), expected);
@@ -121,7 +110,7 @@ public class ImportControlCheckTest extends BaseCheckTestSupport {
 
     @Test
     public void testNull() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(ImportControlCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(ImportControlCheck.class);
         checkConfig.addAttribute("file", null);
         final String[] expected = {"1:1: " + getCheckMessage(MSG_MISSING_FILE)};
         verify(checkConfig, getPath("InputImportControl.java"), expected);
@@ -129,7 +118,7 @@ public class ImportControlCheckTest extends BaseCheckTestSupport {
 
     @Test
     public void testUnknown() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(ImportControlCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(ImportControlCheck.class);
         checkConfig.addAttribute("file", "unknown-file");
         try {
             final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
@@ -138,14 +127,17 @@ public class ImportControlCheckTest extends BaseCheckTestSupport {
         }
         catch (CheckstyleException ex) {
             final String message = getCheckstyleExceptionMessage(ex);
-            assertTrue(message.startsWith("Unable to find: "));
+            final String messageStart = "Unable to find: ";
+
+            assertTrue("Invalid message, should start with: " + messageStart,
+                message.startsWith(message));
         }
     }
 
     @Test
     public void testBroken() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(ImportControlCheck.class);
-        checkConfig.addAttribute("file", getPath("import-control_broken.xml"));
+        final DefaultConfiguration checkConfig = createModuleConfig(ImportControlCheck.class);
+        checkConfig.addAttribute("file", getPath("InputImportControlBroken.xml"));
         try {
             final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
             verify(checkConfig, getPath("InputImportControl.java"), expected);
@@ -153,14 +145,17 @@ public class ImportControlCheckTest extends BaseCheckTestSupport {
         }
         catch (CheckstyleException ex) {
             final String message = getCheckstyleExceptionMessage(ex);
-            assertTrue(message.startsWith("Unable to load "));
+            final String messageStart = "Unable to load ";
+
+            assertTrue("Invalid message, should start with: " + messageStart,
+                message.startsWith(message));
         }
     }
 
     @Test
     public void testOneRegExp() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(ImportControlCheck.class);
-        checkConfig.addAttribute("file", getPath("import-control_one-re.xml"));
+        final DefaultConfiguration checkConfig = createModuleConfig(ImportControlCheck.class);
+        checkConfig.addAttribute("file", getPath("InputImportControlOneRegExp.xml"));
         final String[] expected = {"5:1: " + getCheckMessage(MSG_DISALLOWED, "java.io.File")};
 
         verify(checkConfig, getPath("InputImportControl.java"), expected);
@@ -168,8 +163,8 @@ public class ImportControlCheckTest extends BaseCheckTestSupport {
 
     @Test
     public void testTwoRegExp() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(ImportControlCheck.class);
-        checkConfig.addAttribute("file", getPath("import-control_two-re.xml"));
+        final DefaultConfiguration checkConfig = createModuleConfig(ImportControlCheck.class);
+        checkConfig.addAttribute("file", getPath("InputImportControlTwoRegExp.xml"));
         final String[] expected = {
             "3:1: " + getCheckMessage(MSG_DISALLOWED, "java.awt.Image"),
             "4:1: " + getCheckMessage(MSG_DISALLOWED, "javax.swing.border.*"),
@@ -179,24 +174,86 @@ public class ImportControlCheckTest extends BaseCheckTestSupport {
         verify(checkConfig, getPath("InputImportControl.java"), expected);
     }
 
+    @Test
+    public void testBlacklist() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(ImportControlCheck.class);
+        checkConfig.addAttribute("file", getPath("InputImportControlBlacklist.xml"));
+        final String[] expected = {
+            "3:1: " + getCheckMessage(MSG_DISALLOWED, "java.util.stream.Stream"),
+            "4:1: " + getCheckMessage(MSG_DISALLOWED, "java.util.Date"),
+            "6:1: " + getCheckMessage(MSG_DISALLOWED, "java.util.stream.Collectors"),
+            "7:1: " + getCheckMessage(MSG_DISALLOWED, "java.util.stream.IntStream"),
+        };
+
+        verify(checkConfig, getPath("InputImportControl_Blacklist.java"), expected);
+    }
+
+    @Test
+    public void testStrategyOnMismatchOne() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(ImportControlCheck.class);
+        checkConfig.addAttribute("file", getPath("InputImportControlStrategyOnMismatchOne.xml"));
+        final String[] expected = {
+            "3:1: " + getCheckMessage(MSG_DISALLOWED, "java.awt.Image"),
+            "4:1: " + getCheckMessage(MSG_DISALLOWED, "javax.swing.border.*"),
+            "6:1: " + getCheckMessage(MSG_DISALLOWED, "java.awt.Button.ABORT"),
+        };
+
+        verify(checkConfig, getPath("InputImportControl.java"), expected);
+    }
+
+    @Test
+    public void testStrategyOnMismatchTwo() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(ImportControlCheck.class);
+        checkConfig.addAttribute("file", getPath("InputImportControlStrategyOnMismatchTwo.xml"));
+        final String[] expected = {
+            "3:1: " + getCheckMessage(MSG_DISALLOWED, "java.awt.Image"),
+            "6:1: " + getCheckMessage(MSG_DISALLOWED, "java.awt.Button.ABORT"),
+        };
+
+        verify(checkConfig, getPath("InputImportControl.java"), expected);
+    }
+
+    @Test
+    public void testStrategyOnMismatchThree() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(ImportControlCheck.class);
+        checkConfig.addAttribute("file", getPath("InputImportControlStrategyOnMismatchThree.xml"));
+        final String[] expected = {
+            "3:1: " + getCheckMessage(MSG_DISALLOWED, "java.awt.Image"),
+        };
+
+        verify(checkConfig, getPath("InputImportControl.java"), expected);
+    }
+
+    @Test
+    public void testStrategyOnMismatchFour() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(ImportControlCheck.class);
+        checkConfig.addAttribute("file", getPath("InputImportControlStrategyOnMismatchFour.xml"));
+        final String[] expected = {
+            "3:1: " + getCheckMessage(MSG_DISALLOWED, "java.awt.Image"),
+            "4:1: " + getCheckMessage(MSG_DISALLOWED, "javax.swing.border.*"),
+        };
+
+        verify(checkConfig, getPath("InputImportControl.java"), expected);
+    }
+
     @Test
     public void testPkgRegExpInParent() throws Exception {
-        testRegExpInPackage("import-control_pkg-re-in-parent.xml");
+        testRegExpInPackage("InputImportControlPkgRegExpInParent.xml");
     }
 
     @Test
     public void testPkgRegExpInChild() throws Exception {
-        testRegExpInPackage("import-control_pkg-re-in-child.xml");
+        testRegExpInPackage("InputImportControlPkgRegExpInChild.xml");
     }
 
     @Test
     public void testPkgRegExpInBoth() throws Exception {
-        testRegExpInPackage("import-control_pkg-re-in-both.xml");
+        testRegExpInPackage("InputImportControlPkgRegExpInBoth.xml");
     }
 
     // all import-control_pkg-re* files should be equivalent so use one test for all
     private void testRegExpInPackage(String file) throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(ImportControlCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(ImportControlCheck.class);
         checkConfig.addAttribute("file", getPath(file));
         final String[] expected = {"5:1: " + getCheckMessage(MSG_DISALLOWED, "java.io.File")};
 
@@ -214,72 +271,13 @@ public class ImportControlCheckTest extends BaseCheckTestSupport {
             TokenTypes.STATIC_IMPORT,
         };
 
-        assertArrayEquals(expected, actual);
-    }
-
-    @Test
-    public void testUrl() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(ImportControlCheck.class);
-        checkConfig.addAttribute("url", getUriString("import-control_one.xml"));
-        final String[] expected = {"5:1: " + getCheckMessage(MSG_DISALLOWED, "java.io.File")};
-
-        verify(checkConfig, getPath("InputImportControl.java"), expected);
-    }
-
-    @Test
-    public void testUrlBlank() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(ImportControlCheck.class);
-        checkConfig.addAttribute("url", "");
-        final String[] expected = {"1:1: " + getCheckMessage(MSG_MISSING_FILE)};
-
-        verify(checkConfig, getPath("InputImportControl.java"), expected);
-    }
-
-    @Test
-    public void testUrlNull() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(ImportControlCheck.class);
-        checkConfig.addAttribute("url", null);
-        final String[] expected = {"1:1: " + getCheckMessage(MSG_MISSING_FILE)};
-
-        verify(checkConfig, getPath("InputImportControl.java"), expected);
-    }
-
-    @Test
-    public void testUrlUnableToLoad() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(ImportControlCheck.class);
-        checkConfig.addAttribute("url", "https://UnableToLoadThisURL");
-
-        try {
-            final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
-            verify(checkConfig, getPath("InputImportControl.java"), expected);
-            fail("Test should fail if exception was not thrown");
-        }
-        catch (final CheckstyleException ex) {
-            final String message = getCheckstyleExceptionMessage(ex);
-            assertTrue(message.startsWith("Unable to load "));
-        }
-    }
-
-    @Test
-    public void testUrlIncorrectUrl() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(ImportControlCheck.class);
-        checkConfig.addAttribute("url", "https://{WrongCharsInURL}");
-
-        try {
-            final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
-            verify(checkConfig, getPath("InputImportControl.java"), expected);
-            fail("Test should fail if exception was not thrown");
-        }
-        catch (final CheckstyleException ex) {
-            final String message = getCheckstyleExceptionMessage(ex);
-            assertTrue(message.startsWith("Unable to find: "));
-        }
+        assertArrayEquals("Default acceptable tokens are invalid", expected, actual);
     }
 
     @Test
     public void testResource() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(ImportControlCheck.class);
-        checkConfig.addAttribute("file", getResourcePath("import-control_one.xml"));
+        final DefaultConfiguration checkConfig = createModuleConfig(ImportControlCheck.class);
+        checkConfig.addAttribute("file", getResourcePath("InputImportControlOne.xml"));
         final String[] expected = {"5:1: " + getCheckMessage(MSG_DISALLOWED, "java.io.File")};
 
         verify(checkConfig, getPath("InputImportControl.java"), expected);
@@ -287,7 +285,7 @@ public class ImportControlCheckTest extends BaseCheckTestSupport {
 
     @Test
     public void testResourceUnableToLoad() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(ImportControlCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(ImportControlCheck.class);
         checkConfig.addAttribute("file", getResourcePath("import-control_unknown.xml"));
 
         try {
@@ -295,16 +293,19 @@ public class ImportControlCheckTest extends BaseCheckTestSupport {
             verify(checkConfig, getPath("InputImportControl.java"), expected);
             fail("Test should fail if exception was not thrown");
         }
-        catch (final CheckstyleException ex) {
+        catch (CheckstyleException ex) {
             final String message = getCheckstyleExceptionMessage(ex);
-            assertTrue(message.startsWith("Unable to find: "));
+            final String messageStart = "Unable to find: ";
+
+            assertTrue("Invalid message, should start with: " + messageStart,
+                message.startsWith(message));
         }
     }
 
     @Test
     public void testUrlInFileProperty() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(ImportControlCheck.class);
-        checkConfig.addAttribute("file", getUriString("import-control_one.xml"));
+        final DefaultConfiguration checkConfig = createModuleConfig(ImportControlCheck.class);
+        checkConfig.addAttribute("file", getUriString("InputImportControlOne.xml"));
         final String[] expected = {"5:1: " + getCheckMessage(MSG_DISALLOWED, "java.io.File")};
 
         verify(checkConfig, getPath("InputImportControl.java"), expected);
@@ -312,7 +313,7 @@ public class ImportControlCheckTest extends BaseCheckTestSupport {
 
     @Test
     public void testUrlInFilePropertyUnableToLoad() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(ImportControlCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(ImportControlCheck.class);
         checkConfig.addAttribute("file", "https://UnableToLoadThisURL");
 
         try {
@@ -320,46 +321,43 @@ public class ImportControlCheckTest extends BaseCheckTestSupport {
             verify(checkConfig, getPath("InputImportControl.java"), expected);
             fail("Test should fail if exception was not thrown");
         }
-        catch (final CheckstyleException ex) {
+        catch (CheckstyleException ex) {
             final String message = getCheckstyleExceptionMessage(ex);
-            assertTrue(message.startsWith("Unable to load "));
+            final String messageStart = "Unable to load ";
+
+            assertTrue("Invalid message, should start with: " + messageStart,
+                message.startsWith(message));
         }
     }
 
     @Test
     public void testCacheWhenFileExternalResourceContentDoesNotChange() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(ImportControlCheck.class);
-        checkConfig.addAttribute("file", getPath("import-control_one-re.xml"));
+        final DefaultConfiguration checkConfig = createModuleConfig(ImportControlCheck.class);
+        checkConfig.addAttribute("file", getPath("InputImportControlOneRegExp.xml"));
 
-        final Checker checker = createMockCheckerWithCache(checkConfig);
+        final DefaultConfiguration treeWalkerConfig = createModuleConfig(TreeWalker.class);
+        treeWalkerConfig.addChild(checkConfig);
+
+        final DefaultConfiguration checkerConfig = createRootConfig(treeWalkerConfig);
+        final File cacheFile = temporaryFolder.newFile();
+        checkerConfig.addAttribute("cacheFile", cacheFile.getPath());
 
         final String filePath = temporaryFolder.newFile("EmptyFile.java").getPath();
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
 
-        verify(checker, filePath, filePath, expected);
+        verify(checkerConfig, filePath, expected);
         // One more time to use cache.
-        verify(checker, filePath, filePath, expected);
-    }
+        verify(checkerConfig, filePath, expected);
 
-    @Test
-    public void testCacheWhenUrlExternalResourceContentDoesNotChange() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(ImportControlCheck.class);
-        checkConfig.addAttribute("url", getUriString("import-control_one.xml"));
-
-        final Checker checker = createMockCheckerWithCache(checkConfig);
-
-        final String pathToEmptyFile = temporaryFolder.newFile("TestFile.java").getPath();
-        final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
-
-        verify(checker, pathToEmptyFile, pathToEmptyFile, expected);
-        // One more time to use cache.
-        verify(checker, pathToEmptyFile, pathToEmptyFile, expected);
+        assertTrue("External resource is not present in cache",
+                new String(Files.readAllBytes(cacheFile.toPath()),
+                        StandardCharsets.UTF_8).contains("InputImportControlOneRegExp.xml"));
     }
 
     @Test
     public void testPathRegexMatches() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(ImportControlCheck.class);
-        checkConfig.addAttribute("file", getResourcePath("import-control_one.xml"));
+        final DefaultConfiguration checkConfig = createModuleConfig(ImportControlCheck.class);
+        checkConfig.addAttribute("file", getResourcePath("InputImportControlOne.xml"));
         checkConfig.addAttribute("path", "^.*[\\\\/]src[\\\\/]test[\\\\/].*$");
         final String[] expected = {"5:1: " + getCheckMessage(MSG_DISALLOWED, "java.io.File")};
 
@@ -368,8 +366,8 @@ public class ImportControlCheckTest extends BaseCheckTestSupport {
 
     @Test
     public void testPathRegexMatchesPartially() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(ImportControlCheck.class);
-        checkConfig.addAttribute("file", getResourcePath("import-control_one.xml"));
+        final DefaultConfiguration checkConfig = createModuleConfig(ImportControlCheck.class);
+        checkConfig.addAttribute("file", getResourcePath("InputImportControlOne.xml"));
         checkConfig.addAttribute("path", "[\\\\/]InputImportControl\\.java");
         final String[] expected = {"5:1: " + getCheckMessage(MSG_DISALLOWED, "java.io.File")};
 
@@ -378,8 +376,8 @@ public class ImportControlCheckTest extends BaseCheckTestSupport {
 
     @Test
     public void testPathRegexDoesntMatch() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(ImportControlCheck.class);
-        checkConfig.addAttribute("file", getResourcePath("import-control_one.xml"));
+        final DefaultConfiguration checkConfig = createModuleConfig(ImportControlCheck.class);
+        checkConfig.addAttribute("file", getResourcePath("InputImportControlOne.xml"));
         checkConfig.addAttribute("path", "^.*[\\\\/]src[\\\\/]main[\\\\/].*$");
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
 
@@ -388,30 +386,14 @@ public class ImportControlCheckTest extends BaseCheckTestSupport {
 
     @Test
     public void testPathRegexDoesntMatchPartially() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(ImportControlCheck.class);
-        checkConfig.addAttribute("file", getResourcePath("import-control_one.xml"));
+        final DefaultConfiguration checkConfig = createModuleConfig(ImportControlCheck.class);
+        checkConfig.addAttribute("file", getResourcePath("InputImportControlOne.xml"));
         checkConfig.addAttribute("path", "[\\\\/]NoMatch\\.java");
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
 
         verify(checkConfig, getPath("InputImportControl.java"), expected);
     }
 
-    private Checker createMockCheckerWithCache(DefaultConfiguration checkConfig)
-            throws IOException, CheckstyleException {
-        final DefaultConfiguration treeWalkerConfig = createCheckConfig(TreeWalker.class);
-        treeWalkerConfig.addChild(checkConfig);
-
-        final DefaultConfiguration checkerConfig = new DefaultConfiguration("checkstyle_checks");
-        checkerConfig.addChild(treeWalkerConfig);
-        checkerConfig.addAttribute("cacheFile", temporaryFolder.newFile().getPath());
-
-        final Checker checker = new Checker();
-        checker.setModuleClassLoader(Thread.currentThread().getContextClassLoader());
-        checker.configure(checkerConfig);
-        checker.addListener(new BriefUtLogger(stream));
-        return checker;
-    }
-
     /**
      * Returns String message of original exception that was thrown in
      * ImportControlCheck.setUrl or ImportControlCheck.setFile
@@ -424,4 +406,5 @@ public class ImportControlCheckTest extends BaseCheckTestSupport {
     private static String getCheckstyleExceptionMessage(CheckstyleException exception) {
         return exception.getCause().getCause().getCause().getMessage();
     }
+
 }
