@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2017 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -23,35 +23,56 @@ import static com.puppycrawl.tools.checkstyle.checks.imports.UnusedImportsCheck.
 import static org.junit.Assert.assertArrayEquals;
 
 import java.io.File;
-import java.io.IOException;
+import java.util.Arrays;
+import java.util.List;
 
 import org.junit.Test;
 
-import com.puppycrawl.tools.checkstyle.BaseCheckTestSupport;
+import com.google.common.collect.ImmutableMap;
+import com.puppycrawl.tools.checkstyle.AbstractModuleTestSupport;
 import com.puppycrawl.tools.checkstyle.DefaultConfiguration;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
 import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
 
-public class UnusedImportsCheckTest extends BaseCheckTestSupport {
-    @Override
-    protected String getPath(String filename) throws IOException {
-        return super.getPath("checks" + File.separator
-                + "imports" + File.separator + filename);
-    }
+public class UnusedImportsCheckTest extends AbstractModuleTestSupport {
 
     @Override
-    protected String getNonCompilablePath(String filename) throws IOException {
-        return super.getNonCompilablePath("checks" + File.separator
-                + "imports" + File.separator + filename);
+    protected String getPackageLocation() {
+        return "com/puppycrawl/tools/checkstyle/checks/imports/unusedimports";
+    }
+
+    @Test
+    public void testReferencedStateIsCleared() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(UnusedImportsCheck.class);
+        final String inputWithoutWarnings = getPath("InputUnusedImportsWithoutWarnings.java");
+        final String inputWithWarnings = getPath("InputUnusedImportsCheckClearState.java");
+        final List<String> expectedFirstInput = Arrays.asList(CommonUtils.EMPTY_STRING_ARRAY);
+        final List<String> expectedSecondInput = Arrays.asList(
+                "3:8: " + getCheckMessage(MSG_KEY, "java.util.Arrays"),
+                "4:8: " + getCheckMessage(MSG_KEY, "java.util.List"),
+                "5:8: " + getCheckMessage(MSG_KEY, "java.util.Set")
+        );
+        final File[] inputsWithWarningsFirst =
+            {new File(inputWithWarnings), new File(inputWithoutWarnings)};
+        final File[] inputsWithoutWarningFirst =
+            {new File(inputWithoutWarnings), new File(inputWithWarnings)};
+
+        verify(createChecker(checkConfig), inputsWithWarningsFirst, ImmutableMap.of(
+                inputWithoutWarnings, expectedFirstInput,
+                inputWithWarnings, expectedSecondInput));
+        verify(createChecker(checkConfig), inputsWithoutWarningFirst, ImmutableMap.of(
+                inputWithoutWarnings, expectedFirstInput,
+                inputWithWarnings, expectedSecondInput));
     }
 
     @Test
     public void testWithoutProcessJavadoc() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(UnusedImportsCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(UnusedImportsCheck.class);
         checkConfig.addAttribute("processJavadoc", "false");
         final String[] expected = {
             "8:45: " + getCheckMessage(MSG_KEY,
-                "com.puppycrawl.tools.checkstyle.checks.imports.InputImportBug"),
+                "com.puppycrawl.tools.checkstyle.checks."
+                + "imports.unusedimports.InputUnusedImportsBug"),
             "11:8: " + getCheckMessage(MSG_KEY, "java.lang.String"),
             "13:8: " + getCheckMessage(MSG_KEY, "java.util.List"),
             "14:8: " + getCheckMessage(MSG_KEY, "java.util.List"),
@@ -68,28 +89,28 @@ public class UnusedImportsCheckTest extends BaseCheckTestSupport {
             "35:8: " + getCheckMessage(MSG_KEY, "java.util.BitSet"),
             "37:8: " + getCheckMessage(MSG_KEY, "com.puppycrawl.tools.checkstyle.Checker"),
             "38:8: " + getCheckMessage(MSG_KEY, "com.puppycrawl.tools.checkstyle.CheckerTest"),
-            "39:8: " + getCheckMessage(MSG_KEY,
-                "com.puppycrawl.tools.checkstyle.BaseFileSetCheckTestSupport"),
-            "40:8: " + getCheckMessage(MSG_KEY, "com.puppycrawl.tools.checkstyle.Definitions"),
+            "39:8: " + getCheckMessage(MSG_KEY, "com.puppycrawl.tools.checkstyle.Definitions"),
+            "40:8: " + getCheckMessage(MSG_KEY,
+                "com.puppycrawl.tools.checkstyle.checks.imports.unusedimports."
+                        + "InputUnusedImports15Extensions"),
             "41:8: " + getCheckMessage(MSG_KEY,
-                "com.puppycrawl.tools.checkstyle.checks.Input15Extensions"),
-            "42:8: " + getCheckMessage(MSG_KEY,
                 "com.puppycrawl.tools.checkstyle.ConfigurationLoaderTest"),
-            "43:8: " + getCheckMessage(MSG_KEY,
+            "42:8: " + getCheckMessage(MSG_KEY,
                 "com.puppycrawl.tools.checkstyle.PackageNamesLoader"),
-            "44:8: " + getCheckMessage(MSG_KEY,
+            "43:8: " + getCheckMessage(MSG_KEY,
                 "com.puppycrawl.tools.checkstyle.DefaultConfiguration"),
-            "45:8: " + getCheckMessage(MSG_KEY, "com.puppycrawl.tools.checkstyle.DefaultLogger"),
+            "44:8: " + getCheckMessage(MSG_KEY, "com.puppycrawl.tools.checkstyle.DefaultLogger"),
         };
         verify(checkConfig, getPath("InputUnusedImports.java"), expected);
     }
 
     @Test
     public void testProcessJavadoc() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(UnusedImportsCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(UnusedImportsCheck.class);
         final String[] expected = {
             "8:45: " + getCheckMessage(MSG_KEY,
-                "com.puppycrawl.tools.checkstyle.checks.imports.InputImportBug"),
+                "com.puppycrawl.tools.checkstyle.checks."
+                        + "imports.unusedimports.InputUnusedImportsBug"),
             "11:8: " + getCheckMessage(MSG_KEY, "java.lang.String"),
             "13:8: " + getCheckMessage(MSG_KEY, "java.util.List"),
             "14:8: " + getCheckMessage(MSG_KEY, "java.util.List"),
@@ -99,30 +120,44 @@ public class UnusedImportsCheckTest extends BaseCheckTestSupport {
             "27:15: " + getCheckMessage(MSG_KEY, "java.io.File.createTempFile"),
             //"29:8: Unused import - java.awt.Component.", // Should be detected
             "32:8: " + getCheckMessage(MSG_KEY, "java.awt.Label"),
-            "45:8: " + getCheckMessage(MSG_KEY, "com.puppycrawl.tools.checkstyle.DefaultLogger"),
+            "44:8: " + getCheckMessage(MSG_KEY, "com.puppycrawl.tools.checkstyle.DefaultLogger"),
         };
         verify(checkConfig, getPath("InputUnusedImports.java"), expected);
     }
 
     @Test
     public void testProcessJavadocWithLinkTag() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(UnusedImportsCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(UnusedImportsCheck.class);
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
-        verify(checkConfig, getPath("InputUnusedImportWithValueTag.java"), expected);
+        verify(checkConfig, getPath("InputUnusedImportsWithValueTag.java"), expected);
+    }
+
+    @Test
+    public void testProcessJavadocWithBlockTagContainingMethodParameters() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(UnusedImportsCheck.class);
+        final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
+        verify(checkConfig, getPath("InputUnusedImportsWithBlockMethodParameters.java"), expected);
     }
 
     @Test
     public void testAnnotations() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(UnusedImportsCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(UnusedImportsCheck.class);
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
-        verify(checkConfig, getNonCompilablePath("package-info.java"), expected);
+        verify(checkConfig, getNonCompilablePath("InputUnusedImportsAnnotations.java"), expected);
     }
 
     @Test
     public void testBug() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(UnusedImportsCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(UnusedImportsCheck.class);
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
-        verify(checkConfig, getPath("InputImportBug.java"), expected);
+        verify(checkConfig, getPath("InputUnusedImportsBug.java"), expected);
+    }
+
+    @Test
+    public void testNewlinesInsideTags() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(UnusedImportsCheck.class);
+        final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
+        verify(checkConfig, getPath("InputUnusedImportsWithNewlinesInsideTags.java"), expected);
     }
 
     @Test
@@ -147,7 +182,7 @@ public class UnusedImportsCheckTest extends BaseCheckTestSupport {
             TokenTypes.VARIABLE_DEF,
         };
 
-        assertArrayEquals(expected, actual);
+        assertArrayEquals("Default required tokens are invalid", expected, actual);
     }
 
     @Test
@@ -172,23 +207,23 @@ public class UnusedImportsCheckTest extends BaseCheckTestSupport {
             TokenTypes.VARIABLE_DEF,
         };
 
-        assertArrayEquals(expected, actual);
+        assertArrayEquals("Default acceptable tokens are invalid", expected, actual);
     }
 
     @Test
     public void testFileInUnnamedPackage() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(UnusedImportsCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(UnusedImportsCheck.class);
         final String[] expected = {
             "5:8: " + getCheckMessage(MSG_KEY, "java.util.Arrays"),
             "6:8: " + getCheckMessage(MSG_KEY, "java.lang.String"),
         };
-        verify(checkConfig, getNonCompilablePath("InputRedundantImport_UnnamedPackage.java"),
+        verify(checkConfig, getNonCompilablePath("InputUnusedImportsFileInUnnamedPackage.java"),
             expected);
     }
 
     @Test
     public void testImportsFromJavaLang() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(UnusedImportsCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(UnusedImportsCheck.class);
         final String[] expected = {
             "3:8: " + getCheckMessage(MSG_KEY, "java.lang.String"),
             "4:8: " + getCheckMessage(MSG_KEY, "java.lang.Math"),
@@ -202,6 +237,16 @@ public class UnusedImportsCheckTest extends BaseCheckTestSupport {
             "12:8: " + getCheckMessage(MSG_KEY, "java.lang.Float"),
             "13:8: " + getCheckMessage(MSG_KEY, "java.lang.Short"),
         };
-        verify(checkConfig, getPath("InputUnusedImportFromJavaLang.java"), expected);
+        verify(checkConfig, getPath("InputUnusedImportsFromJavaLang.java"), expected);
     }
+
+    @Test
+    public void testImportsJavadocQualifiedName() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(UnusedImportsCheck.class);
+        final String[] expected = {
+            "4:8: " + getCheckMessage(MSG_KEY, "java.util.List"),
+        };
+        verify(checkConfig, getPath("InputUnusedImportsJavadocQualifiedName.java"), expected);
+    }
+
 }
