@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2017 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -24,35 +24,24 @@ import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 
-import java.io.File;
-import java.io.IOException;
 import java.lang.reflect.Constructor;
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
 
-import org.junit.Before;
 import org.junit.Test;
 
-import com.puppycrawl.tools.checkstyle.BaseCheckTestSupport;
+import com.puppycrawl.tools.checkstyle.AbstractModuleTestSupport;
 import com.puppycrawl.tools.checkstyle.DefaultConfiguration;
 import com.puppycrawl.tools.checkstyle.api.CheckstyleException;
-import com.puppycrawl.tools.checkstyle.checks.AbstractTypeAwareCheck;
 import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
 
-@SuppressWarnings("deprecation")
-public class AbstractTypeAwareCheckTest extends BaseCheckTestSupport {
-    private DefaultConfiguration checkConfig;
-
-    @Before
-    public void setUp() {
-        checkConfig = createCheckConfig(JavadocMethodCheck.class);
-    }
+public class AbstractTypeAwareCheckTest extends AbstractModuleTestSupport {
 
     @Override
-    protected String getPath(String filename) throws IOException {
-        return super.getPath("checks" + File.separator
-                + "javadoc" + File.separator + filename);
+    protected String getPackageLocation() {
+        return "com/puppycrawl/tools/checkstyle/checks/javadoc/abstracttypeaware";
     }
 
     @Test
@@ -61,53 +50,60 @@ public class AbstractTypeAwareCheckTest extends BaseCheckTestSupport {
         final Method isSubclass = check.getClass().getSuperclass()
                 .getDeclaredMethod("isSubclass", Class.class, Class.class);
         isSubclass.setAccessible(true);
-        assertFalse((boolean) isSubclass.invoke(check, null, null));
+        assertFalse("Should return false if at least one of the params is null",
+            (boolean) isSubclass.invoke(check, null, null));
     }
 
     @Test
     public void testTokenToString() throws Exception {
-        final Class<?> tokenType = Class
-                .forName("com.puppycrawl.tools.checkstyle.checks.AbstractTypeAwareCheck$Token");
+        final Class<?> tokenType = Class.forName("com.puppycrawl.tools.checkstyle.checks.javadoc."
+                + "AbstractTypeAwareCheck$Token");
         final Constructor<?> tokenConstructor = tokenType.getDeclaredConstructor(String.class,
                 int.class, int.class);
         final Object token = tokenConstructor.newInstance("blablabla", 1, 1);
         final Method toString = token.getClass().getDeclaredMethod("toString");
         final String result = (String) toString.invoke(token);
-        assertEquals("Token[blablabla(1x1)]", result);
+        assertEquals("Invalid toString result", "Token[blablabla(1x1)]", result);
     }
 
     @Test
     public void testClassRegularClass() throws Exception {
-        final Class<?> tokenType = Class
-                .forName("com.puppycrawl.tools.checkstyle.checks.AbstractTypeAwareCheck$Token");
+        final Class<?> tokenType = Class.forName("com.puppycrawl.tools.checkstyle.checks.javadoc."
+                + "AbstractTypeAwareCheck$Token");
 
         final Class<?> regularClassType = Class
-                .forName(
-                    "com.puppycrawl.tools.checkstyle.checks.AbstractTypeAwareCheck$RegularClass");
+                .forName("com.puppycrawl.tools.checkstyle.checks.javadoc."
+                        + "AbstractTypeAwareCheck$RegularClass");
         final Constructor<?> regularClassConstructor = regularClassType.getDeclaredConstructor(
                 tokenType, String.class, AbstractTypeAwareCheck.class);
         regularClassConstructor.setAccessible(true);
 
         try {
             regularClassConstructor.newInstance(null, "", new JavadocMethodCheck());
+            fail("Exception is expected");
         }
         catch (InvocationTargetException ex) {
-            assertTrue(ex.getCause() instanceof IllegalArgumentException);
-            assertEquals("ClassInfo's name should be non-null", ex.getCause().getMessage());
+            assertTrue("Invalid exception class, expected: IllegalArgumentException.class",
+                ex.getCause() instanceof IllegalArgumentException);
+            assertEquals("Invalid exception message",
+                "ClassInfo's name should be non-null", ex.getCause().getMessage());
         }
 
         final Constructor<?> tokenConstructor = tokenType.getDeclaredConstructor(String.class,
                 int.class, int.class);
         final Object token = tokenConstructor.newInstance("blablabla", 1, 1);
 
+        final JavadocMethodCheck methodCheck = new JavadocMethodCheck();
         final Object regularClass = regularClassConstructor.newInstance(token, "sur",
-                new JavadocMethodCheck());
+                methodCheck);
 
         final Method toString = regularClass.getClass().getDeclaredMethod("toString");
         toString.setAccessible(true);
         final String result = (String) toString.invoke(regularClass);
-        assertEquals("RegularClass[name=Token[blablabla(1x1)], in class=sur, loadable=true,"
-                + " class=null]", result);
+        final String expected = "RegularClass[name=Token[blablabla(1x1)], in class='sur', check="
+                + methodCheck.hashCode() + "," + " loadable=true, class=null]";
+
+        assertEquals("Invalid toString result", expected, result);
 
         final Method setClazz = regularClass.getClass().getDeclaredMethod("setClazz", Class.class);
         setClazz.setAccessible(true);
@@ -116,17 +112,17 @@ public class AbstractTypeAwareCheckTest extends BaseCheckTestSupport {
 
         final Method getClazz = regularClass.getClass().getDeclaredMethod("getClazz");
         getClazz.setAccessible(true);
-        assertNull(getClazz.invoke(regularClass));
+        assertNull("Expected null", getClazz.invoke(regularClass));
     }
 
     @Test
     public void testClassAliasToString() throws Exception {
-        final Class<?> tokenType = Class
-                .forName("com.puppycrawl.tools.checkstyle.checks.AbstractTypeAwareCheck$Token");
+        final Class<?> tokenType = Class.forName("com.puppycrawl.tools.checkstyle.checks.javadoc."
+                + "AbstractTypeAwareCheck$Token");
 
         final Class<?> regularClassType = Class
-                .forName(
-                    "com.puppycrawl.tools.checkstyle.checks.AbstractTypeAwareCheck$RegularClass");
+                .forName("com.puppycrawl.tools.checkstyle.checks.javadoc."
+                        + "AbstractTypeAwareCheck$RegularClass");
         final Constructor<?> regularClassConstructor = regularClassType.getDeclaredConstructor(
                 tokenType, String.class, AbstractTypeAwareCheck.class);
         regularClassConstructor.setAccessible(true);
@@ -139,9 +135,10 @@ public class AbstractTypeAwareCheckTest extends BaseCheckTestSupport {
                 new JavadocMethodCheck());
 
         final Class<?> classAliasType = Class.forName(
-                "com.puppycrawl.tools.checkstyle.checks.AbstractTypeAwareCheck$ClassAlias");
-        final Class<?> abstractTypeInfoType = Class.forName(
-                "com.puppycrawl.tools.checkstyle.checks.AbstractTypeAwareCheck$AbstractClassInfo");
+                "com.puppycrawl.tools.checkstyle.checks.javadoc.AbstractTypeAwareCheck$ClassAlias");
+        final Class<?> abstractTypeInfoType = Class
+                .forName("com.puppycrawl.tools.checkstyle.checks.javadoc."
+                        + "AbstractTypeAwareCheck$AbstractClassInfo");
 
         final Constructor<?> classAliasConstructor = classAliasType
                 .getDeclaredConstructor(tokenType, abstractTypeInfoType);
@@ -151,34 +148,38 @@ public class AbstractTypeAwareCheckTest extends BaseCheckTestSupport {
         final Method toString = classAlias.getClass().getDeclaredMethod("toString");
         toString.setAccessible(true);
         final String result = (String) toString.invoke(classAlias);
-        assertEquals("ClassAlias[alias Token[blablabla(1x1)] for Token[blablabla(1x1)]]", result);
+        assertEquals("Invalid toString result",
+            "ClassAlias[alias Token[blablabla(1x1)] for Token[blablabla(1x1)]]", result);
     }
 
     @Test
     public void testWithoutLogErrors() throws Exception {
-        final DefaultConfiguration config = createCheckConfig(JavadocMethodCheck.class);
+        final DefaultConfiguration config = createModuleConfig(JavadocMethodCheck.class);
         config.addAttribute("logLoadErrors", "false");
         config.addAttribute("allowUndeclaredRTE", "true");
         final String[] expected = {
             "7:8: " + getCheckMessage(MSG_CLASS_INFO, "@throws", "InvalidExceptionName"),
         };
         try {
-            verify(config, getPath("InputLoadErrors.java"), expected);
+            verify(config, getPath("InputAbstractTypeAwareLoadErrors.java"), expected);
+            fail("Exception is expected");
         }
         catch (CheckstyleException ex) {
             final IllegalStateException cause = (IllegalStateException) ex.getCause();
-            assertEquals("Unable to get"
-                            + " class information for @throws tag 'InvalidExceptionName'.",
-                    cause.getMessage());
+            assertEquals("Invalid exception message",
+                getCheckMessage(MSG_CLASS_INFO, "@throws", "InvalidExceptionName"),
+                cause.getMessage());
         }
     }
 
     @Test
     public void testWithSuppressLoadErrors() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(JavadocMethodCheck.class);
         checkConfig.addAttribute("suppressLoadErrors", "true");
         checkConfig.addAttribute("allowUndeclaredRTE", "true");
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
 
-        verify(checkConfig, getPath("InputLoadErrors.java"), expected);
+        verify(checkConfig, getPath("InputAbstractTypeAwareLoadErrors.java"), expected);
     }
+
 }
