@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2017 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -29,30 +29,19 @@ import static com.puppycrawl.tools.checkstyle.checks.javadoc.JavadocMethodCheck.
 import static com.puppycrawl.tools.checkstyle.checks.javadoc.JavadocMethodCheck.MSG_UNUSED_TAG_GENERAL;
 import static org.junit.Assert.assertArrayEquals;
 
-import java.io.File;
-import java.io.IOException;
-
-import org.junit.Before;
 import org.junit.Test;
 
-import com.puppycrawl.tools.checkstyle.BaseCheckTestSupport;
+import com.puppycrawl.tools.checkstyle.AbstractModuleTestSupport;
 import com.puppycrawl.tools.checkstyle.DefaultConfiguration;
 import com.puppycrawl.tools.checkstyle.api.Scope;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
 import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
 
-public class JavadocMethodCheckTest extends BaseCheckTestSupport {
-    private DefaultConfiguration checkConfig;
-
-    @Before
-    public void setUp() {
-        checkConfig = createCheckConfig(JavadocMethodCheck.class);
-    }
+public class JavadocMethodCheckTest extends AbstractModuleTestSupport {
 
     @Override
-    protected String getPath(String filename) throws IOException {
-        return super.getPath("checks" + File.separator
-                + "javadoc" + File.separator + filename);
+    protected String getPackageLocation() {
+        return "com/puppycrawl/tools/checkstyle/checks/javadoc/javadocmethod";
     }
 
     @Test
@@ -71,34 +60,34 @@ public class JavadocMethodCheckTest extends BaseCheckTestSupport {
             TokenTypes.ANNOTATION_FIELD_DEF,
         };
 
-        assertArrayEquals(expected, actual);
+        assertArrayEquals("Default acceptable tokens are invalid", expected, actual);
     }
 
     @Test
     public void testLogLoadErrors() throws Exception {
-        final DefaultConfiguration config = createCheckConfig(JavadocMethodCheck.class);
+        final DefaultConfiguration config = createModuleConfig(JavadocMethodCheck.class);
         config.addAttribute("logLoadErrors", "true");
         config.addAttribute("allowUndeclaredRTE", "true");
         final String[] expected = {
             "7:8: " + getCheckMessage(MSG_CLASS_INFO, "@throws", "InvalidExceptionName"),
         };
-        verify(config, getPath("InputLoadErrors.java"), expected);
+        verify(config, getPath("InputJavadocMethodLoadErrors.java"), expected);
     }
 
     @Test
     public void extendAnnotationTest() throws Exception {
-        final DefaultConfiguration config = createCheckConfig(JavadocMethodCheck.class);
+        final DefaultConfiguration config = createModuleConfig(JavadocMethodCheck.class);
         config.addAttribute("allowedAnnotations", "MyAnnotation, Override");
         config.addAttribute("minLineCount", "2");
         final String[] expected = {
             "44:1: " + getCheckMessage(MSG_JAVADOC_MISSING),
         };
-        verify(config, getPath("InputExtendAnnotation.java"), expected);
+        verify(config, getPath("InputJavadocMethodExtendAnnotation.java"), expected);
     }
 
     @Test
     public void newTest() throws Exception {
-        final DefaultConfiguration config = createCheckConfig(JavadocMethodCheck.class);
+        final DefaultConfiguration config = createModuleConfig(JavadocMethodCheck.class);
         config.addAttribute("allowedAnnotations", "MyAnnotation, Override");
         config.addAttribute("minLineCount", "2");
         final String[] expected = {
@@ -109,15 +98,15 @@ public class JavadocMethodCheckTest extends BaseCheckTestSupport {
 
     @Test
     public void allowedAnnotationsTest() throws Exception {
-
-        final DefaultConfiguration config = createCheckConfig(JavadocMethodCheck.class);
+        final DefaultConfiguration config = createModuleConfig(JavadocMethodCheck.class);
         config.addAttribute("allowedAnnotations", "Override,ThisIsOk, \t\n\t ThisIsOkToo");
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
-        verify(config, getPath("InputAllowedAnnotations.java"), expected);
+        verify(config, getPath("InputJavadocMethodAllowedAnnotations.java"), expected);
     }
 
     @Test
     public void testTags() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(JavadocMethodCheck.class);
         checkConfig.addAttribute("validateThrows", "true");
         final String[] expected = {
             "14:5: " + getCheckMessage(MSG_JAVADOC_MISSING),
@@ -146,15 +135,18 @@ public class JavadocMethodCheckTest extends BaseCheckTestSupport {
             "254:8: " + getCheckMessage(MSG_UNUSED_TAG, "@throws", "java.io.FileNotFoundException"),
             "256:28: " + getCheckMessage(MSG_EXPECTED_TAG, "@throws", "IOException"),
             "262:8: " + getCheckMessage(MSG_UNUSED_TAG, "@param", "aParam"),
-            "320:9: " + getCheckMessage(MSG_JAVADOC_MISSING),
-            "329:5: " + getCheckMessage(MSG_JAVADOC_MISSING),
+            "305: " + getCheckMessage(MSG_RETURN_EXPECTED),
+            "305:22: " + getCheckMessage(MSG_EXPECTED_TAG, "@param", "aParam"),
+            "328:9: " + getCheckMessage(MSG_JAVADOC_MISSING),
+            "337:5: " + getCheckMessage(MSG_JAVADOC_MISSING),
         };
 
-        verify(checkConfig, getPath("InputTags.java"), expected);
+        verify(checkConfig, getPath("InputJavadocMethodTags.java"), expected);
     }
 
     @Test
     public void testTagsWithResolver() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(JavadocMethodCheck.class);
         checkConfig.addAttribute("allowUndeclaredRTE", "true");
         checkConfig.addAttribute("validateThrows", "true");
         final String[] expected = {
@@ -181,14 +173,17 @@ public class JavadocMethodCheckTest extends BaseCheckTestSupport {
             "254:8: " + getCheckMessage(MSG_UNUSED_TAG, "@throws", "java.io.FileNotFoundException"),
             "256:28: " + getCheckMessage(MSG_EXPECTED_TAG, "@throws", "IOException"),
             "262:8: " + getCheckMessage(MSG_UNUSED_TAG, "@param", "aParam"),
-            "320:9: " + getCheckMessage(MSG_JAVADOC_MISSING),
-            "329:5: " + getCheckMessage(MSG_JAVADOC_MISSING),
+            "305: " + getCheckMessage(MSG_RETURN_EXPECTED),
+            "305:22: " + getCheckMessage(MSG_EXPECTED_TAG, "@param", "aParam"),
+            "328:9: " + getCheckMessage(MSG_JAVADOC_MISSING),
+            "337:5: " + getCheckMessage(MSG_JAVADOC_MISSING),
         };
-        verify(checkConfig, getPath("InputTags.java"), expected);
+        verify(checkConfig, getPath("InputJavadocMethodTags.java"), expected);
     }
 
     @Test
     public void testStrictJavadoc() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(JavadocMethodCheck.class);
         final String[] expected = {
             "12:9: " + getCheckMessage(MSG_JAVADOC_MISSING),
             "18:13: " + getCheckMessage(MSG_JAVADOC_MISSING),
@@ -204,19 +199,21 @@ public class JavadocMethodCheckTest extends BaseCheckTestSupport {
             "84:5: " + getCheckMessage(MSG_JAVADOC_MISSING),
             "94:32: " + getCheckMessage(MSG_EXPECTED_TAG, "@param", "aA"),
         };
-        verify(checkConfig, getPath("InputPublicOnly.java"), expected);
+        verify(checkConfig, getPath("InputJavadocMethodPublicOnly.java"), expected);
     }
 
     @Test
     public void testNoJavadoc() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(JavadocMethodCheck.class);
         checkConfig.addAttribute("scope", Scope.NOTHING.getName());
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
-        verify(checkConfig, getPath("InputPublicOnly.java"), expected);
+        verify(checkConfig, getPath("InputJavadocMethodPublicOnly.java"), expected);
     }
 
     // pre 1.4 relaxed mode is roughly equivalent with check=protected
     @Test
     public void testRelaxedJavadoc() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(JavadocMethodCheck.class);
         checkConfig.addAttribute("scope", Scope.PROTECTED.getName());
         final String[] expected = {
             "59:5: " + getCheckMessage(MSG_JAVADOC_MISSING),
@@ -224,45 +221,50 @@ public class JavadocMethodCheckTest extends BaseCheckTestSupport {
             "79:5: " + getCheckMessage(MSG_JAVADOC_MISSING),
             "84:5: " + getCheckMessage(MSG_JAVADOC_MISSING),
         };
-        verify(checkConfig, getPath("InputPublicOnly.java"), expected);
+        verify(checkConfig, getPath("InputJavadocMethodPublicOnly.java"), expected);
     }
 
     @Test
     public void testScopeInnerInterfacesPublic() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(JavadocMethodCheck.class);
         checkConfig.addAttribute("scope", Scope.PUBLIC.getName());
         final String[] expected = {
             "43:9: " + getCheckMessage(MSG_JAVADOC_MISSING),
             "44:9: " + getCheckMessage(MSG_JAVADOC_MISSING),
         };
-        verify(checkConfig, getPath("InputScopeInnerInterfaces.java"), expected);
+        verify(checkConfig, getPath("InputJavadocMethodScopeInnerInterfaces.java"), expected);
     }
 
     @Test
     public void testScopeAnonInnerPrivate() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(JavadocMethodCheck.class);
         checkConfig.addAttribute("scope", Scope.PRIVATE.getName());
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
-        verify(checkConfig, getPath("InputScopeAnonInner.java"), expected);
+        verify(checkConfig, getPath("InputJavadocMethodScopeAnonInner.java"), expected);
     }
 
     @Test
     public void testScopeAnonInnerAnonInner() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(JavadocMethodCheck.class);
         checkConfig.addAttribute("scope", Scope.ANONINNER.getName());
         final String[] expected = {
             "26:9: " + getCheckMessage(MSG_JAVADOC_MISSING),
             "39:17: " + getCheckMessage(MSG_JAVADOC_MISSING),
             "53:17: " + getCheckMessage(MSG_JAVADOC_MISSING), };
-        verify(checkConfig, getPath("InputScopeAnonInner.java"), expected);
+        verify(checkConfig, getPath("InputJavadocMethodScopeAnonInner.java"), expected);
     }
 
     @Test
     public void testScopeAnonInnerWithResolver() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(JavadocMethodCheck.class);
         checkConfig.addAttribute("allowUndeclaredRTE", "true");
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
-        verify(checkConfig, getPath("InputScopeAnonInner.java"), expected);
+        verify(checkConfig, getPath("InputJavadocMethodScopeAnonInner.java"), expected);
     }
 
     @Test
     public void testTagsWithSubclassesAllowed() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(JavadocMethodCheck.class);
         checkConfig.addAttribute("allowThrowsTagsForSubclasses", "true");
         checkConfig.addAttribute("validateThrows", "true");
         final String[] expected = {
@@ -289,14 +291,17 @@ public class JavadocMethodCheckTest extends BaseCheckTestSupport {
             "179:8: " + getCheckMessage(MSG_UNUSED_TAG, "@throws", "ArrayStoreException"),
             "256:28: " + getCheckMessage(MSG_EXPECTED_TAG, "@throws", "IOException"),
             "262:8: " + getCheckMessage(MSG_UNUSED_TAG, "@param", "aParam"),
-            "320:9: " + getCheckMessage(MSG_JAVADOC_MISSING),
-            "329:5: " + getCheckMessage(MSG_JAVADOC_MISSING),
+            "305: " + getCheckMessage(MSG_RETURN_EXPECTED),
+            "305:22: " + getCheckMessage(MSG_EXPECTED_TAG, "@param", "aParam"),
+            "328:9: " + getCheckMessage(MSG_JAVADOC_MISSING),
+            "337:5: " + getCheckMessage(MSG_JAVADOC_MISSING),
         };
-        verify(checkConfig, getPath("InputTags.java"), expected);
+        verify(checkConfig, getPath("InputJavadocMethodTags.java"), expected);
     }
 
     @Test
     public void testScopes() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(JavadocMethodCheck.class);
         final String[] expected = {
             "10:5: " + getCheckMessage(MSG_JAVADOC_MISSING),
             "11:5: " + getCheckMessage(MSG_JAVADOC_MISSING),
@@ -336,22 +341,24 @@ public class JavadocMethodCheckTest extends BaseCheckTestSupport {
             "108:9: " + getCheckMessage(MSG_JAVADOC_MISSING),
             "119:5: " + getCheckMessage(MSG_JAVADOC_MISSING),
         };
-        verify(checkConfig, getPath("InputNoJavadoc.java"), expected);
+        verify(checkConfig, getPath("InputJavadocMethodNoJavadoc.java"), expected);
     }
 
     @Test
     public void testScopes2() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(JavadocMethodCheck.class);
         checkConfig.addAttribute("scope", Scope.PROTECTED.getName());
         final String[] expected = {
             "10:5: " + getCheckMessage(MSG_JAVADOC_MISSING),
             "11:5: " + getCheckMessage(MSG_JAVADOC_MISSING),
             "21:9: " + getCheckMessage(MSG_JAVADOC_MISSING),
             "22:9: " + getCheckMessage(MSG_JAVADOC_MISSING), };
-        verify(checkConfig, getPath("InputNoJavadoc.java"), expected);
+        verify(checkConfig, getPath("InputJavadocMethodNoJavadoc.java"), expected);
     }
 
     @Test
     public void testExcludeScope() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(JavadocMethodCheck.class);
         checkConfig.addAttribute("scope", Scope.PRIVATE.getName());
         checkConfig.addAttribute("excludeScope", Scope.PROTECTED.getName());
         final String[] expected = {
@@ -381,27 +388,30 @@ public class JavadocMethodCheckTest extends BaseCheckTestSupport {
             "108:9: " + getCheckMessage(MSG_JAVADOC_MISSING),
             "119:5: " + getCheckMessage(MSG_JAVADOC_MISSING),
         };
-        verify(checkConfig, getPath("InputNoJavadoc.java"), expected);
+        verify(checkConfig, getPath("InputJavadocMethodNoJavadoc.java"), expected);
     }
 
     @Test
     public void testAllowMissingJavadoc() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(JavadocMethodCheck.class);
         checkConfig.addAttribute("allowMissingJavadoc", "true");
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
-        verify(checkConfig, getPath("InputNoJavadoc.java"), expected);
+        verify(checkConfig, getPath("InputJavadocMethodNoJavadoc.java"), expected);
     }
 
     @Test
     public void testAllowMissingJavadocTags() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(JavadocMethodCheck.class);
         checkConfig.addAttribute("allowMissingParamTags", "true");
         checkConfig.addAttribute("allowMissingThrowsTags", "true");
         checkConfig.addAttribute("allowMissingReturnTag", "true");
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
-        verify(checkConfig, getPath("InputMissingJavadocTags.java"), expected);
+        verify(checkConfig, getPath("InputJavadocMethodMissingJavadocTags.java"), expected);
     }
 
     @Test
     public void testDoAllowMissingJavadocTagsByDefault() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(JavadocMethodCheck.class);
         final String[] expected = {
             "10: " + getCheckMessage(MSG_RETURN_EXPECTED),
             "20:26: " + getCheckMessage(MSG_EXPECTED_TAG, "@param", "number"),
@@ -410,11 +420,12 @@ public class JavadocMethodCheckTest extends BaseCheckTestSupport {
             "61: " + getCheckMessage(MSG_RETURN_EXPECTED),
             "72: " + getCheckMessage(MSG_RETURN_EXPECTED),
         };
-        verify(checkConfig, getPath("InputMissingJavadocTags.java"), expected);
+        verify(checkConfig, getPath("InputJavadocMethodMissingJavadocTags.java"), expected);
     }
 
     @Test
     public void testSetterGetterOff() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(JavadocMethodCheck.class);
         final String[] expected = {
             "7:5: " + getCheckMessage(MSG_JAVADOC_MISSING),
             "12:5: " + getCheckMessage(MSG_JAVADOC_MISSING),
@@ -434,11 +445,12 @@ public class JavadocMethodCheckTest extends BaseCheckTestSupport {
             "74:5: " + getCheckMessage(MSG_JAVADOC_MISSING),
             "76:5: " + getCheckMessage(MSG_JAVADOC_MISSING),
         };
-        verify(checkConfig, getPath("InputSetterGetter.java"), expected);
+        verify(checkConfig, getPath("InputJavadocMethodSetterGetter.java"), expected);
     }
 
     @Test
     public void testSetterGetterOn() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(JavadocMethodCheck.class);
         checkConfig.addAttribute("allowMissingPropertyJavadoc", "true");
         final String[] expected = {
             "17:5: " + getCheckMessage(MSG_JAVADOC_MISSING),
@@ -456,42 +468,47 @@ public class JavadocMethodCheckTest extends BaseCheckTestSupport {
             "74:5: " + getCheckMessage(MSG_JAVADOC_MISSING),
             "76:5: " + getCheckMessage(MSG_JAVADOC_MISSING),
         };
-        verify(checkConfig, getPath("InputSetterGetter.java"), expected);
+        verify(checkConfig, getPath("InputJavadocMethodSetterGetter.java"), expected);
     }
 
     @Test
     public void testTypeParamsTags() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(JavadocMethodCheck.class);
         final String[] expected = {
             "26:8: " + getCheckMessage(MSG_UNUSED_TAG, "@param", "<BB>"),
             "28:13: " + getCheckMessage(MSG_EXPECTED_TAG, "@param", "<Z>"),
             "53:8: " + getCheckMessage(MSG_UNUSED_TAG, "@param", "<Z"),
             "55:13: " + getCheckMessage(MSG_EXPECTED_TAG, "@param", "<Z>"),
         };
-        verify(checkConfig, getPath("InputTypeParamsTags.java"), expected);
+        verify(checkConfig, getPath("InputJavadocMethodTypeParamsTags.java"), expected);
     }
 
     @Test
     public void test11684081() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(JavadocMethodCheck.class);
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
-        verify(checkConfig, getPath("Input_01.java"), expected);
+        verify(checkConfig, getPath("InputJavadocMethod_01.java"), expected);
     }
 
     @Test
     public void test11684082() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(JavadocMethodCheck.class);
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
-        verify(checkConfig, getPath("Input_02.java"), expected);
+        verify(checkConfig, getPath("InputJavadocMethod_02.java"), expected);
     }
 
     @Test
     public void test11684083() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(JavadocMethodCheck.class);
         checkConfig.addAttribute("allowThrowsTagsForSubclasses", "true");
         checkConfig.addAttribute("allowUndeclaredRTE", "true");
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
-        verify(checkConfig, getPath("Input_03.java"), expected);
+        verify(checkConfig, getPath("InputJavadocMethod_03.java"), expected);
     }
 
     @Test
     public void testGenerics1() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(JavadocMethodCheck.class);
         checkConfig.addAttribute("allowThrowsTagsForSubclasses", "true");
         checkConfig.addAttribute("allowUndeclaredRTE", "true");
         checkConfig.addAttribute("validateThrows", "true");
@@ -502,11 +519,12 @@ public class JavadocMethodCheckTest extends BaseCheckTestSupport {
             "43:38: " + getCheckMessage(MSG_EXPECTED_TAG, "@throws", "RuntimeException"),
             "44:13: " + getCheckMessage(MSG_EXPECTED_TAG, "@throws", "java.lang.RuntimeException"),
         };
-        verify(checkConfig, getPath("InputTestGenerics.java"), expected);
+        verify(checkConfig, getPath("InputJavadocMethodGenerics.java"), expected);
     }
 
     @Test
     public void testGenerics2() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(JavadocMethodCheck.class);
         checkConfig.addAttribute("allowThrowsTagsForSubclasses", "true");
         checkConfig.addAttribute("validateThrows", "true");
         final String[] expected = {
@@ -516,11 +534,12 @@ public class JavadocMethodCheckTest extends BaseCheckTestSupport {
             "43:38: " + getCheckMessage(MSG_EXPECTED_TAG, "@throws", "RuntimeException"),
             "44:13: " + getCheckMessage(MSG_EXPECTED_TAG, "@throws", "java.lang.RuntimeException"),
         };
-        verify(checkConfig, getPath("InputTestGenerics.java"), expected);
+        verify(checkConfig, getPath("InputJavadocMethodGenerics.java"), expected);
     }
 
     @Test
     public void testGenerics3() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(JavadocMethodCheck.class);
         checkConfig.addAttribute("validateThrows", "true");
         final String[] expected = {
             "8:8: " + getCheckMessage(MSG_UNUSED_TAG, "@throws", "RE"),
@@ -530,19 +549,21 @@ public class JavadocMethodCheckTest extends BaseCheckTestSupport {
             "43:38: " + getCheckMessage(MSG_EXPECTED_TAG, "@throws", "RuntimeException"),
             "44:13: " + getCheckMessage(MSG_EXPECTED_TAG, "@throws", "java.lang.RuntimeException"),
         };
-        verify(checkConfig, getPath("InputTestGenerics.java"), expected);
+        verify(checkConfig, getPath("InputJavadocMethodGenerics.java"), expected);
     }
 
     @Test
     public void test1379666() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(JavadocMethodCheck.class);
         checkConfig.addAttribute("allowThrowsTagsForSubclasses", "true");
         checkConfig.addAttribute("allowUndeclaredRTE", "true");
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
-        verify(checkConfig, getPath("Input_1379666.java"), expected);
+        verify(checkConfig, getPath("InputJavadocMethod_1379666.java"), expected);
     }
 
     @Test
     public void testInheritDoc() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(JavadocMethodCheck.class);
         final String[] expected = {
             "6:5: " + getCheckMessage(MSG_INVALID_INHERIT_DOC),
             "11:5: " + getCheckMessage(MSG_INVALID_INHERIT_DOC),
@@ -551,11 +572,12 @@ public class JavadocMethodCheckTest extends BaseCheckTestSupport {
             "41:5: " + getCheckMessage(MSG_INVALID_INHERIT_DOC),
             "46:5: " + getCheckMessage(MSG_INVALID_INHERIT_DOC),
         };
-        verify(checkConfig, getPath("InputInheritDoc.java"), expected);
+        verify(checkConfig, getPath("InputJavadocMethodInheritDoc.java"), expected);
     }
 
     @Test
     public void testSkipCertainMethods() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(JavadocMethodCheck.class);
         checkConfig.addAttribute("ignoreMethodNamesRegex", "^foo.*$");
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
         verify(checkConfig, getPath("InputJavadocMethodIgnoreNameRegex.java"), expected);
@@ -563,6 +585,7 @@ public class JavadocMethodCheckTest extends BaseCheckTestSupport {
 
     @Test
     public void testNotSkipAnythingWhenSkipRegexDoesNotMatch() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(JavadocMethodCheck.class);
         checkConfig.addAttribute("ignoreMethodNamesRegex", "regexThatDoesNotMatch");
         final String[] expected = {
             "5:5: " + getCheckMessage(MSG_JAVADOC_MISSING),
@@ -574,6 +597,7 @@ public class JavadocMethodCheckTest extends BaseCheckTestSupport {
 
     @Test
     public void testMethodsNotSkipWrittenJavadocs() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(JavadocMethodCheck.class);
         checkConfig.addAttribute("allowedAnnotations", "MyAnnotation");
         final String[] expected = {
             "7:8: " + getCheckMessage(MSG_UNUSED_TAG, "@param", "BAD"),
@@ -583,7 +607,8 @@ public class JavadocMethodCheckTest extends BaseCheckTestSupport {
     }
 
     @Test
-    public void testAllowToSkipOverriden() throws Exception {
+    public void testAllowToSkipOverridden() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(JavadocMethodCheck.class);
         checkConfig.addAttribute("allowedAnnotations", "MyAnnotation");
         final String[] expected = {
             "7:8: " + getCheckMessage(MSG_UNUSED_TAG, "@param", "BAD"),
@@ -594,7 +619,9 @@ public class JavadocMethodCheckTest extends BaseCheckTestSupport {
 
     @Test
     public void testJava8ReceiverParameter() throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(JavadocMethodCheck.class);
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
-        verify(checkConfig, getPath("InputJavadocReceiverParameter.java"), expected);
+        verify(checkConfig, getPath("InputJavadocMethodReceiverParameter.java"), expected);
     }
+
 }
