@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2017 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -22,27 +22,24 @@ package com.puppycrawl.tools.checkstyle.checks.naming;
 import static com.puppycrawl.tools.checkstyle.checks.naming.AbstractClassNameCheck.MSG_ILLEGAL_ABSTRACT_CLASS_NAME;
 import static com.puppycrawl.tools.checkstyle.checks.naming.AbstractClassNameCheck.MSG_NO_ABSTRACT_CLASS_MODIFIER;
 
-import java.io.File;
-import java.io.IOException;
-
 import org.junit.Assert;
 import org.junit.Test;
 
-import com.puppycrawl.tools.checkstyle.BaseCheckTestSupport;
+import com.puppycrawl.tools.checkstyle.AbstractModuleTestSupport;
 import com.puppycrawl.tools.checkstyle.DefaultConfiguration;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
 
-public class AbstractClassNameCheckTest extends BaseCheckTestSupport {
+public class AbstractClassNameCheckTest extends AbstractModuleTestSupport {
+
     @Override
-    protected String getPath(String filename) throws IOException {
-        return super.getPath("checks" + File.separator
-                + "naming" + File.separator + filename);
+    protected String getPackageLocation() {
+        return "com/puppycrawl/tools/checkstyle/checks/naming/abstractclassname";
     }
 
     @Test
     public void testIllegalAbstractClassName() throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(AbstractClassNameCheck.class);
+            createModuleConfig(AbstractClassNameCheck.class);
         checkConfig.addAttribute("ignoreName", "false");
         checkConfig.addAttribute("ignoreModifier", "true");
 
@@ -63,19 +60,18 @@ public class AbstractClassNameCheckTest extends BaseCheckTestSupport {
     @Test
     public void testCustomFormat() throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(AbstractClassNameCheck.class);
+            createModuleConfig(AbstractClassNameCheck.class);
         checkConfig.addAttribute("ignoreName", "false");
         checkConfig.addAttribute("ignoreModifier", "true");
-        final String pattern = "^NonAbstract.+$";
-        checkConfig.addAttribute("format", pattern);
+        checkConfig.addAttribute("format", "^NonAbstract.+$");
 
         final String[] expected = {
             "3:1: " + getCheckMessage(MSG_ILLEGAL_ABSTRACT_CLASS_NAME, "InputAbstractClassName",
-                pattern),
+                "^NonAbstract.+$"),
             "9:1: " + getCheckMessage(MSG_ILLEGAL_ABSTRACT_CLASS_NAME, "AbstractClassOther",
-                pattern),
+                "^NonAbstract.+$"),
             "21:1: " + getCheckMessage(MSG_ILLEGAL_ABSTRACT_CLASS_NAME, "AbstractClassName2",
-                pattern),
+                "^NonAbstract.+$"),
         };
 
         verify(checkConfig, getPath("InputAbstractClassName.java"), expected);
@@ -83,7 +79,7 @@ public class AbstractClassNameCheckTest extends BaseCheckTestSupport {
 
     @Test
     public void testIllegalClassType() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(AbstractClassNameCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(AbstractClassNameCheck.class);
         checkConfig.addAttribute("ignoreName", "true");
         checkConfig.addAttribute("ignoreModifier", "false");
 
@@ -97,7 +93,7 @@ public class AbstractClassNameCheckTest extends BaseCheckTestSupport {
 
     @Test
     public void testAllVariants() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(AbstractClassNameCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(AbstractClassNameCheck.class);
         checkConfig.addAttribute("ignoreName", "false");
         checkConfig.addAttribute("ignoreModifier", "false");
 
@@ -119,7 +115,7 @@ public class AbstractClassNameCheckTest extends BaseCheckTestSupport {
 
     @Test
     public void testFalsePositive() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(AbstractClassNameCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(AbstractClassNameCheck.class);
 
         final String[] expected = {
             "9:5: " + getCheckMessage(MSG_NO_ABSTRACT_CLASS_MODIFIER, "AbstractClass"),
@@ -135,7 +131,7 @@ public class AbstractClassNameCheckTest extends BaseCheckTestSupport {
         final int[] expected = {
             TokenTypes.CLASS_DEF,
         };
-        Assert.assertArrayEquals(expected, actual);
+        Assert.assertArrayEquals("Invalid acceptable tokens", expected, actual);
     }
 
     @Test
@@ -145,6 +141,7 @@ public class AbstractClassNameCheckTest extends BaseCheckTestSupport {
         final int[] expected = {
             TokenTypes.CLASS_DEF,
         };
-        Assert.assertArrayEquals(expected, actual);
+        Assert.assertArrayEquals("Invalid required tokens", expected, actual);
     }
+
 }
