@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2017 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -22,21 +22,18 @@ package com.puppycrawl.tools.checkstyle.checks.naming;
 import static com.puppycrawl.tools.checkstyle.checks.naming.AbstractNameCheck.MSG_INVALID_PATTERN;
 import static org.junit.Assert.assertArrayEquals;
 
-import java.io.File;
-import java.io.IOException;
-
 import org.junit.Test;
 
-import com.puppycrawl.tools.checkstyle.BaseCheckTestSupport;
+import com.puppycrawl.tools.checkstyle.AbstractModuleTestSupport;
 import com.puppycrawl.tools.checkstyle.DefaultConfiguration;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
 
 public class ClassTypeParameterNameCheckTest
-    extends BaseCheckTestSupport {
+    extends AbstractModuleTestSupport {
+
     @Override
-    protected String getPath(String filename) throws IOException {
-        return super.getPath("checks" + File.separator
-                + "naming" + File.separator + filename);
+    protected String getPackageLocation() {
+        return "com/puppycrawl/tools/checkstyle/checks/naming/classtypeparametername";
     }
 
     @Test
@@ -44,39 +41,40 @@ public class ClassTypeParameterNameCheckTest
         final ClassTypeParameterNameCheck checkObj =
             new ClassTypeParameterNameCheck();
         final int[] expected = {TokenTypes.TYPE_PARAMETER};
-        assertArrayEquals(expected, checkObj.getRequiredTokens());
+        assertArrayEquals("Default required tokens are invalid",
+            expected, checkObj.getRequiredTokens());
     }
 
     @Test
     public void testClassDefault()
             throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(ClassTypeParameterNameCheck.class);
+            createModuleConfig(ClassTypeParameterNameCheck.class);
 
         final String pattern = "^[A-Z]$";
 
         final String[] expected = {
-            "5:38: " + getCheckMessage(MSG_INVALID_PATTERN, "t", pattern),
+            "5:42: " + getCheckMessage(MSG_INVALID_PATTERN, "t", pattern),
             "13:14: " + getCheckMessage(MSG_INVALID_PATTERN, "foo", pattern),
             "27:24: " + getCheckMessage(MSG_INVALID_PATTERN, "foo", pattern),
         };
-        verify(checkConfig, getPath("InputTypeParameterName.java"), expected);
+        verify(checkConfig, getPath("InputClassTypeParameterName.java"), expected);
     }
 
     @Test
     public void testClassFooName()
             throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(ClassTypeParameterNameCheck.class);
+            createModuleConfig(ClassTypeParameterNameCheck.class);
         checkConfig.addAttribute("format", "^foo$");
 
         final String pattern = "^foo$";
 
         final String[] expected = {
-            "5:38: " + getCheckMessage(MSG_INVALID_PATTERN, "t", pattern),
+            "5:42: " + getCheckMessage(MSG_INVALID_PATTERN, "t", pattern),
             "33:18: " + getCheckMessage(MSG_INVALID_PATTERN, "T", pattern),
         };
-        verify(checkConfig, getPath("InputTypeParameterName.java"), expected);
+        verify(checkConfig, getPath("InputClassTypeParameterName.java"), expected);
     }
 
     @Test
@@ -87,6 +85,7 @@ public class ClassTypeParameterNameCheckTest
         final int[] expected = {
             TokenTypes.TYPE_PARAMETER,
         };
-        assertArrayEquals(expected, actual);
+        assertArrayEquals("Default acceptable tokens are invalid", expected, actual);
     }
+
 }
