@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2017 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -22,30 +22,25 @@ package com.puppycrawl.tools.checkstyle.checks.naming;
 import static com.puppycrawl.tools.checkstyle.checks.naming.AbstractNameCheck.MSG_INVALID_PATTERN;
 import static com.puppycrawl.tools.checkstyle.checks.naming.TypeNameCheck.DEFAULT_PATTERN;
 
-import java.io.File;
-import java.io.IOException;
-
 import org.junit.Test;
 
-import com.puppycrawl.tools.checkstyle.BaseCheckTestSupport;
+import com.puppycrawl.tools.checkstyle.AbstractModuleTestSupport;
 import com.puppycrawl.tools.checkstyle.DefaultConfiguration;
-import com.puppycrawl.tools.checkstyle.api.TokenTypes;
 import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
-import com.puppycrawl.tools.checkstyle.utils.TokenUtils;
 
 public class TypeNameCheckTest
-    extends BaseCheckTestSupport {
+    extends AbstractModuleTestSupport {
+
     @Override
-    protected String getPath(String filename) throws IOException {
-        return super.getPath("checks" + File.separator
-                + "naming" + File.separator + filename);
+    protected String getPackageLocation() {
+        return "com/puppycrawl/tools/checkstyle/checks/naming/typename";
     }
 
     @Test
     public void testSpecified()
             throws Exception {
         final DefaultConfiguration checkConfig =
-                createCheckConfig(TypeNameCheck.class);
+                createModuleConfig(TypeNameCheck.class);
         checkConfig.addAttribute("format", "^inputHe");
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
         verify(checkConfig, getPath("InputTypeName.java"), expected);
@@ -55,7 +50,7 @@ public class TypeNameCheckTest
     public void testDefault()
             throws Exception {
         final DefaultConfiguration checkConfig =
-                createCheckConfig(TypeNameCheck.class);
+                createModuleConfig(TypeNameCheck.class);
         final String[] expected = {
             "3:7: " + getCheckMessage(MSG_INVALID_PATTERN,
                     "inputHeaderClass", DEFAULT_PATTERN),
@@ -73,8 +68,8 @@ public class TypeNameCheckTest
     public void testClassSpecific()
             throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(TypeNameCheck.class);
-        checkConfig.addAttribute("tokens", TokenUtils.getTokenName(TokenTypes.CLASS_DEF));
+            createModuleConfig(TypeNameCheck.class);
+        checkConfig.addAttribute("tokens", "CLASS_DEF");
         final String[] expected = {
             "3:7: " + getCheckMessage(MSG_INVALID_PATTERN,
                     "inputHeaderClass", DEFAULT_PATTERN),
@@ -86,8 +81,8 @@ public class TypeNameCheckTest
     public void testInterfaceSpecific()
             throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(TypeNameCheck.class);
-        checkConfig.addAttribute("tokens", TokenUtils.getTokenName(TokenTypes.INTERFACE_DEF));
+            createModuleConfig(TypeNameCheck.class);
+        checkConfig.addAttribute("tokens", "INTERFACE_DEF");
         final String[] expected = {
             "5:22: " + getCheckMessage(MSG_INVALID_PATTERN,
                     "inputHeaderInterface", DEFAULT_PATTERN),
@@ -99,8 +94,8 @@ public class TypeNameCheckTest
     public void testEnumSpecific()
             throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(TypeNameCheck.class);
-        checkConfig.addAttribute("tokens", TokenUtils.getTokenName(TokenTypes.ENUM_DEF));
+            createModuleConfig(TypeNameCheck.class);
+        checkConfig.addAttribute("tokens", "ENUM_DEF");
         final String[] expected = {
             "7:17: " + getCheckMessage(MSG_INVALID_PATTERN,
                     "inputHeaderEnum", DEFAULT_PATTERN),
@@ -112,12 +107,13 @@ public class TypeNameCheckTest
     public void testAnnotationSpecific()
             throws Exception {
         final DefaultConfiguration checkConfig =
-            createCheckConfig(TypeNameCheck.class);
-        checkConfig.addAttribute("tokens", TokenUtils.getTokenName(TokenTypes.ANNOTATION_DEF));
+            createModuleConfig(TypeNameCheck.class);
+        checkConfig.addAttribute("tokens", "ANNOTATION_DEF");
         final String[] expected = {
             "9:23: " + getCheckMessage(MSG_INVALID_PATTERN,
                 "inputHeaderAnnotation", DEFAULT_PATTERN),
         };
         verify(checkConfig, getPath("InputTypeName.java"), expected);
     }
+
 }
