@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2017 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -23,34 +23,37 @@ import static com.puppycrawl.tools.checkstyle.checks.regexp.RegexpOnFilenameChec
 import static com.puppycrawl.tools.checkstyle.checks.regexp.RegexpOnFilenameCheck.MSG_MISMATCH;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.fail;
+import static org.mockito.Mockito.spy;
+import static org.mockito.Mockito.when;
 
 import java.io.File;
-import java.io.IOException;
 import java.util.regex.Pattern;
 
 import org.junit.Test;
 
-import com.puppycrawl.tools.checkstyle.BaseFileSetCheckTestSupport;
+import com.puppycrawl.tools.checkstyle.AbstractModuleTestSupport;
 import com.puppycrawl.tools.checkstyle.DefaultConfiguration;
 import com.puppycrawl.tools.checkstyle.api.CheckstyleException;
 import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
 
-public class RegexpOnFilenameCheckTest extends BaseFileSetCheckTestSupport {
+public class RegexpOnFilenameCheckTest extends AbstractModuleTestSupport {
+
     @Override
-    protected String getPath(String filename) throws IOException {
-        return super.getPath("checks" + File.separator + "regexp" + File.separator + filename);
+    protected String getPackageLocation() {
+        return "com/puppycrawl/tools/checkstyle/checks/regexp/regexponfilename";
     }
 
     @Test
     public void testDefaultConfigurationOnValidInput() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(RegexpOnFilenameCheck.class);
-        verify(checkConfig, getPath("InputSemantic.java"), CommonUtils.EMPTY_STRING_ARRAY);
+        final DefaultConfiguration checkConfig = createModuleConfig(RegexpOnFilenameCheck.class);
+        verify(checkConfig, getPath("InputRegexpOnFilenameSemantic.java"),
+                CommonUtils.EMPTY_STRING_ARRAY);
     }
 
     @Test
     public void testDefaultProperties() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(RegexpOnFilenameCheck.class);
-        final String path = getPath("Input Space.properties");
+        final DefaultConfiguration checkConfig = createModuleConfig(RegexpOnFilenameCheck.class);
+        final String path = getPath("InputRegexpOnFilename Space.properties");
         final String[] expected = {
             "0: " + getCheckMessage(MSG_MATCH, "", "\\s"),
         };
@@ -59,10 +62,10 @@ public class RegexpOnFilenameCheckTest extends BaseFileSetCheckTestSupport {
 
     @Test
     public void testMatchFileMatches() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(RegexpOnFilenameCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(RegexpOnFilenameCheck.class);
         checkConfig.addAttribute("match", "true");
         checkConfig.addAttribute("fileNamePattern", ".*\\.java");
-        final String path = getPath("InputSemantic.java");
+        final String path = getPath("InputRegexpOnFilenameSemantic.java");
         final String[] expected = {
             "0: " + getCheckMessage(MSG_MATCH, "", ".*\\.java"),
         };
@@ -71,18 +74,19 @@ public class RegexpOnFilenameCheckTest extends BaseFileSetCheckTestSupport {
 
     @Test
     public void testMatchFileNotMatches() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(RegexpOnFilenameCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(RegexpOnFilenameCheck.class);
         checkConfig.addAttribute("match", "true");
         checkConfig.addAttribute("fileNamePattern", "BAD.*");
-        verify(checkConfig, getPath("InputSemantic.java"), CommonUtils.EMPTY_STRING_ARRAY);
+        verify(checkConfig, getPath("InputRegexpOnFilenameSemantic.java"),
+                CommonUtils.EMPTY_STRING_ARRAY);
     }
 
     @Test
     public void testNotMatchFileMatches() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(RegexpOnFilenameCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(RegexpOnFilenameCheck.class);
         checkConfig.addAttribute("match", "false");
         checkConfig.addAttribute("fileNamePattern", ".*\\.properties");
-        final String path = getPath("InputSemantic.java");
+        final String path = getPath("InputRegexpOnFilenameSemantic.java");
         final String[] expected = {
             "0: " + getCheckMessage(MSG_MISMATCH, "", ".*\\.properties"),
         };
@@ -91,18 +95,19 @@ public class RegexpOnFilenameCheckTest extends BaseFileSetCheckTestSupport {
 
     @Test
     public void testNotMatchFileNotMatches() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(RegexpOnFilenameCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(RegexpOnFilenameCheck.class);
         checkConfig.addAttribute("match", "false");
         checkConfig.addAttribute("fileNamePattern", ".*\\.java");
-        verify(checkConfig, getPath("InputSemantic.java"), CommonUtils.EMPTY_STRING_ARRAY);
+        verify(checkConfig, getPath("InputRegexpOnFilenameSemantic.java"),
+                CommonUtils.EMPTY_STRING_ARRAY);
     }
 
     @Test
     public void testMatchFolderMatches() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(RegexpOnFilenameCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(RegexpOnFilenameCheck.class);
         checkConfig.addAttribute("match", "true");
         checkConfig.addAttribute("folderPattern", ".*[\\\\/]resources[\\\\/].*");
-        final String path = getPath("InputSemantic.java");
+        final String path = getPath("InputRegexpOnFilenameSemantic.java");
         final String[] expected = {
             "0: " + getCheckMessage(MSG_MATCH, ".*[\\\\/]resources[\\\\/].*", ""),
         };
@@ -111,18 +116,19 @@ public class RegexpOnFilenameCheckTest extends BaseFileSetCheckTestSupport {
 
     @Test
     public void testMatchFolderNotMatches() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(RegexpOnFilenameCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(RegexpOnFilenameCheck.class);
         checkConfig.addAttribute("match", "true");
         checkConfig.addAttribute("folderPattern", "BAD.*");
-        verify(checkConfig, getPath("InputSemantic.java"), CommonUtils.EMPTY_STRING_ARRAY);
+        verify(checkConfig, getPath("InputRegexpOnFilenameSemantic.java"),
+                CommonUtils.EMPTY_STRING_ARRAY);
     }
 
     @Test
     public void testNotMatchFolderMatches() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(RegexpOnFilenameCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(RegexpOnFilenameCheck.class);
         checkConfig.addAttribute("match", "false");
         checkConfig.addAttribute("folderPattern", ".*[\\\\/]gov[\\\\/].*");
-        final String path = getPath("InputSemantic.java");
+        final String path = getPath("InputRegexpOnFilenameSemantic.java");
         final String[] expected = {
             "0: " + getCheckMessage(MSG_MISMATCH, ".*[\\\\/]gov[\\\\/].*", ""),
         };
@@ -131,19 +137,20 @@ public class RegexpOnFilenameCheckTest extends BaseFileSetCheckTestSupport {
 
     @Test
     public void testNotMatchFolderNotMatches() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(RegexpOnFilenameCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(RegexpOnFilenameCheck.class);
         checkConfig.addAttribute("match", "false");
         checkConfig.addAttribute("folderPattern", ".*[\\\\/]resources[\\\\/].*");
-        verify(checkConfig, getPath("InputSemantic.java"), CommonUtils.EMPTY_STRING_ARRAY);
+        verify(checkConfig, getPath("InputRegexpOnFilenameSemantic.java"),
+                CommonUtils.EMPTY_STRING_ARRAY);
     }
 
     @Test
     public void testMatchFolderAndFileMatches() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(RegexpOnFilenameCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(RegexpOnFilenameCheck.class);
         checkConfig.addAttribute("match", "true");
         checkConfig.addAttribute("folderPattern", ".*[\\\\/]resources[\\\\/].*");
         checkConfig.addAttribute("fileNamePattern", ".*\\.java");
-        final String path = getPath("InputSemantic.java");
+        final String path = getPath("InputRegexpOnFilenameSemantic.java");
         final String[] expected = {
             "0: " + getCheckMessage(MSG_MATCH, ".*[\\\\/]resources[\\\\/].*", ".*\\.java"),
         };
@@ -152,38 +159,41 @@ public class RegexpOnFilenameCheckTest extends BaseFileSetCheckTestSupport {
 
     @Test
     public void testMatchFolderAndFileNotMatchesBoth() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(RegexpOnFilenameCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(RegexpOnFilenameCheck.class);
         checkConfig.addAttribute("match", "true");
         checkConfig.addAttribute("folderPattern", "BAD.*");
         checkConfig.addAttribute("fileNamePattern", ".*\\.properties");
-        verify(checkConfig, getPath("InputSemantic.java"), CommonUtils.EMPTY_STRING_ARRAY);
+        verify(checkConfig, getPath("InputRegexpOnFilenameSemantic.java"),
+                CommonUtils.EMPTY_STRING_ARRAY);
     }
 
     @Test
     public void testMatchFolderAndFileNotMatchesFile() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(RegexpOnFilenameCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(RegexpOnFilenameCheck.class);
         checkConfig.addAttribute("match", "true");
         checkConfig.addAttribute("folderPattern", ".*[\\\\/]resources[\\\\/].*");
         checkConfig.addAttribute("fileNamePattern", ".*\\.properties");
-        verify(checkConfig, getPath("InputSemantic.java"), CommonUtils.EMPTY_STRING_ARRAY);
+        verify(checkConfig, getPath("InputRegexpOnFilenameSemantic.java"),
+                CommonUtils.EMPTY_STRING_ARRAY);
     }
 
     @Test
     public void testMatchFolderAndFileNotMatchesFolder() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(RegexpOnFilenameCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(RegexpOnFilenameCheck.class);
         checkConfig.addAttribute("match", "true");
         checkConfig.addAttribute("folderPattern", "BAD.*");
         checkConfig.addAttribute("fileNamePattern", ".*\\.java");
-        verify(checkConfig, getPath("InputSemantic.java"), CommonUtils.EMPTY_STRING_ARRAY);
+        verify(checkConfig, getPath("InputRegexpOnFilenameSemantic.java"),
+                CommonUtils.EMPTY_STRING_ARRAY);
     }
 
     @Test
     public void testNotMatchFolderAndFileMatches() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(RegexpOnFilenameCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(RegexpOnFilenameCheck.class);
         checkConfig.addAttribute("match", "false");
         checkConfig.addAttribute("folderPattern", ".*[\\\\/]com[\\\\/].*");
         checkConfig.addAttribute("fileNamePattern", ".*\\.dat");
-        final String path = getPath("InputSemantic.java");
+        final String path = getPath("InputRegexpOnFilenameSemantic.java");
         final String[] expected = {
             "0: " + getCheckMessage(MSG_MISMATCH, ".*[\\\\/]com[\\\\/].*", ".*\\.dat"),
         };
@@ -192,36 +202,40 @@ public class RegexpOnFilenameCheckTest extends BaseFileSetCheckTestSupport {
 
     @Test
     public void testNotMatchFolderAndFileNotMatchesFolder() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(RegexpOnFilenameCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(RegexpOnFilenameCheck.class);
         checkConfig.addAttribute("match", "false");
         checkConfig.addAttribute("folderPattern", ".*[\\\\/]javastrangefolder[\\\\/].*");
         checkConfig.addAttribute("fileNamePattern", ".*\\.dat");
-        verify(checkConfig, getPath("InputSemantic.java"), CommonUtils.EMPTY_STRING_ARRAY);
+        verify(checkConfig, getPath("InputRegexpOnFilenameSemantic.java"),
+                CommonUtils.EMPTY_STRING_ARRAY);
     }
 
     @Test
     public void testNotMatchFolderAndFileNotMatchesFile() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(RegexpOnFilenameCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(RegexpOnFilenameCheck.class);
         checkConfig.addAttribute("match", "false");
         checkConfig.addAttribute("folderPattern", ".*[\\\\/]govstrangefolder[\\\\/].*");
         checkConfig.addAttribute("fileNamePattern", ".*\\.java");
-        verify(checkConfig, getPath("InputSemantic.java"), CommonUtils.EMPTY_STRING_ARRAY);
+        verify(checkConfig, getPath("InputRegexpOnFilenameSemantic.java"),
+                CommonUtils.EMPTY_STRING_ARRAY);
     }
 
     @Test
     public void testIgnoreExtension() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(RegexpOnFilenameCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(RegexpOnFilenameCheck.class);
         checkConfig.addAttribute("fileNamePattern", ".*\\.java");
         checkConfig.addAttribute("ignoreFileNameExtensions", "true");
-        verify(checkConfig, getPath("InputSemantic.java"), CommonUtils.EMPTY_STRING_ARRAY);
+        verify(checkConfig, getPath("InputRegexpOnFilenameSemantic.java"),
+                CommonUtils.EMPTY_STRING_ARRAY);
     }
 
     @Test
     public void testIgnoreExtensionNoExtension() throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(RegexpOnFilenameCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(RegexpOnFilenameCheck.class);
         checkConfig.addAttribute("fileNamePattern", "\\.");
         checkConfig.addAttribute("ignoreFileNameExtensions", "true");
-        verify(checkConfig, getPath("InputNoExtension"), CommonUtils.EMPTY_STRING_ARRAY);
+        verify(checkConfig, getPath("InputRegexpOnFilenameNoExtension"),
+                CommonUtils.EMPTY_STRING_ARRAY);
     }
 
     @Test
@@ -235,8 +249,29 @@ public class RegexpOnFilenameCheckTest extends BaseFileSetCheckTestSupport {
             fail("CheckstyleException expected");
         }
         catch (CheckstyleException ex) {
-            assertEquals("unable to create canonical path names for " + file.getAbsolutePath(),
-                    ex.getMessage());
+            assertEquals("Invalid exception message",
+                "unable to create canonical path names for " + file.getAbsolutePath(),
+                ex.getMessage());
         }
     }
+
+    /**
+     * Test require readable file with no parent to be used.
+     * Usage of Mockito.spy() is the only way to satisfy these requirements
+     * without the need to create new file in current working directory.
+     *
+     * @throws Exception if error occurs
+     */
+    @Test
+    public void testWithFileWithoutParent() throws Exception {
+        final DefaultConfiguration moduleConfig = createModuleConfig(RegexpOnFilenameCheck.class);
+        final File fileWithoutParent = spy(new File(getPath("package-info.java")));
+        when(fileWithoutParent.getParent()).thenReturn(null);
+        when(fileWithoutParent.getParentFile()).thenReturn(null);
+        final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
+        verify(createChecker(moduleConfig),
+                new File[] {fileWithoutParent},
+                getPath("package-info.java"), expected);
+    }
+
 }
