@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2017 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -27,23 +27,14 @@ import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
 import java.net.HttpURLConnection;
-import java.net.URI;
 import java.net.URL;
 
 import org.junit.Rule;
 import org.junit.Test;
 import org.junit.rules.TemporaryFolder;
-import org.junit.runner.RunWith;
-import org.mockito.BDDMockito;
-import org.mockito.Mockito;
-import org.powermock.api.mockito.PowerMockito;
-import org.powermock.core.classloader.annotations.PrepareForTest;
-import org.powermock.modules.junit4.PowerMockRunner;
 
 import com.google.common.io.Closeables;
-import com.puppycrawl.tools.checkstyle.BaseCheckTestSupport;
-import com.puppycrawl.tools.checkstyle.BriefUtLogger;
-import com.puppycrawl.tools.checkstyle.Checker;
+import com.puppycrawl.tools.checkstyle.AbstractModuleTestSupport;
 import com.puppycrawl.tools.checkstyle.DefaultConfiguration;
 import com.puppycrawl.tools.checkstyle.api.AuditEvent;
 import com.puppycrawl.tools.checkstyle.api.CheckstyleException;
@@ -51,16 +42,14 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
 import nl.jqno.equalsverifier.EqualsVerifier;
 import nl.jqno.equalsverifier.Warning;
 
-@RunWith(PowerMockRunner.class)
-@PrepareForTest({SuppressionFilter.class, CommonUtils.class})
-public class SuppressionFilterTest extends BaseCheckTestSupport {
+public class SuppressionFilterTest extends AbstractModuleTestSupport {
 
     @Rule
     public final TemporaryFolder temporaryFolder = new TemporaryFolder();
 
     @Override
-    protected String getPath(String filename) throws IOException {
-        return super.getPath("filters" + File.separator + filename);
+    protected String getPackageLocation() {
+        return "com/puppycrawl/tools/checkstyle/filters/suppressionfilter";
     }
 
     @Test
@@ -74,138 +63,108 @@ public class SuppressionFilterTest extends BaseCheckTestSupport {
     }
 
     @Test
-    public void testAccept() throws CheckstyleException {
-        final String fileName = "src/test/resources/com/puppycrawl/tools/checkstyle/filters/"
-                          + "suppressions_none.xml";
+    public void testAccept() throws Exception {
+        final String fileName = getPath("InputSuppressionFilterNone.xml");
         final boolean optional = false;
-        final SuppressionFilter filter = createSupressionFilter(fileName, optional);
+        final SuppressionFilter filter = createSuppressionFilter(fileName, optional);
 
         final AuditEvent ev = new AuditEvent(this, "ATest.java", null);
 
-        assertTrue(filter.accept(ev));
+        assertTrue("Audit event should be excepted when there are no suppressions",
+            filter.accept(ev));
     }
 
     @Test
     public void testAcceptOnNullFile() throws CheckstyleException {
         final String fileName = null;
         final boolean optional = false;
-        final SuppressionFilter filter = createSupressionFilter(fileName, optional);
+        final SuppressionFilter filter = createSuppressionFilter(fileName, optional);
 
         final AuditEvent ev = new AuditEvent(this, "AnyJava.java", null);
-
-        assertTrue(filter.accept(ev));
+        assertTrue("Audit event on null file should be excepted, but was not", filter.accept(ev));
     }
 
     @Test
-    public void testNonExistanceSuppressionFileWithFalseOptional() {
-        final String fileName = "src/test/resources/com/puppycrawl/tools/checkstyle/filters/"
-                + "non_existance_suppresion_file.xml";
+    public void testNonExistentSuppressionFileWithFalseOptional() {
+        final String fileName = "non_existent_suppression_file.xml";
         try {
             final boolean optional = false;
-            createSupressionFilter(fileName, optional);
+            createSuppressionFilter(fileName, optional);
             fail("Exception is expected");
         }
         catch (CheckstyleException ex) {
-            assertEquals("Unable to find: " + fileName, ex.getMessage());
+            assertEquals("Invalid error message",
+                "Unable to find: " + fileName, ex.getMessage());
         }
     }
 
     @Test
-    public void testExistanceInvalidSuppressionFileWithTrueOptional() {
-        final String fileName = "src/test/resources/com/puppycrawl/tools/checkstyle/filters/"
-                + "suppressions_invalid_file.xml";
+    public void testExistingInvalidSuppressionFileWithTrueOptional() throws IOException {
+        final String fileName = getPath("InputSuppressionFilterInvalidFile.xml");
         try {
             final boolean optional = true;
-            createSupressionFilter(fileName, optional);
+            createSuppressionFilter(fileName, optional);
             fail("Exception is expected");
         }
         catch (CheckstyleException ex) {
-            assertEquals("Unable to parse " + fileName + " - invalid files or checks format",
-                    ex.getMessage());
+            assertEquals("Invalid error message",
+                "Unable to parse " + fileName + " - invalid files or checks or message format",
+                ex.getMessage());
         }
     }
 
     @Test
     public void testExistingSuppressionFileWithTrueOptional() throws Exception {
-        final String fileName = "src/test/resources/com/puppycrawl/tools/checkstyle/filters/"
-                + "suppressions_none.xml";
+        final String fileName = getPath("InputSuppressionFilterNone.xml");
         final boolean optional = true;
-        final SuppressionFilter filter = createSupressionFilter(fileName, optional);
+        final SuppressionFilter filter = createSuppressionFilter(fileName, optional);
 
         final AuditEvent ev = new AuditEvent(this, "AnyFile.java", null);
 
-        assertTrue(filter.accept(ev));
+        assertTrue("Suppression file with true optional was not accepted",
+            filter.accept(ev));
     }
 
     @Test
-    public void testExistingConfigWithTrueOptionalThrowsIoErrorWhileClosing()
-            throws Exception {
-        final InputStream inputStream = PowerMockito.mock(InputStream.class);
-        Mockito.doThrow(IOException.class).when(inputStream).close();
-
-        final URL url = PowerMockito.mock(URL.class);
-        BDDMockito.given(url.openStream()).willReturn(inputStream);
-
-        final URI uri = PowerMockito.mock(URI.class);
-        BDDMockito.given(uri.toURL()).willReturn(url);
-
-        PowerMockito.mockStatic(CommonUtils.class);
-
-        final String fileName = "src/test/resources/com/puppycrawl/tools/checkstyle/filters/"
-                + "suppressions_none.xml";
-        BDDMockito.given(CommonUtils.getUriByFilename(fileName)).willReturn(uri);
-
+    public void testNonExistentSuppressionFileWithTrueOptional() throws Exception {
+        final String fileName = "non_existent_suppression_file.xml";
         final boolean optional = true;
-        final SuppressionFilter filter = createSupressionFilter(fileName, optional);
-        final AuditEvent ev = new AuditEvent(this, "AnyFile.java", null);
-        assertTrue(filter.accept(ev));
-    }
-
-    @Test
-    public void testNonExistanceSuppressionFileWithTrueOptional() throws Exception {
-        final String fileName = "src/test/resources/com/puppycrawl/tools/checkstyle/filters/"
-                + "non_existance_suppresion_file.xml";
-        final boolean optional = true;
-        final SuppressionFilter filter = createSupressionFilter(fileName, optional);
+        final SuppressionFilter filter = createSuppressionFilter(fileName, optional);
 
         final AuditEvent ev = new AuditEvent(this, "AnyFile.java", null);
 
-        assertTrue(filter.accept(ev));
+        assertTrue("Should except event when suppression file does not exist",
+            filter.accept(ev));
     }
 
     @Test
-    public void testNonExistanceSuppressionUrlWithTrueOptional() throws Exception {
+    public void testNonExistentSuppressionUrlWithTrueOptional() throws Exception {
         final String fileName =
-                "http://checkstyle.sourceforge.net/non_existing_suppression.xml";
+                "http://checkstyle.sourceforge.net/non_existent_suppression.xml";
         final boolean optional = true;
-        final SuppressionFilter filter = createSupressionFilter(fileName, optional);
+        final SuppressionFilter filter = createSuppressionFilter(fileName, optional);
 
         final AuditEvent ev = new AuditEvent(this, "AnyFile.java", null);
 
-        assertTrue(filter.accept(ev));
+        assertTrue("Should except event when suppression file url does not exist",
+            filter.accept(ev));
     }
 
     @Test
     public void testLocalFileExternalResourceContentDoesNotChange() throws Exception {
-        final DefaultConfiguration filterConfig = createCheckConfig(SuppressionFilter.class);
-        filterConfig.addAttribute("file", getPath("suppressions_none.xml"));
+        final DefaultConfiguration filterConfig = createModuleConfig(SuppressionFilter.class);
+        filterConfig.addAttribute("file", getPath("InputSuppressionFilterNone.xml"));
 
-        final DefaultConfiguration checkerConfig = new DefaultConfiguration("checkstyle_checks");
-        checkerConfig.addChild(filterConfig);
-        final String cacheFile = temporaryFolder.newFile().getPath();
-        checkerConfig.addAttribute("cacheFile", cacheFile);
-
-        final Checker checker = new Checker();
-        checker.setModuleClassLoader(Thread.currentThread().getContextClassLoader());
-        checker.addListener(new BriefUtLogger(stream));
-        checker.configure(checkerConfig);
+        final DefaultConfiguration checkerConfig = createRootConfig(filterConfig);
+        final File cacheFile = temporaryFolder.newFile();
+        checkerConfig.addAttribute("cacheFile", cacheFile.getPath());
 
         final String filePath = temporaryFolder.newFile("file.java").getPath();
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
 
-        verify(checker, filePath, expected);
+        verify(checkerConfig, filePath, expected);
         // One more time to use cache.
-        verify(checker, filePath, expected);
+        verify(checkerConfig, filePath, expected);
     }
 
     @Test
@@ -230,38 +189,29 @@ public class SuppressionFilterTest extends BaseCheckTestSupport {
         // instead of a skip when it doesn't pass
         if (urlForTest != null) {
             final DefaultConfiguration firstFilterConfig =
-                createCheckConfig(SuppressionFilter.class);
+                createModuleConfig(SuppressionFilter.class);
+            // -@cs[CheckstyleTestMakeup] need to test dynamic property
             firstFilterConfig.addAttribute("file", urlForTest);
 
-            final DefaultConfiguration firstCheckerConfig =
-                new DefaultConfiguration("checkstyle_checks");
-            firstCheckerConfig.addChild(firstFilterConfig);
-            final String cacheFile = temporaryFolder.newFile().getPath();
-            firstCheckerConfig.addAttribute("cacheFile", cacheFile);
-
-            final Checker checker = new Checker();
-            checker.setModuleClassLoader(Thread.currentThread().getContextClassLoader());
-            checker.configure(firstCheckerConfig);
-            checker.addListener(new BriefUtLogger(stream));
+            final DefaultConfiguration firstCheckerConfig = createRootConfig(firstFilterConfig);
+            final File cacheFile = temporaryFolder.newFile();
+            firstCheckerConfig.addAttribute("cacheFile", cacheFile.getPath());
 
             final String pathToEmptyFile = temporaryFolder.newFile("file.java").getPath();
             final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
 
-            verify(checker, pathToEmptyFile, expected);
+            verify(firstCheckerConfig, pathToEmptyFile, expected);
 
             // One more time to use cache.
             final DefaultConfiguration secondFilterConfig =
-                createCheckConfig(SuppressionFilter.class);
+                createModuleConfig(SuppressionFilter.class);
+            // -@cs[CheckstyleTestMakeup] need to test dynamic property
             secondFilterConfig.addAttribute("file", urlForTest);
 
-            final DefaultConfiguration secondCheckerConfig =
-                new DefaultConfiguration("checkstyle_checks");
-            secondCheckerConfig.addAttribute("cacheFile", cacheFile);
-            secondCheckerConfig.addChild(secondFilterConfig);
+            final DefaultConfiguration secondCheckerConfig = createRootConfig(secondFilterConfig);
+            secondCheckerConfig.addAttribute("cacheFile", cacheFile.getPath());
 
-            checker.configure(secondCheckerConfig);
-
-            verify(checker, pathToEmptyFile, expected);
+            verify(secondCheckerConfig, pathToEmptyFile, expected);
         }
     }
 
@@ -275,9 +225,9 @@ public class SuppressionFilterTest extends BaseCheckTestSupport {
             while (attemptCount <= attemptLimit) {
                 InputStream stream = null;
                 try {
-                    final URL addres = new URL(url);
-                    stream = addres.openStream();
-                    // Attemt to read a byte in order to check wtether file content is available
+                    final URL address = new URL(url);
+                    stream = address.openStream();
+                    // Attempt to read a byte in order to check whether file content is available
                     available = stream.read() != -1;
                     break;
                 }
@@ -303,18 +253,19 @@ public class SuppressionFilterTest extends BaseCheckTestSupport {
     }
 
     private static boolean isUrlReachable(String url) {
+        boolean result = true;
         try {
             final URL verifiableUrl = new URL(url);
             final HttpURLConnection urlConnect = (HttpURLConnection) verifiableUrl.openConnection();
             urlConnect.getContent();
         }
-        catch (IOException ex) {
-            return false;
+        catch (IOException ignored) {
+            result = false;
         }
-        return true;
+        return result;
     }
 
-    private static SuppressionFilter createSupressionFilter(String fileName, boolean optional)
+    private static SuppressionFilter createSuppressionFilter(String fileName, boolean optional)
             throws CheckstyleException {
         final SuppressionFilter suppressionFilter = new SuppressionFilter();
         suppressionFilter.setFile(fileName);
@@ -322,4 +273,5 @@ public class SuppressionFilterTest extends BaseCheckTestSupport {
         suppressionFilter.finishLocalSetup();
         return suppressionFilter;
     }
+
 }
