@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2017 the original author or authors.
+// Copyright (C) 2001-2018 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -19,75 +19,67 @@
 
 package com.puppycrawl.tools.checkstyle.grammars.java8;
 
-import java.io.File;
-import java.io.IOException;
-
 import org.junit.Test;
 
-import com.puppycrawl.tools.checkstyle.BaseCheckTestSupport;
+import com.puppycrawl.tools.checkstyle.AbstractModuleTestSupport;
 import com.puppycrawl.tools.checkstyle.DefaultConfiguration;
 import com.puppycrawl.tools.checkstyle.checks.naming.MemberNameCheck;
 import com.puppycrawl.tools.checkstyle.utils.CommonUtils;
 
-public class MethodReferencesTest extends BaseCheckTestSupport {
+public class MethodReferencesTest extends AbstractModuleTestSupport {
+
     @Override
-    protected String getPath(String filename) throws IOException {
-        return super.getPath("grammars" + File.separator
-                + "java8" + File.separator + filename);
+    protected String getPackageLocation() {
+        return "com/puppycrawl/tools/checkstyle/grammars/java8";
     }
 
     @Test
     public void testCanParse()
             throws Exception {
         final DefaultConfiguration checkConfig =
-                createCheckConfig(MemberNameCheck.class);
+                createModuleConfig(MemberNameCheck.class);
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
         verify(checkConfig, getPath("InputMethodReferences.java"), expected);
-
     }
 
     @Test
     public void testFromSpec()
             throws Exception {
         final DefaultConfiguration checkConfig =
-                createCheckConfig(MemberNameCheck.class);
+                createModuleConfig(MemberNameCheck.class);
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
         verify(checkConfig, getPath("InputMethodReferences2.java"), expected);
-
     }
 
     @Test
     public void testGenericInPostfixExpressionBeforeReference()
             throws Exception {
         final DefaultConfiguration checkConfig =
-                createCheckConfig(MemberNameCheck.class);
+                createModuleConfig(MemberNameCheck.class);
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
         verify(checkConfig, getPath("InputMethodReferences3.java"), expected);
-
     }
 
     @Test
     public void testArrayAfterGeneric()
             throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(MemberNameCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(MemberNameCheck.class);
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
         verify(checkConfig, getPath("InputMethodReferences4.java"), expected);
-
     }
 
     @Test
-    public void testFromHiernate()
+    public void testFromHibernate()
             throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(MemberNameCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(MemberNameCheck.class);
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
         verify(checkConfig, getPath("InputMethodReferences5.java"), expected);
-
     }
 
     @Test
     public void testFromSpring()
             throws Exception {
-        final DefaultConfiguration checkConfig = createCheckConfig(MemberNameCheck.class);
+        final DefaultConfiguration checkConfig = createModuleConfig(MemberNameCheck.class);
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
         verify(checkConfig, getPath("InputMethodReferences6.java"), expected);
     }
@@ -96,9 +88,9 @@ public class MethodReferencesTest extends BaseCheckTestSupport {
     public void testMethodReferences7()
             throws Exception {
         final DefaultConfiguration checkConfig =
-                createCheckConfig(MemberNameCheck.class);
+                createModuleConfig(MemberNameCheck.class);
         final String[] expected = CommonUtils.EMPTY_STRING_ARRAY;
         verify(checkConfig, getPath("InputMethodReferences7.java"), expected);
-
     }
+
 }
